pub struct FormatSpec {
pub size: usize,
pub arg_count: usize,
/* private fields */
}Fields
size: usizearg_count: usizeImplementations
Sourceimpl FormatSpec
impl FormatSpec
pub fn parse(fmt: &[u8], vm: &VirtualMachine) -> PyResult<Self>
pub fn pack( &self, args: Vec<PyObjectRef>, vm: &VirtualMachine, ) -> PyResult<Vec<u8>>
Sourcepub fn try_pack(
&self,
args: Vec<PyObjectRef>,
vm: &VirtualMachine,
) -> Result<Vec<u8>, PackError>
pub fn try_pack( &self, args: Vec<PyObjectRef>, vm: &VirtualMachine, ) -> Result<Vec<u8>, PackError>
Self::pack, keeping why a value could not be packed.
pub fn pack_into( &self, buffer: &mut [u8], args: Vec<PyObjectRef>, vm: &VirtualMachine, ) -> PyResult<()>
Sourcepub fn try_pack_into(
&self,
buffer: &mut [u8],
args: Vec<PyObjectRef>,
vm: &VirtualMachine,
) -> Result<(), PackError>
pub fn try_pack_into( &self, buffer: &mut [u8], args: Vec<PyObjectRef>, vm: &VirtualMachine, ) -> Result<(), PackError>
Self::pack_into, keeping why a value could not be packed.
pub fn unpack(&self, data: &[u8], vm: &VirtualMachine) -> PyResult<PyTupleRef>
pub const fn size(&self) -> usize
pub fn codes_sizeof(&self) -> usize