Module builtins

Module builtins 

This package contains the python basic/builtin types 7 common PyRef type aliases are exposed - PyBytesRef, PyDictRef, PyIntRef, PyListRef, PyStrRef, PyTypeRef, PyTupleRef Do not add more PyRef type aliases. They will be rare enough to use directly PyRef<T>.

Structs

PositionIterInternal
PyArithmeticError
PyAssertionError
PyAsyncGen
PyAttributeError
PyBaseException
PyBaseExceptionGroup
PyBaseObject
object()
PyBlockingIOError
PyBool
PyBoundMethod
PyBrokenPipeError
PyBufferError
PyByteArray
PyBytes
PyBytesWarning
PyCallableIterator
PyCapsule
PyCapsule - a container for C pointers. In RustPython, this is a minimal implementation for compatibility.
PyChildProcessError
PyClassMethod
classmethod(function) -> method
PyCode
PyComplex
Create a complex number from a real part and an optional imaginary part.
PyConnectionAbortedError
PyConnectionError
PyConnectionRefusedError
PyConnectionResetError
PyCoroutine
PyDeprecationWarning
PyDict
PyEOFError
PyEllipsis
PyEncodingWarning
PyEnumerate
PyException
PyFileExistsError
PyFileNotFoundError
PyFilter
PyFloat
PyFloatingPointError
PyFrozenSet
PyFunction
PyFutureWarning
PyGenerator
PyGeneratorExit
PyGenericAlias
PyGetSet
PyImportError
PyImportWarning
PyIncompleteInputError
PyIndentationError
PyIndexError
PyInt
PyInterpolation
Interpolation object for t-strings (PEP 750).
PyInterruptedError
PyIsADirectoryError
PyKeyError
PyKeyboardInterrupt
PyList
PyLookupError
PyMap
PyMappingProxy
PyMemoryError
PyMemoryView
PyModule
PyModuleDef
PyModuleNotFoundError
PyModuleSlots
PyNameError
PyNamespace
A simple attribute-based namespace.
PyNone
PyNotADirectoryError
PyNotImplemented
PyNotImplementedError
PyOSError
PyOverflowError
PyPendingDeprecationWarning
PyPermissionError
PyProcessLookupError
PyProperty
PyPythonFinalizationError
PyRange
PyRecursionError
PyReferenceError
PyResourceWarning
PyRuntimeError
PyRuntimeWarning
PySequenceIterator
PySet
PySlice
PyStaticMethod
PyStopAsyncIteration
PyStopIteration
PyStr
PySuper
PySyntaxError
PySyntaxWarning
PySystemError
PySystemExit
PyTabError
PyTemplate
Template object for t-strings (PEP 750).
PyTemplateIter
Iterator for Template objects
PyTimeoutError
PyTraceback
PyTuple
PyType
PyTypeError
PyUnboundLocalError
PyUnicodeDecodeError
PyUnicodeEncodeError
PyUnicodeError
PyUnicodeTranslateError
PyUnicodeWarning
PyUnion
PyUserWarning
PyUtf8Str
PyValueError
PyWarning
PyWeak
PyWeakReference: each weakref holds a direct pointer to its referent.
PyWeakProxy
PyZeroDivisionError
PyZip

Enums

IterStatus
Marks status of iterator.

Functions

builtins_iter
builtins_reversed
init
make_union
try_bigint_to_f64
try_f64_to_bigint

Type Aliases

PyBaseExceptionRef
PyBytesRef
PyDictRef
PyIntRef
PyListRef
PyStrInterned
The unique reference of interned PyStr Always intended to be used as a static reference
PyStrRef
PyTupleRef
PyTypeRef
PyUtf8StrInterned
Interned PyUtf8Str — guaranteed UTF-8 at type level. Same layout as PyStrInterned due to #[repr(transparent)] on both PyInterned<T> and PyUtf8Str.
PyUtf8StrRef