SlotFunc

Enum SlotFunc 

pub enum SlotFunc {
Show 34 variants Init(fn(&PyObject, FuncArgs, &VirtualMachine) -> PyResult<()>), Hash(fn(&PyObject, &VirtualMachine) -> PyResult<PyHash>), Str(fn(&PyObject, &VirtualMachine) -> PyResult<PyRef<PyStr>>), Repr(fn(&PyObject, &VirtualMachine) -> PyResult<PyRef<PyStr>>), Iter(fn(PyObjectRef, &VirtualMachine) -> PyResult), IterNext(fn(&PyObject, &VirtualMachine) -> PyResult<PyIterReturn>), Call(fn(&PyObject, FuncArgs, &VirtualMachine) -> PyResult), Del(fn(&PyObject, &VirtualMachine) -> PyResult<()>), GetAttro(fn(&PyObject, &Py<PyStr>, &VirtualMachine) -> PyResult), SetAttro(fn(&PyObject, &Py<PyStr>, PySetterValue, &VirtualMachine) -> PyResult<()>), DelAttro(fn(&PyObject, &Py<PyStr>, PySetterValue, &VirtualMachine) -> PyResult<()>), RichCompare(fn(&PyObject, &PyObject, PyComparisonOp, &VirtualMachine) -> PyResult<Either<PyObjectRef, PyComparisonValue>>, PyComparisonOp), DescrGet(fn(&PyObject, Option<&PyObject>, Option<&PyObject>, &VirtualMachine) -> PyResult), DescrSet(fn(&PyObject, PyObjectRef, PySetterValue, &VirtualMachine) -> PyResult<()>), DescrDel(fn(&PyObject, PyObjectRef, PySetterValue, &VirtualMachine) -> PyResult<()>), SeqLength(fn(PySequence<'_>, &VirtualMachine) -> PyResult<usize>), SeqConcat(fn(PySequence<'_>, &PyObject, &VirtualMachine) -> PyResult), SeqRepeat(fn(PySequence<'_>, isize, &VirtualMachine) -> PyResult), SeqItem(fn(PySequence<'_>, isize, &VirtualMachine) -> PyResult), SeqSetItem(fn(PySequence<'_>, isize, Option<PyObjectRef>, &VirtualMachine) -> PyResult<()>), SeqDelItem(fn(PySequence<'_>, isize, Option<PyObjectRef>, &VirtualMachine) -> PyResult<()>), SeqContains(fn(PySequence<'_>, &PyObject, &VirtualMachine) -> PyResult<bool>), MapLength(fn(PyMapping<'_>, &VirtualMachine) -> PyResult<usize>), MapSubscript(fn(PyMapping<'_>, &PyObject, &VirtualMachine) -> PyResult), MapSetSubscript(fn(PyMapping<'_>, &PyObject, Option<PyObjectRef>, &VirtualMachine) -> PyResult<()>), MapDelSubscript(fn(PyMapping<'_>, &PyObject, Option<PyObjectRef>, &VirtualMachine) -> PyResult<()>), NumBoolean(PyNumberUnaryFunc<bool>), NumUnary(PyNumberUnaryFunc), NumBinary(PyNumberBinaryFunc), NumBinaryRight(PyNumberBinaryFunc), NumTernary(PyNumberTernaryFunc), NumTernaryRight(PyNumberTernaryFunc), GetBuffer(fn(&PyObject, BufferFlags, &VirtualMachine) -> PyResult<PyBuffer>), ReleaseBuffer,
}
Each variant knows how to call the wrapped function with proper types

Variants



Init(fn(&PyObject, FuncArgs, &VirtualMachine) -> PyResult<()>)



Hash(fn(&PyObject, &VirtualMachine) -> PyResult<PyHash>)



Str(fn(&PyObject, &VirtualMachine) -> PyResult<PyRef<PyStr>>)



Repr(fn(&PyObject, &VirtualMachine) -> PyResult<PyRef<PyStr>>)



Iter(fn(PyObjectRef, &VirtualMachine) -> PyResult)



IterNext(fn(&PyObject, &VirtualMachine) -> PyResult<PyIterReturn>)



Call(fn(&PyObject, FuncArgs, &VirtualMachine) -> PyResult)



Del(fn(&PyObject, &VirtualMachine) -> PyResult<()>)



GetAttro(fn(&PyObject, &Py<PyStr>, &VirtualMachine) -> PyResult)



SetAttro(fn(&PyObject, &Py<PyStr>, PySetterValue, &VirtualMachine) -> PyResult<()>)



DelAttro(fn(&PyObject, &Py<PyStr>, PySetterValue, &VirtualMachine) -> PyResult<()>)



RichCompare(fn(&PyObject, &PyObject, PyComparisonOp, &VirtualMachine) -> PyResult<Either<PyObjectRef, PyComparisonValue>>, PyComparisonOp)



DescrGet(fn(&PyObject, Option<&PyObject>, Option<&PyObject>, &VirtualMachine) -> PyResult)



DescrSet(fn(&PyObject, PyObjectRef, PySetterValue, &VirtualMachine) -> PyResult<()>)



DescrDel(fn(&PyObject, PyObjectRef, PySetterValue, &VirtualMachine) -> PyResult<()>)



SeqLength(fn(PySequence<'_>, &VirtualMachine) -> PyResult<usize>)



SeqConcat(fn(PySequence<'_>, &PyObject, &VirtualMachine) -> PyResult)



SeqRepeat(fn(PySequence<'_>, isize, &VirtualMachine) -> PyResult)



SeqItem(fn(PySequence<'_>, isize, &VirtualMachine) -> PyResult)



SeqSetItem(fn(PySequence<'_>, isize, Option<PyObjectRef>, &VirtualMachine) -> PyResult<()>)



SeqDelItem(fn(PySequence<'_>, isize, Option<PyObjectRef>, &VirtualMachine) -> PyResult<()>)



SeqContains(fn(PySequence<'_>, &PyObject, &VirtualMachine) -> PyResult<bool>)



MapLength(fn(PyMapping<'_>, &VirtualMachine) -> PyResult<usize>)



MapSubscript(fn(PyMapping<'_>, &PyObject, &VirtualMachine) -> PyResult)



MapSetSubscript(fn(PyMapping<'_>, &PyObject, Option<PyObjectRef>, &VirtualMachine) -> PyResult<()>)



MapDelSubscript(fn(PyMapping<'_>, &PyObject, Option<PyObjectRef>, &VirtualMachine) -> PyResult<()>)



NumBoolean(PyNumberUnaryFunc<bool>)



NumUnary(PyNumberUnaryFunc)



NumBinary(PyNumberBinaryFunc)



NumBinaryRight(PyNumberBinaryFunc)



NumTernary(PyNumberTernaryFunc)



NumTernaryRight(PyNumberTernaryFunc)



GetBuffer(fn(&PyObject, BufferFlags, &VirtualMachine) -> PyResult<PyBuffer>)



ReleaseBuffer

Implementations

Source

impl SlotFunc

pub fn call( &self, obj: PyObjectRef, args: FuncArgs, vm: &VirtualMachine, ) -> PyResult

Call the wrapped slot function with proper type handling