pub struct PyBaseObject;Expand description
object()
The base class of the class hierarchy.
When called, it accepts no arguments and returns a new featureless instance that has no instance attributes and cannot be given any.
Implementations
Sourceimpl PyBaseObject
impl PyBaseObject
pub fn __dir__(obj: PyObjectRef, vm: &VirtualMachine) -> PyResult<PyList>