pub struct PyOSError { /* private fields */ }Trait Implementations
Sourceimpl Constructor for PyOSError
impl Constructor for PyOSError
type Args = FuncArgs
Sourcefn py_new(
_cls: &Py<PyType>,
args: FuncArgs,
vm: &VirtualMachine,
) -> PyResult<Self>
fn py_new( _cls: &Py<PyType>, args: FuncArgs, vm: &VirtualMachine, ) -> PyResult<Self>
Creates the payload for this type. In most cases, just implement this method
and let the default
slot_new handle wrapping with the correct type.Sourcefn slot_new(cls: PyTypeRef, args: FuncArgs, vm: &VirtualMachine) -> PyResult
fn slot_new(cls: PyTypeRef, args: FuncArgs, vm: &VirtualMachine) -> PyResult
The type slot for
__new__. Override this only when you need special
behavior beyond simple payload creation.const __OWN_METHOD_DEFS: &'static [PyMethodDef] = _
fn __extend_py_class(ctx: &'static Context, class: &'static Py<PyType>)
fn __extend_slots(slots: &mut PyTypeSlots)
Sourceimpl Initializer for PyOSError
impl Initializer for PyOSError
type Args = FuncArgs
fn slot_init( zelf: PyObjectRef, args: FuncArgs, vm: &VirtualMachine, ) -> PyResult<()>
fn init( _zelf: PyRef<Self>, _args: Self::Args, _vm: &VirtualMachine, ) -> PyResult<()>
const __OWN_METHOD_DEFS: &'static [PyMethodDef] = _
fn __extend_py_class(ctx: &'static Context, class: &'static Py<PyType>)
fn __extend_slots(slots: &mut PyTypeSlots)
Sourceimpl MaybeTraverse for PyOSError
impl MaybeTraverse for PyOSError
Sourceconst HAS_TRAVERSE: bool = false
const HAS_TRAVERSE: bool = false
if is traceable, will be used by vtable to determine
Sourceconst HAS_CLEAR: bool = false
const HAS_CLEAR: bool = false
if has clear implementation for circular reference resolution (tp_clear)
fn try_traverse(&self, tracer_fn: &mut TraverseFn<'_>)
fn try_clear(&mut self, out: &mut Vec<PyObjectRef>)
Sourceimpl PyClassDef for PyOSError
impl PyClassDef for PyOSError
const NAME: &'static str = "OSError"
const MODULE_NAME: Option<&'static str> = None
const TP_NAME: &'static str = "OSError"
const DOC: Option<&'static str>
const BASICSIZE: usize
const UNHASHABLE: bool = false
type Base = PyException
const ITEMSIZE: usize = 0
Sourceimpl PyClassImpl for PyOSError
impl PyClassImpl for PyOSError
const TP_FLAGS: PyTypeFlags
const METHOD_DEFS: &'static [PyMethodDef]
fn impl_extend_class(ctx: &'static Context, class: &'static Py<PyType>)
fn extend_slots(slots: &mut PyTypeSlots)
fn extend_class(ctx: &'static Context, class: &'static Py<PyType>)where
Self: Sized,
fn make_static_type() -> PyTypeRefwhere
Self: StaticType + Sized,
fn make_slots() -> PyTypeSlots
Sourceimpl PyPayload for PyOSError
impl PyPayload for PyOSError
const PAYLOAD_TYPE_ID: TypeId = <PyException as ::rustpython_vm::PyPayload>::PAYLOAD_TYPE_ID
fn class(ctx: &Context) -> &'static Py<PyType>
fn try_downcast_from(obj: &PyObject, vm: &VirtualMachine) -> PyResult<()>
Sourceconst HAS_FREELIST: bool = false
const HAS_FREELIST: bool = false
Whether this type has a freelist. Types with freelists require
immediate (non-deferred) GC untracking during dealloc to prevent
race conditions when the object is reused.
Sourceconst MAX_FREELIST: usize = 0
const MAX_FREELIST: usize = 0
Maximum number of objects to keep in the freelist.
Sourceunsafe fn freelist_push(_obj: *mut PyObject) -> bool
unsafe fn freelist_push(_obj: *mut PyObject) -> bool
Try to push a dead object onto this type’s freelist for reuse.
Returns true if the object was stored (caller must NOT free the memory).
Called before tp_clear, so the payload is still intact. Read more
Sourceunsafe fn freelist_pop(_payload: &Self) -> Option<NonNull<PyObject>>
unsafe fn freelist_pop(_payload: &Self) -> Option<NonNull<PyObject>>
Try to pop a pre-allocated object from this type’s freelist.
The returned pointer still has the old payload; the caller must
reinitialize
ref_count, gc_bits, and payload. Read morefn into_pyobject(self, vm: &VirtualMachine) -> PyObjectRefwhere
Self: Debug,
fn _into_ref(self, cls: PyTypeRef, ctx: &Context) -> PyRef<Self>where
Self: Debug,
fn into_exact_ref(self, ctx: &Context) -> PyRefExact<Self>where
Self: Debug,
fn into_ref(self, ctx: &Context) -> PyRef<Self>where
Self: Debug,
fn into_ref_with_type(
self,
vm: &VirtualMachine,
cls: PyTypeRef,
) -> PyResult<PyRef<Self>>where
Self: Debug,
Sourceimpl PySubclass for PyOSError
impl PySubclass for PyOSError
Sourceimpl StaticType for PyOSError
impl StaticType for PyOSError
fn static_cell() -> &'static StaticCell<PyTypeRef>
fn static_baseclass() -> &'static Py<PyType>
fn static_metaclass() -> &'static Py<PyType>
fn static_type() -> &'static Py<PyType>
fn init_manually(typ: PyTypeRef) -> &'static Py<PyType>
fn init_builtin_type() -> &'static Py<PyType>where
Self: PyClassImpl,
fn create_static_type() -> PyTypeRefwhere
Self: PyClassImpl,
Sourceimpl Traverse for PyOSError
impl Traverse for PyOSError
Sourcefn traverse(&self, tracer_fn: &mut TraverseFn<'_>)
fn traverse(&self, tracer_fn: &mut TraverseFn<'_>)
impl
traverse() with caution! Following those guideline so traverse doesn’t cause memory error!: Read moreSourcefn clear(&mut self, _out: &mut Vec<PyObjectRef>)
fn clear(&mut self, _out: &mut Vec<PyObjectRef>)
Extract all owned child PyObjectRefs for circular reference resolution (tp_clear).
Called just before object deallocation to break circular references.
Default implementation does nothing.