PyStr

Struct PyStr 

pub struct PyStr { /* private fields */ }

Implementations

Source

impl PyStr

pub unsafe fn new_ascii_unchecked(bytes: Vec<u8>) -> Self

Safety

Given bytes must be ascii

pub fn new_ref(zelf: impl Into<Self>, ctx: &Context) -> PyRef<Self>

👎Deprecated:

use PyStr::from(…).into_ref() instead

pub const fn as_wtf8(&self) -> &Wtf8

pub const fn as_bytes(&self) -> &[u8] ⓘ

pub fn to_str(&self) -> Option<&str>

pub fn expect_str(&self) -> &str

Returns &str

Panic

If the string contains surrogates.

pub fn contains_nuls(&self) -> bool

Check string bytes for interior NULs.

pub fn to_string_lossy(&self) -> Cow<'_, str>

pub const fn kind(&self) -> StrKind

pub fn as_str_kind(&self) -> PyKindStr<'_>

pub const fn is_utf8(&self) -> bool

pub fn as_utf8(&self) -> Option<&PyUtf8Str>

pub fn try_as_utf8<'a>(&'a self, vm: &VirtualMachine) -> PyResult<&'a PyUtf8Str>

Source

impl PyStr

pub fn byte_len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn char_len(&self) -> usize

pub fn char_index_to_byte(&self, index: usize) -> usize

The byte offset the index-th character starts at, or the string’s byte length if index is at or past its end.

pub fn byte_to_char_index(&self, bytepos: usize) -> usize

The character index of the character starting at byte offset bytepos, which must be a character boundary at or before the end.

pub fn __mod__( &self, values: PyObjectRef, vm: &VirtualMachine, ) -> PyResult<Wtf8Buf>