pub struct PyUnicodeError(/* private fields */);Trait Implementations
Sourceimpl Constructor for PyUnicodeError
impl Constructor for PyUnicodeError
type Args = FuncArgs
Sourcefn slot_new(cls: PyTypeRef, args: FuncArgs, vm: &VirtualMachine) -> PyResult
fn slot_new(cls: PyTypeRef, args: FuncArgs, vm: &VirtualMachine) -> PyResult
The type slot for
__new__. Override this only when you need special
behavior beyond simple payload creation.Sourcefn py_new(
_cls: &Py<PyType>,
_args: Self::Args,
_vm: &VirtualMachine,
) -> PyResult<Self>
fn py_new( _cls: &Py<PyType>, _args: Self::Args, _vm: &VirtualMachine, ) -> PyResult<Self>
Creates the payload for this type. In most cases, just implement this method
and let the default
slot_new handle wrapping with the correct type.const __OWN_METHOD_DEFS: &'static [PyMethodDef] = _
fn __extend_py_class(ctx: &'static Context, class: &'static Py<PyType>)
fn __extend_slots(slots: &mut PyTypeSlots)
Sourceimpl Debug for PyUnicodeError
impl Debug for PyUnicodeError
Sourceimpl MaybeTraverse for PyUnicodeError
impl MaybeTraverse for PyUnicodeError
Sourceconst HAS_TRAVERSE: bool = false
const HAS_TRAVERSE: bool = false
if is traceable, will be used by vtable to determine
Sourceconst HAS_CLEAR: bool = false
const HAS_CLEAR: bool = false
if has clear implementation for circular reference resolution (tp_clear)
fn try_traverse(&self, tracer_fn: &mut TraverseFn<'_>)
fn try_clear(&mut self, out: &mut Vec<PyObjectRef>)
Sourceimpl PyClassDef for PyUnicodeError
impl PyClassDef for PyUnicodeError
const NAME: &'static str = "UnicodeError"
const MODULE_NAME: Option<&'static str> = None
const TP_NAME: &'static str = "UnicodeError"
const DOC: Option<&'static str>
const BASICSIZE: usize = 0
const UNHASHABLE: bool = false
type Base = PyValueError
const ITEMSIZE: usize = 0
Sourceimpl PyClassImpl for PyUnicodeError
impl PyClassImpl for PyUnicodeError
const TP_FLAGS: PyTypeFlags
const METHOD_DEFS: &'static [PyMethodDef]
fn impl_extend_class(ctx: &'static Context, class: &'static Py<PyType>)
fn extend_slots(slots: &mut PyTypeSlots)
fn extend_class(ctx: &'static Context, class: &'static Py<PyType>)where
Self: Sized,
fn make_static_type() -> PyTypeRefwhere
Self: StaticType + Sized,
fn make_slots() -> PyTypeSlots
Sourceimpl PyPayload for PyUnicodeError
impl PyPayload for PyUnicodeError
const PAYLOAD_TYPE_ID: TypeId = <PyValueError as ::rustpython_vm::PyPayload>::PAYLOAD_TYPE_ID
fn class(ctx: &Context) -> &'static Py<PyType>
fn try_downcast_from(obj: &PyObject, vm: &VirtualMachine) -> PyResult<()>
Sourceconst HAS_FREELIST: bool = false
const HAS_FREELIST: bool = false
Whether this type has a freelist. Types with freelists require
immediate (non-deferred) GC untracking during dealloc to prevent
race conditions when the object is reused.
Sourceconst MAX_FREELIST: usize = 0
const MAX_FREELIST: usize = 0
Maximum number of objects to keep in the freelist.
Sourceunsafe fn freelist_push(_obj: *mut PyObject) -> bool
unsafe fn freelist_push(_obj: *mut PyObject) -> bool
Try to push a dead object onto this type’s freelist for reuse.
Returns true if the object was stored (caller must NOT free the memory).
Called before tp_clear, so the payload is still intact. Read more
Sourceunsafe fn freelist_pop(_payload: &Self) -> Option<NonNull<PyObject>>
unsafe fn freelist_pop(_payload: &Self) -> Option<NonNull<PyObject>>
Try to pop a pre-allocated object from this type’s freelist.
The returned pointer still has the old payload; the caller must
reinitialize
ref_count, gc_bits, and payload. Read morefn into_pyobject(self, vm: &VirtualMachine) -> PyObjectRefwhere
Self: Debug,
fn _into_ref(self, cls: PyTypeRef, ctx: &Context) -> PyRef<Self>where
Self: Debug,
fn into_exact_ref(self, ctx: &Context) -> PyRefExact<Self>where
Self: Debug,
fn into_ref(self, ctx: &Context) -> PyRef<Self>where
Self: Debug,
fn into_ref_with_type(
self,
vm: &VirtualMachine,
cls: PyTypeRef,
) -> PyResult<PyRef<Self>>where
Self: Debug,
Sourceimpl PySubclass for PyUnicodeError
impl PySubclass for PyUnicodeError
Sourceimpl StaticType for PyUnicodeError
impl StaticType for PyUnicodeError
fn static_cell() -> &'static StaticCell<PyTypeRef>
fn static_baseclass() -> &'static Py<PyType>
fn static_metaclass() -> &'static Py<PyType>
fn static_type() -> &'static Py<PyType>
fn init_manually(typ: PyTypeRef) -> &'static Py<PyType>
fn init_builtin_type() -> &'static Py<PyType>where
Self: PyClassImpl,
fn create_static_type() -> PyTypeRefwhere
Self: PyClassImpl,