pub enum AnyOpcode {
Real(Opcode),
Pseudo(PseudoOpcode),
}Variants
Real(Opcode)
Pseudo(PseudoOpcode)
Implementations
Sourceimpl AnyOpcode
impl AnyOpcode
Sourcepub const fn real(self) -> Option<Opcode>
pub const fn real(self) -> Option<Opcode>
Gets the inner value of Self::Real.
Sourcepub const fn pseudo(self) -> Option<PseudoOpcode>
pub const fn pseudo(self) -> Option<PseudoOpcode>
Gets the inner value of Self::Pseudo.
Sourcepub const fn expect_real(self) -> Opcode
pub const fn expect_real(self) -> Opcode
Same as Self::real but panics if wasn’t called on Self::Real.
Panics
If was called on something else other than Self::Real.
Sourcepub const fn expect_pseudo(self) -> PseudoOpcode
pub const fn expect_pseudo(self) -> PseudoOpcode
Same as Self::pseudo but panics if wasn’t called on Self::Pseudo.
Panics
If was called on something else other than Self::Pseudo.
pub const fn has_arg(&self) -> bool
pub const fn has_jump(&self) -> bool
pub const fn has_free(&self) -> bool
pub const fn has_local(&self) -> bool
pub const fn has_name(&self) -> bool
pub const fn has_const(&self) -> bool
pub const fn is_instrumented(&self) -> bool
pub const fn is_block_push(&self) -> bool
pub fn stack_effect_jump(&self, oparg: u32) -> i32
pub fn stack_effect(&self, oparg: u32) -> i32
pub const fn deopt(&self) -> Option<AnyOpcode>