pub enum BinaryOperator {
Show 27 variants
Add,
And,
FloorDivide,
Lshift,
MatrixMultiply,
Multiply,
Remainder,
Or,
Power,
Rshift,
Subtract,
TrueDivide,
Xor,
InplaceAdd,
InplaceAnd,
InplaceFloorDivide,
InplaceLshift,
InplaceMatrixMultiply,
InplaceMultiply,
InplaceRemainder,
InplaceOr,
InplacePower,
InplaceRshift,
InplaceSubtract,
InplaceTrueDivide,
InplaceXor,
Subscr,
}Expand description
The possible Binary operators
Examples
use rustpython_compiler_core::bytecode::{Arg, BinaryOperator, Instruction};
let (op, _) = Arg::new(BinaryOperator::Add);
let instruction = Instruction::BinaryOp { op };See also:
Variants
Add
+
And
&
FloorDivide
//
Lshift
<<
MatrixMultiply
@
Multiply
*
Remainder
%
Or
|
Power
**
Rshift
>>
Subtract
-
TrueDivide
/
Xor
^
InplaceAdd
+=
InplaceAnd
&=
InplaceFloorDivide
//=
InplaceLshift
<<=
InplaceMatrixMultiply
@=
InplaceMultiply
*=
InplaceRemainder
%=
InplaceOr
|=
InplacePower
**=
InplaceRshift
>>=
InplaceSubtract
-=
InplaceTrueDivide
/=
InplaceXor
^=
Subscr
[] subscript
Implementations
Sourceimpl BinaryOperator
impl BinaryOperator
Sourcepub const fn as_inplace(self) -> BinaryOperator
pub const fn as_inplace(self) -> BinaryOperator
Get the “inplace” version of the operator.
This has no effect if self is already an “inplace” operator.
Example
use rustpython_compiler_core::bytecode::BinaryOperator;
assert_eq!(BinaryOperator::Power.as_inplace(), BinaryOperator::InplacePower);
assert_eq!(BinaryOperator::InplaceSubtract.as_inplace(), BinaryOperator::InplaceSubtract);Trait Implementations
Sourceimpl Clone for BinaryOperator
impl Clone for BinaryOperator
Sourcefn clone(&self) -> BinaryOperator
fn clone(&self) -> BinaryOperator
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BinaryOperator
impl Debug for BinaryOperator
Sourceimpl Display for BinaryOperator
impl Display for BinaryOperator
Sourceimpl PartialEq for BinaryOperator
impl PartialEq for BinaryOperator
Sourceimpl TryFrom<u32> for BinaryOperator
impl TryFrom<u32> for BinaryOperator
Sourcetype Error = MarshalError
type Error = MarshalError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: u32,
) -> Result<BinaryOperator, <BinaryOperator as TryFrom<u32>>::Error>
fn try_from( value: u32, ) -> Result<BinaryOperator, <BinaryOperator as TryFrom<u32>>::Error>
Performs the conversion.
Sourceimpl TryFrom<u8> for BinaryOperator
impl TryFrom<u8> for BinaryOperator
Sourcetype Error = MarshalError
type Error = MarshalError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: u8,
) -> Result<BinaryOperator, <BinaryOperator as TryFrom<u8>>::Error>
fn try_from( value: u8, ) -> Result<BinaryOperator, <BinaryOperator as TryFrom<u8>>::Error>
Performs the conversion.
impl Copy for BinaryOperator
impl Eq for BinaryOperator
impl OpArgType for BinaryOperator
impl StructuralPartialEq for BinaryOperator