Module oparg

Module oparg 

Structs

ConstIdx
Label
LoadAttr
LoadSuperAttr
MakeFunctionFlags
OpArg
Full 32-bit op_arg, including any possible ExtendedArg extension.
OpArgByte
Opcode argument that may be extended by a prior ExtendedArg.
OpArgState
ResumeContext
Context for Instruction::Resume.
UnpackExArgs
VarNum
VarNums

Enums

BinaryOperator
The possible Binary operators
BuildSliceArgCount
Specifies if a slice is built with either 2 or 3 arguments.
CommonConstant
Common constants for LOAD_COMMON_CONSTANT opcode. pycore_opcode_utils.h CONSTANT_*
ComparisonOperator
COMPARE_OP arg is (cmp_index << 5) | mask. Only the upper 3 bits identify the comparison; the lower 5 bits are an inline cache mask for adaptive specialization.
ConvertValueOparg
Oparg values for Instruction::ConvertValue.
IntrinsicFunction1
Intrinsic function for CALL_INTRINSIC_1
IntrinsicFunction2
Intrinsic function for CALL_INTRINSIC_2
Invert
Whether or not to invert the operation.
MakeFunctionFlag
SET_FUNCTION_ATTRIBUTE flags. Bitmask: Defaults=0x01, KwOnly=0x02, Annotations=0x04, Closure=0x08, TypeParams=0x10, Annotate=0x20. Stored as bit position (0-5) by bitflag! macro.
RaiseKind
The kind of Raise that occurred.
ResumeLocation
SpecialMethod
Special method for LOAD_SPECIAL opcode (context managers).

Traits

OpArgType

Type Aliases

NameIdx