pub enum ConvertValueOparg {
None,
Str,
Repr,
Ascii,
}Expand description
Variants
None
No conversion.
f"{x}"
f"{x:4}"Str
Converts by calling str(<value>).
f"{x!s}"
f"{x!s:2}"Repr
Converts by calling repr(<value>).
f"{x!r}"
f"{x!r:2}"Ascii
Converts by calling ascii(<value>).
f"{x!a}"
f"{x!a:2}"Trait Implementations
Sourceimpl Clone for ConvertValueOparg
impl Clone for ConvertValueOparg
Sourcefn clone(&self) -> ConvertValueOparg
fn clone(&self) -> ConvertValueOparg
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConvertValueOparg
impl Debug for ConvertValueOparg
Sourceimpl Display for ConvertValueOparg
impl Display for ConvertValueOparg
Sourceimpl Hash for ConvertValueOparg
impl Hash for ConvertValueOparg
Sourceimpl PartialEq for ConvertValueOparg
impl PartialEq for ConvertValueOparg
Sourceimpl TryFrom<u32> for ConvertValueOparg
impl TryFrom<u32> for ConvertValueOparg
Sourcetype Error = MarshalError
type Error = MarshalError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: u32,
) -> Result<ConvertValueOparg, <ConvertValueOparg as TryFrom<u32>>::Error>
fn try_from( value: u32, ) -> Result<ConvertValueOparg, <ConvertValueOparg as TryFrom<u32>>::Error>
Performs the conversion.
Sourceimpl TryFrom<u8> for ConvertValueOparg
impl TryFrom<u8> for ConvertValueOparg
Sourcetype Error = MarshalError
type Error = MarshalError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: u8,
) -> Result<ConvertValueOparg, <ConvertValueOparg as TryFrom<u8>>::Error>
fn try_from( value: u8, ) -> Result<ConvertValueOparg, <ConvertValueOparg as TryFrom<u8>>::Error>
Performs the conversion.
impl Copy for ConvertValueOparg
impl Eq for ConvertValueOparg
impl OpArgType for ConvertValueOparg
impl StructuralPartialEq for ConvertValueOparg