pub struct CodeFlags(/* private fields */);Implementations
Sourceimpl CodeFlags
impl CodeFlags
pub const OPTIMIZED: CodeFlags
pub const NEWLOCALS: CodeFlags
pub const VARARGS: CodeFlags
pub const VARKEYWORDS: CodeFlags
pub const NESTED: CodeFlags
pub const GENERATOR: CodeFlags
pub const COROUTINE: CodeFlags
pub const ITERABLE_COROUTINE: CodeFlags
pub const ASYNC_GENERATOR: CodeFlags
pub const FUTURE_DIVISION: CodeFlags
pub const FUTURE_ABSOLUTE_IMPORT: CodeFlags
pub const FUTURE_WITH_STATEMENT: CodeFlags
pub const FUTURE_PRINT_FUNCTION: CodeFlags
pub const FUTURE_UNICODE_LITERALS: CodeFlags
pub const FUTURE_BARRY_AS_BDFL: CodeFlags
pub const FUTURE_GENERATOR_STOP: CodeFlags
pub const FUTURE_ANNOTATIONS: CodeFlags
Sourcepub const HAS_DOCSTRING: CodeFlags
pub const HAS_DOCSTRING: CodeFlags
If a code object represents a function and has a docstring, this bit is set and the first item in co_consts is the docstring.
pub const METHOD: CodeFlags
Sourceimpl CodeFlags
impl CodeFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<CodeFlags>
pub const fn from_bits(bits: u32) -> Option<CodeFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> CodeFlags
pub const fn from_bits_truncate(bits: u32) -> CodeFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> CodeFlags
pub const fn from_bits_retain(bits: u32) -> CodeFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CodeFlags>
pub fn from_name(name: &str) -> Option<CodeFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CodeFlags) -> bool
pub const fn intersects(&self, other: CodeFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: CodeFlags) -> bool
pub const fn contains(&self, other: CodeFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: CodeFlags)
pub fn remove(&mut self, other: CodeFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CodeFlags)
pub fn toggle(&mut self, other: CodeFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: CodeFlags, value: bool)
pub fn set(&mut self, other: CodeFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CodeFlags) -> CodeFlags
pub const fn intersection(self, other: CodeFlags) -> CodeFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: CodeFlags) -> CodeFlags
pub const fn union(self, other: CodeFlags) -> CodeFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: CodeFlags) -> CodeFlags
pub const fn difference(self, other: CodeFlags) -> CodeFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: CodeFlags) -> CodeFlags
pub const fn symmetric_difference(self, other: CodeFlags) -> CodeFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> CodeFlags
pub const fn complement(self) -> CodeFlags
The bitwise negation (!) of the bits in self, truncating the result.