AnyRootNodeRef

Enum AnyRootNodeRef 

pub enum AnyRootNodeRef<'a> {
Show 27 variants Mod(&'a Mod), Stmt(&'a Stmt), Expr(&'a Expr), ExceptHandler(&'a ExceptHandler), InterpolatedStringElement(&'a InterpolatedStringElement), Pattern(&'a Pattern), TypeParam(&'a TypeParam), InterpolatedStringFormatSpec(&'a InterpolatedStringFormatSpec), PatternArguments(&'a PatternArguments), PatternKeyword(&'a PatternKeyword), Comprehension(&'a Comprehension), Arguments(&'a Arguments), Parameters(&'a Parameters), Parameter(&'a Parameter), ParameterWithDefault(&'a ParameterWithDefault), Keyword(&'a Keyword), Alias(&'a Alias), WithItem(&'a WithItem), MatchCase(&'a MatchCase), Decorator(&'a Decorator), ElifElseClause(&'a ElifElseClause), TypeParams(&'a TypeParams), FString(&'a FString), TString(&'a TString), StringLiteral(&'a StringLiteral), BytesLiteral(&'a BytesLiteral), Identifier(&'a Identifier),
}
An enumeration of all AST nodes.

Unlike AnyNodeRef, this type does not flatten nested enums, so its variants only consist of the “root” AST node types. This is useful as it exposes references to the original enums, not just references to their inner values.

For example, AnyRootNodeRef::Mod contains a reference to the Mod enum, while AnyNodeRef has top-level AnyNodeRef::ModModule and AnyNodeRef::ModExpression variants.

Variants



Mod(&'a Mod)



Stmt(&'a Stmt)



Expr(&'a Expr)



ExceptHandler(&'a ExceptHandler)



InterpolatedStringElement(&'a InterpolatedStringElement)



Pattern(&'a Pattern)



TypeParam(&'a TypeParam)



InterpolatedStringFormatSpec(&'a InterpolatedStringFormatSpec)



PatternArguments(&'a PatternArguments)



PatternKeyword(&'a PatternKeyword)



Comprehension(&'a Comprehension)



Arguments(&'a Arguments)



Parameters(&'a Parameters)



Parameter(&'a Parameter)



ParameterWithDefault(&'a ParameterWithDefault)



Keyword(&'a Keyword)



Alias(&'a Alias)



WithItem(&'a WithItem)



MatchCase(&'a MatchCase)



Decorator(&'a Decorator)



ElifElseClause(&'a ElifElseClause)



TypeParams(&'a TypeParams)



FString(&'a FString)



TString(&'a TString)



StringLiteral(&'a StringLiteral)



BytesLiteral(&'a BytesLiteral)



Identifier(&'a Identifier)

Implementations

Source

impl<'a> AnyRootNodeRef<'a>

pub fn visit_source_order<'b, V>(self, visitor: &mut V)
where 'a: 'b, V: SourceOrderVisitor<'b> + ?Sized,