ExprRef

Enum ExprRef 

pub enum ExprRef<'a> {
Show 34 variants BoolOp(&'a ExprBoolOp), Named(&'a ExprNamed), BinOp(&'a ExprBinOp), UnaryOp(&'a ExprUnaryOp), Lambda(&'a ExprLambda), If(&'a ExprIf), Dict(&'a ExprDict), Set(&'a ExprSet), ListComp(&'a ExprListComp), SetComp(&'a ExprSetComp), DictComp(&'a ExprDictComp), Generator(&'a ExprGenerator), Await(&'a ExprAwait), Yield(&'a ExprYield), YieldFrom(&'a ExprYieldFrom), Compare(&'a ExprCompare), Call(&'a ExprCall), FString(&'a ExprFString), TString(&'a ExprTString), StringLiteral(&'a ExprStringLiteral), BytesLiteral(&'a ExprBytesLiteral), NumberLiteral(&'a ExprNumberLiteral), BooleanLiteral(&'a ExprBooleanLiteral), NoneLiteral(&'a ExprNoneLiteral), EllipsisLiteral(&'a ExprEllipsisLiteral), Constant(&'a ExprConstant), Attribute(&'a ExprAttribute), Subscript(&'a ExprSubscript), Starred(&'a ExprStarred), Name(&'a ExprName), List(&'a ExprList), Tuple(&'a ExprTuple), Slice(&'a ExprSlice), IpyEscapeCommand(&'a ExprIpyEscapeCommand),
}
See also expr

Variants



BoolOp(&'a ExprBoolOp)



Named(&'a ExprNamed)



BinOp(&'a ExprBinOp)



UnaryOp(&'a ExprUnaryOp)



Lambda(&'a ExprLambda)



If(&'a ExprIf)



Dict(&'a ExprDict)



Set(&'a ExprSet)



ListComp(&'a ExprListComp)



SetComp(&'a ExprSetComp)



DictComp(&'a ExprDictComp)



Generator(&'a ExprGenerator)



Await(&'a ExprAwait)



Yield(&'a ExprYield)



YieldFrom(&'a ExprYieldFrom)



Compare(&'a ExprCompare)



Call(&'a ExprCall)



FString(&'a ExprFString)



TString(&'a ExprTString)



StringLiteral(&'a ExprStringLiteral)



BytesLiteral(&'a ExprBytesLiteral)



NumberLiteral(&'a ExprNumberLiteral)



BooleanLiteral(&'a ExprBooleanLiteral)



NoneLiteral(&'a ExprNoneLiteral)



EllipsisLiteral(&'a ExprEllipsisLiteral)



Constant(&'a ExprConstant)



Attribute(&'a ExprAttribute)



Subscript(&'a ExprSubscript)



Starred(&'a ExprStarred)



Name(&'a ExprName)



List(&'a ExprList)



Tuple(&'a ExprTuple)



Slice(&'a ExprSlice)



IpyEscapeCommand(&'a ExprIpyEscapeCommand)

Implementations

Source

impl<'a> ExprRef<'a>

pub const fn is_bool_op_expr(&self) -> bool

Returns true if self is of variant BoolOp.

pub fn as_bool_op_expr(&self) -> Option<&&'a ExprBoolOp>

Returns Some if self is a reference of variant BoolOp, and None otherwise.

pub fn as_mut_bool_op_expr(&mut self) -> Option<&mut &'a ExprBoolOp>

Returns Some if self is a mutable reference of variant BoolOp, and None otherwise.

pub fn expect_bool_op_expr(self) -> &'a ExprBoolOp
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of BoolOp.

Panics

Panics if the value is not BoolOp. In debug builds the panic message includes the content of self.

pub fn bool_op_expr(self) -> Option<&'a ExprBoolOp>

Returns Some if self is of variant BoolOp, and None otherwise.

pub const fn is_named_expr(&self) -> bool

Returns true if self is of variant Named.

pub fn as_named_expr(&self) -> Option<&&'a ExprNamed>

Returns Some if self is a reference of variant Named, and None otherwise.

pub fn as_mut_named_expr(&mut self) -> Option<&mut &'a ExprNamed>

Returns Some if self is a mutable reference of variant Named, and None otherwise.

pub fn expect_named_expr(self) -> &'a ExprNamed
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Named.

Panics

Panics if the value is not Named. In debug builds the panic message includes the content of self.

pub fn named_expr(self) -> Option<&'a ExprNamed>

Returns Some if self is of variant Named, and None otherwise.

pub const fn is_bin_op_expr(&self) -> bool

Returns true if self is of variant BinOp.

pub fn as_bin_op_expr(&self) -> Option<&&'a ExprBinOp>

Returns Some if self is a reference of variant BinOp, and None otherwise.

pub fn as_mut_bin_op_expr(&mut self) -> Option<&mut &'a ExprBinOp>

Returns Some if self is a mutable reference of variant BinOp, and None otherwise.

pub fn expect_bin_op_expr(self) -> &'a ExprBinOp
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of BinOp.

Panics

Panics if the value is not BinOp. In debug builds the panic message includes the content of self.

pub fn bin_op_expr(self) -> Option<&'a ExprBinOp>

Returns Some if self is of variant BinOp, and None otherwise.

pub const fn is_unary_op_expr(&self) -> bool

Returns true if self is of variant UnaryOp.

pub fn as_unary_op_expr(&self) -> Option<&&'a ExprUnaryOp>

Returns Some if self is a reference of variant UnaryOp, and None otherwise.

pub fn as_mut_unary_op_expr(&mut self) -> Option<&mut &'a ExprUnaryOp>

Returns Some if self is a mutable reference of variant UnaryOp, and None otherwise.

pub fn expect_unary_op_expr(self) -> &'a ExprUnaryOp
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of UnaryOp.

Panics

Panics if the value is not UnaryOp. In debug builds the panic message includes the content of self.

pub fn unary_op_expr(self) -> Option<&'a ExprUnaryOp>

Returns Some if self is of variant UnaryOp, and None otherwise.

pub const fn is_lambda_expr(&self) -> bool

Returns true if self is of variant Lambda.

pub fn as_lambda_expr(&self) -> Option<&&'a ExprLambda>

Returns Some if self is a reference of variant Lambda, and None otherwise.

pub fn as_mut_lambda_expr(&mut self) -> Option<&mut &'a ExprLambda>

Returns Some if self is a mutable reference of variant Lambda, and None otherwise.

pub fn expect_lambda_expr(self) -> &'a ExprLambda
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Lambda.

Panics

Panics if the value is not Lambda. In debug builds the panic message includes the content of self.

pub fn lambda_expr(self) -> Option<&'a ExprLambda>

Returns Some if self is of variant Lambda, and None otherwise.

pub const fn is_if_expr(&self) -> bool

Returns true if self is of variant If.

pub fn as_if_expr(&self) -> Option<&&'a ExprIf>

Returns Some if self is a reference of variant If, and None otherwise.

pub fn as_mut_if_expr(&mut self) -> Option<&mut &'a ExprIf>

Returns Some if self is a mutable reference of variant If, and None otherwise.

pub fn expect_if_expr(self) -> &'a ExprIf
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of If.

Panics

Panics if the value is not If. In debug builds the panic message includes the content of self.

pub fn if_expr(self) -> Option<&'a ExprIf>

Returns Some if self is of variant If, and None otherwise.

pub const fn is_dict_expr(&self) -> bool

Returns true if self is of variant Dict.

pub fn as_dict_expr(&self) -> Option<&&'a ExprDict>

Returns Some if self is a reference of variant Dict, and None otherwise.

pub fn as_mut_dict_expr(&mut self) -> Option<&mut &'a ExprDict>

Returns Some if self is a mutable reference of variant Dict, and None otherwise.

pub fn expect_dict_expr(self) -> &'a ExprDict
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Dict.

Panics

Panics if the value is not Dict. In debug builds the panic message includes the content of self.

pub fn dict_expr(self) -> Option<&'a ExprDict>

Returns Some if self is of variant Dict, and None otherwise.

pub const fn is_set_expr(&self) -> bool

Returns true if self is of variant Set.

pub fn as_set_expr(&self) -> Option<&&'a ExprSet>

Returns Some if self is a reference of variant Set, and None otherwise.

pub fn as_mut_set_expr(&mut self) -> Option<&mut &'a ExprSet>

Returns Some if self is a mutable reference of variant Set, and None otherwise.

pub fn expect_set_expr(self) -> &'a ExprSet
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Set.

Panics

Panics if the value is not Set. In debug builds the panic message includes the content of self.

pub fn set_expr(self) -> Option<&'a ExprSet>

Returns Some if self is of variant Set, and None otherwise.

pub const fn is_list_comp_expr(&self) -> bool

Returns true if self is of variant ListComp.

pub fn as_list_comp_expr(&self) -> Option<&&'a ExprListComp>

Returns Some if self is a reference of variant ListComp, and None otherwise.

pub fn as_mut_list_comp_expr(&mut self) -> Option<&mut &'a ExprListComp>

Returns Some if self is a mutable reference of variant ListComp, and None otherwise.

pub fn expect_list_comp_expr(self) -> &'a ExprListComp
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of ListComp.

Panics

Panics if the value is not ListComp. In debug builds the panic message includes the content of self.

pub fn list_comp_expr(self) -> Option<&'a ExprListComp>

Returns Some if self is of variant ListComp, and None otherwise.

pub const fn is_set_comp_expr(&self) -> bool

Returns true if self is of variant SetComp.

pub fn as_set_comp_expr(&self) -> Option<&&'a ExprSetComp>

Returns Some if self is a reference of variant SetComp, and None otherwise.

pub fn as_mut_set_comp_expr(&mut self) -> Option<&mut &'a ExprSetComp>

Returns Some if self is a mutable reference of variant SetComp, and None otherwise.

pub fn expect_set_comp_expr(self) -> &'a ExprSetComp
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of SetComp.

Panics

Panics if the value is not SetComp. In debug builds the panic message includes the content of self.

pub fn set_comp_expr(self) -> Option<&'a ExprSetComp>

Returns Some if self is of variant SetComp, and None otherwise.

pub const fn is_dict_comp_expr(&self) -> bool

Returns true if self is of variant DictComp.

pub fn as_dict_comp_expr(&self) -> Option<&&'a ExprDictComp>

Returns Some if self is a reference of variant DictComp, and None otherwise.

pub fn as_mut_dict_comp_expr(&mut self) -> Option<&mut &'a ExprDictComp>

Returns Some if self is a mutable reference of variant DictComp, and None otherwise.

pub fn expect_dict_comp_expr(self) -> &'a ExprDictComp
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of DictComp.

Panics

Panics if the value is not DictComp. In debug builds the panic message includes the content of self.

pub fn dict_comp_expr(self) -> Option<&'a ExprDictComp>

Returns Some if self is of variant DictComp, and None otherwise.

pub const fn is_generator_expr(&self) -> bool

Returns true if self is of variant Generator.

pub fn as_generator_expr(&self) -> Option<&&'a ExprGenerator>

Returns Some if self is a reference of variant Generator, and None otherwise.

pub fn as_mut_generator_expr(&mut self) -> Option<&mut &'a ExprGenerator>

Returns Some if self is a mutable reference of variant Generator, and None otherwise.

pub fn expect_generator_expr(self) -> &'a ExprGenerator
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Generator.

Panics

Panics if the value is not Generator. In debug builds the panic message includes the content of self.

pub fn generator_expr(self) -> Option<&'a ExprGenerator>

Returns Some if self is of variant Generator, and None otherwise.

pub const fn is_await_expr(&self) -> bool

Returns true if self is of variant Await.

pub fn as_await_expr(&self) -> Option<&&'a ExprAwait>

Returns Some if self is a reference of variant Await, and None otherwise.

pub fn as_mut_await_expr(&mut self) -> Option<&mut &'a ExprAwait>

Returns Some if self is a mutable reference of variant Await, and None otherwise.

pub fn expect_await_expr(self) -> &'a ExprAwait
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Await.

Panics

Panics if the value is not Await. In debug builds the panic message includes the content of self.

pub fn await_expr(self) -> Option<&'a ExprAwait>

Returns Some if self is of variant Await, and None otherwise.

pub const fn is_yield_expr(&self) -> bool

Returns true if self is of variant Yield.

pub fn as_yield_expr(&self) -> Option<&&'a ExprYield>

Returns Some if self is a reference of variant Yield, and None otherwise.

pub fn as_mut_yield_expr(&mut self) -> Option<&mut &'a ExprYield>

Returns Some if self is a mutable reference of variant Yield, and None otherwise.

pub fn expect_yield_expr(self) -> &'a ExprYield
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Yield.

Panics

Panics if the value is not Yield. In debug builds the panic message includes the content of self.

pub fn yield_expr(self) -> Option<&'a ExprYield>

Returns Some if self is of variant Yield, and None otherwise.

pub const fn is_yield_from_expr(&self) -> bool

Returns true if self is of variant YieldFrom.

pub fn as_yield_from_expr(&self) -> Option<&&'a ExprYieldFrom>

Returns Some if self is a reference of variant YieldFrom, and None otherwise.

pub fn as_mut_yield_from_expr(&mut self) -> Option<&mut &'a ExprYieldFrom>

Returns Some if self is a mutable reference of variant YieldFrom, and None otherwise.

pub fn expect_yield_from_expr(self) -> &'a ExprYieldFrom
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of YieldFrom.

Panics

Panics if the value is not YieldFrom. In debug builds the panic message includes the content of self.

pub fn yield_from_expr(self) -> Option<&'a ExprYieldFrom>

Returns Some if self is of variant YieldFrom, and None otherwise.

pub const fn is_compare_expr(&self) -> bool

Returns true if self is of variant Compare.

pub fn as_compare_expr(&self) -> Option<&&'a ExprCompare>

Returns Some if self is a reference of variant Compare, and None otherwise.

pub fn as_mut_compare_expr(&mut self) -> Option<&mut &'a ExprCompare>

Returns Some if self is a mutable reference of variant Compare, and None otherwise.

pub fn expect_compare_expr(self) -> &'a ExprCompare
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Compare.

Panics

Panics if the value is not Compare. In debug builds the panic message includes the content of self.

pub fn compare_expr(self) -> Option<&'a ExprCompare>

Returns Some if self is of variant Compare, and None otherwise.

pub const fn is_call_expr(&self) -> bool

Returns true if self is of variant Call.

pub fn as_call_expr(&self) -> Option<&&'a ExprCall>

Returns Some if self is a reference of variant Call, and None otherwise.

pub fn as_mut_call_expr(&mut self) -> Option<&mut &'a ExprCall>

Returns Some if self is a mutable reference of variant Call, and None otherwise.

pub fn expect_call_expr(self) -> &'a ExprCall
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Call.

Panics

Panics if the value is not Call. In debug builds the panic message includes the content of self.

pub fn call_expr(self) -> Option<&'a ExprCall>

Returns Some if self is of variant Call, and None otherwise.

pub const fn is_f_string_expr(&self) -> bool

Returns true if self is of variant FString.

pub fn as_f_string_expr(&self) -> Option<&&'a ExprFString>

Returns Some if self is a reference of variant FString, and None otherwise.

pub fn as_mut_f_string_expr(&mut self) -> Option<&mut &'a ExprFString>

Returns Some if self is a mutable reference of variant FString, and None otherwise.

pub fn expect_f_string_expr(self) -> &'a ExprFString
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of FString.

Panics

Panics if the value is not FString. In debug builds the panic message includes the content of self.

pub fn f_string_expr(self) -> Option<&'a ExprFString>

Returns Some if self is of variant FString, and None otherwise.

pub const fn is_t_string_expr(&self) -> bool

Returns true if self is of variant TString.

pub fn as_t_string_expr(&self) -> Option<&&'a ExprTString>

Returns Some if self is a reference of variant TString, and None otherwise.

pub fn as_mut_t_string_expr(&mut self) -> Option<&mut &'a ExprTString>

Returns Some if self is a mutable reference of variant TString, and None otherwise.

pub fn expect_t_string_expr(self) -> &'a ExprTString
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of TString.

Panics

Panics if the value is not TString. In debug builds the panic message includes the content of self.

pub fn t_string_expr(self) -> Option<&'a ExprTString>

Returns Some if self is of variant TString, and None otherwise.

pub const fn is_string_literal_expr(&self) -> bool

Returns true if self is of variant StringLiteral.

pub fn as_string_literal_expr(&self) -> Option<&&'a ExprStringLiteral>

Returns Some if self is a reference of variant StringLiteral, and None otherwise.

pub fn as_mut_string_literal_expr( &mut self, ) -> Option<&mut &'a ExprStringLiteral>

Returns Some if self is a mutable reference of variant StringLiteral, and None otherwise.

pub fn expect_string_literal_expr(self) -> &'a ExprStringLiteral
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of StringLiteral.

Panics

Panics if the value is not StringLiteral. In debug builds the panic message includes the content of self.

pub fn string_literal_expr(self) -> Option<&'a ExprStringLiteral>

Returns Some if self is of variant StringLiteral, and None otherwise.

pub const fn is_bytes_literal_expr(&self) -> bool

Returns true if self is of variant BytesLiteral.

pub fn as_bytes_literal_expr(&self) -> Option<&&'a ExprBytesLiteral>

Returns Some if self is a reference of variant BytesLiteral, and None otherwise.

pub fn as_mut_bytes_literal_expr(&mut self) -> Option<&mut &'a ExprBytesLiteral>

Returns Some if self is a mutable reference of variant BytesLiteral, and None otherwise.

pub fn expect_bytes_literal_expr(self) -> &'a ExprBytesLiteral
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of BytesLiteral.

Panics

Panics if the value is not BytesLiteral. In debug builds the panic message includes the content of self.

pub fn bytes_literal_expr(self) -> Option<&'a ExprBytesLiteral>

Returns Some if self is of variant BytesLiteral, and None otherwise.

pub const fn is_number_literal_expr(&self) -> bool

Returns true if self is of variant NumberLiteral.

pub fn as_number_literal_expr(&self) -> Option<&&'a ExprNumberLiteral>

Returns Some if self is a reference of variant NumberLiteral, and None otherwise.

pub fn as_mut_number_literal_expr( &mut self, ) -> Option<&mut &'a ExprNumberLiteral>

Returns Some if self is a mutable reference of variant NumberLiteral, and None otherwise.

pub fn expect_number_literal_expr(self) -> &'a ExprNumberLiteral
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of NumberLiteral.

Panics

Panics if the value is not NumberLiteral. In debug builds the panic message includes the content of self.

pub fn number_literal_expr(self) -> Option<&'a ExprNumberLiteral>

Returns Some if self is of variant NumberLiteral, and None otherwise.

pub const fn is_boolean_literal_expr(&self) -> bool

Returns true if self is of variant BooleanLiteral.

pub fn as_boolean_literal_expr(&self) -> Option<&&'a ExprBooleanLiteral>

Returns Some if self is a reference of variant BooleanLiteral, and None otherwise.

pub fn as_mut_boolean_literal_expr( &mut self, ) -> Option<&mut &'a ExprBooleanLiteral>

Returns Some if self is a mutable reference of variant BooleanLiteral, and None otherwise.

pub fn expect_boolean_literal_expr(self) -> &'a ExprBooleanLiteral
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of BooleanLiteral.

Panics

Panics if the value is not BooleanLiteral. In debug builds the panic message includes the content of self.

pub fn boolean_literal_expr(self) -> Option<&'a ExprBooleanLiteral>

Returns Some if self is of variant BooleanLiteral, and None otherwise.

pub const fn is_none_literal_expr(&self) -> bool

Returns true if self is of variant NoneLiteral.

pub fn as_none_literal_expr(&self) -> Option<&&'a ExprNoneLiteral>

Returns Some if self is a reference of variant NoneLiteral, and None otherwise.

pub fn as_mut_none_literal_expr(&mut self) -> Option<&mut &'a ExprNoneLiteral>

Returns Some if self is a mutable reference of variant NoneLiteral, and None otherwise.

pub fn expect_none_literal_expr(self) -> &'a ExprNoneLiteral
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of NoneLiteral.

Panics

Panics if the value is not NoneLiteral. In debug builds the panic message includes the content of self.

pub fn none_literal_expr(self) -> Option<&'a ExprNoneLiteral>

Returns Some if self is of variant NoneLiteral, and None otherwise.

pub const fn is_ellipsis_literal_expr(&self) -> bool

Returns true if self is of variant EllipsisLiteral.

pub fn as_ellipsis_literal_expr(&self) -> Option<&&'a ExprEllipsisLiteral>

Returns Some if self is a reference of variant EllipsisLiteral, and None otherwise.

pub fn as_mut_ellipsis_literal_expr( &mut self, ) -> Option<&mut &'a ExprEllipsisLiteral>

Returns Some if self is a mutable reference of variant EllipsisLiteral, and None otherwise.

pub fn expect_ellipsis_literal_expr(self) -> &'a ExprEllipsisLiteral
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of EllipsisLiteral.

Panics

Panics if the value is not EllipsisLiteral. In debug builds the panic message includes the content of self.

pub fn ellipsis_literal_expr(self) -> Option<&'a ExprEllipsisLiteral>

Returns Some if self is of variant EllipsisLiteral, and None otherwise.

pub const fn is_constant_expr(&self) -> bool

Returns true if self is of variant Constant.

pub fn as_constant_expr(&self) -> Option<&&'a ExprConstant>

Returns Some if self is a reference of variant Constant, and None otherwise.

pub fn as_mut_constant_expr(&mut self) -> Option<&mut &'a ExprConstant>

Returns Some if self is a mutable reference of variant Constant, and None otherwise.

pub fn expect_constant_expr(self) -> &'a ExprConstant
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Constant.

Panics

Panics if the value is not Constant. In debug builds the panic message includes the content of self.

pub fn constant_expr(self) -> Option<&'a ExprConstant>

Returns Some if self is of variant Constant, and None otherwise.

pub const fn is_attribute_expr(&self) -> bool

Returns true if self is of variant Attribute.

pub fn as_attribute_expr(&self) -> Option<&&'a ExprAttribute>

Returns Some if self is a reference of variant Attribute, and None otherwise.

pub fn as_mut_attribute_expr(&mut self) -> Option<&mut &'a ExprAttribute>

Returns Some if self is a mutable reference of variant Attribute, and None otherwise.

pub fn expect_attribute_expr(self) -> &'a ExprAttribute
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Attribute.

Panics

Panics if the value is not Attribute. In debug builds the panic message includes the content of self.

pub fn attribute_expr(self) -> Option<&'a ExprAttribute>

Returns Some if self is of variant Attribute, and None otherwise.

pub const fn is_subscript_expr(&self) -> bool

Returns true if self is of variant Subscript.

pub fn as_subscript_expr(&self) -> Option<&&'a ExprSubscript>

Returns Some if self is a reference of variant Subscript, and None otherwise.

pub fn as_mut_subscript_expr(&mut self) -> Option<&mut &'a ExprSubscript>

Returns Some if self is a mutable reference of variant Subscript, and None otherwise.

pub fn expect_subscript_expr(self) -> &'a ExprSubscript
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Subscript.

Panics

Panics if the value is not Subscript. In debug builds the panic message includes the content of self.

pub fn subscript_expr(self) -> Option<&'a ExprSubscript>

Returns Some if self is of variant Subscript, and None otherwise.

pub const fn is_starred_expr(&self) -> bool

Returns true if self is of variant Starred.

pub fn as_starred_expr(&self) -> Option<&&'a ExprStarred>

Returns Some if self is a reference of variant Starred, and None otherwise.

pub fn as_mut_starred_expr(&mut self) -> Option<&mut &'a ExprStarred>

Returns Some if self is a mutable reference of variant Starred, and None otherwise.

pub fn expect_starred_expr(self) -> &'a ExprStarred
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Starred.

Panics

Panics if the value is not Starred. In debug builds the panic message includes the content of self.

pub fn starred_expr(self) -> Option<&'a ExprStarred>

Returns Some if self is of variant Starred, and None otherwise.

pub const fn is_name_expr(&self) -> bool

Returns true if self is of variant Name.

pub fn as_name_expr(&self) -> Option<&&'a ExprName>

Returns Some if self is a reference of variant Name, and None otherwise.

pub fn as_mut_name_expr(&mut self) -> Option<&mut &'a ExprName>

Returns Some if self is a mutable reference of variant Name, and None otherwise.

pub fn expect_name_expr(self) -> &'a ExprName
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Name.

Panics

Panics if the value is not Name. In debug builds the panic message includes the content of self.

pub fn name_expr(self) -> Option<&'a ExprName>

Returns Some if self is of variant Name, and None otherwise.

pub const fn is_list_expr(&self) -> bool

Returns true if self is of variant List.

pub fn as_list_expr(&self) -> Option<&&'a ExprList>

Returns Some if self is a reference of variant List, and None otherwise.

pub fn as_mut_list_expr(&mut self) -> Option<&mut &'a ExprList>

Returns Some if self is a mutable reference of variant List, and None otherwise.

pub fn expect_list_expr(self) -> &'a ExprList
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of List.

Panics

Panics if the value is not List. In debug builds the panic message includes the content of self.

pub fn list_expr(self) -> Option<&'a ExprList>

Returns Some if self is of variant List, and None otherwise.

pub const fn is_tuple_expr(&self) -> bool

Returns true if self is of variant Tuple.

pub fn as_tuple_expr(&self) -> Option<&&'a ExprTuple>

Returns Some if self is a reference of variant Tuple, and None otherwise.

pub fn as_mut_tuple_expr(&mut self) -> Option<&mut &'a ExprTuple>

Returns Some if self is a mutable reference of variant Tuple, and None otherwise.

pub fn expect_tuple_expr(self) -> &'a ExprTuple
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Tuple.

Panics

Panics if the value is not Tuple. In debug builds the panic message includes the content of self.

pub fn tuple_expr(self) -> Option<&'a ExprTuple>

Returns Some if self is of variant Tuple, and None otherwise.

pub const fn is_slice_expr(&self) -> bool

Returns true if self is of variant Slice.

pub fn as_slice_expr(&self) -> Option<&&'a ExprSlice>

Returns Some if self is a reference of variant Slice, and None otherwise.

pub fn as_mut_slice_expr(&mut self) -> Option<&mut &'a ExprSlice>

Returns Some if self is a mutable reference of variant Slice, and None otherwise.

pub fn expect_slice_expr(self) -> &'a ExprSlice
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of Slice.

Panics

Panics if the value is not Slice. In debug builds the panic message includes the content of self.

pub fn slice_expr(self) -> Option<&'a ExprSlice>

Returns Some if self is of variant Slice, and None otherwise.

pub const fn is_ipy_escape_command_expr(&self) -> bool

Returns true if self is of variant IpyEscapeCommand.

pub fn as_ipy_escape_command_expr(&self) -> Option<&&'a ExprIpyEscapeCommand>

Returns Some if self is a reference of variant IpyEscapeCommand, and None otherwise.

pub fn as_mut_ipy_escape_command_expr( &mut self, ) -> Option<&mut &'a ExprIpyEscapeCommand>

Returns Some if self is a mutable reference of variant IpyEscapeCommand, and None otherwise.

pub fn expect_ipy_escape_command_expr(self) -> &'a ExprIpyEscapeCommand
where ExprRef<'a>: Debug,

Unwraps the value, yielding the content of IpyEscapeCommand.

Panics

Panics if the value is not IpyEscapeCommand. In debug builds the panic message includes the content of self.

pub fn ipy_escape_command_expr(self) -> Option<&'a ExprIpyEscapeCommand>

Returns Some if self is of variant IpyEscapeCommand, and None otherwise.

Source

impl ExprRef<'_>