FStringPart

Enum FStringPart 

pub enum FStringPart {
    Literal(StringLiteral),
    FString(FString),
}
An f-string part which is either a string literal or an f-string.

Variants



Literal(StringLiteral)



FString(FString)

Implementations

Source

impl FStringPart

pub const fn is_literal(&self) -> bool

Returns true if self is of variant Literal.

pub fn as_literal(&self) -> Option<&StringLiteral>

Returns Some if self is a reference of variant Literal, and None otherwise.

pub fn as_mut_literal(&mut self) -> Option<&mut StringLiteral>

Returns Some if self is a mutable reference of variant Literal, and None otherwise.

pub fn expect_literal(self) -> StringLiteral

Unwraps the value, yielding the content of Literal.

Panics

Panics if the value is not Literal. In debug builds the panic message includes the content of self.

pub fn literal(self) -> Option<StringLiteral>

Returns Some if self is of variant Literal, and None otherwise.

pub const fn is_f_string(&self) -> bool

Returns true if self is of variant FString.

pub fn as_f_string(&self) -> Option<&FString>

Returns Some if self is a reference of variant FString, and None otherwise.

pub fn as_mut_f_string(&mut self) -> Option<&mut FString>

Returns Some if self is a mutable reference of variant FString, and None otherwise.

pub fn expect_f_string(self) -> FString

Unwraps the value, yielding the content of FString.

Panics

Panics if the value is not FString. In debug builds the panic message includes the content of self.

pub fn f_string(self) -> Option<FString>

Returns Some if self is of variant FString, and None otherwise.

Source

impl FStringPart

pub fn quote_style(&self) -> Quote

pub fn is_empty_literal(&self) -> bool