InterpolatedStringElementRef

Enum InterpolatedStringElementRef 

pub enum InterpolatedStringElementRef<'a> {
    Interpolation(&'a InterpolatedElement),
    Literal(&'a InterpolatedStringLiteralElement),
}

Variants

Implementations

Source

impl<'a> InterpolatedStringElementRef<'a>

pub const fn is_interpolation(&self) -> bool

Returns true if self is of variant Interpolation.

pub fn as_interpolation(&self) -> Option<&&'a InterpolatedElement>

Returns Some if self is a reference of variant Interpolation, and None otherwise.

pub fn as_mut_interpolation(&mut self) -> Option<&mut &'a InterpolatedElement>

Returns Some if self is a mutable reference of variant Interpolation, and None otherwise.

pub fn expect_interpolation(self) -> &'a InterpolatedElement

Unwraps the value, yielding the content of Interpolation.

Panics

Panics if the value is not Interpolation. In debug builds the panic message includes the content of self.

pub fn interpolation(self) -> Option<&'a InterpolatedElement>

Returns Some if self is of variant Interpolation, and None otherwise.

pub const fn is_literal(&self) -> bool

Returns true if self is of variant Literal.

pub fn as_literal(&self) -> Option<&&'a InterpolatedStringLiteralElement>

Returns Some if self is a reference of variant Literal, and None otherwise.

pub fn as_mut_literal( &mut self, ) -> Option<&mut &'a InterpolatedStringLiteralElement>

Returns Some if self is a mutable reference of variant Literal, and None otherwise.

pub fn expect_literal(self) -> &'a InterpolatedStringLiteralElement

Unwraps the value, yielding the content of Literal.

Panics

Panics if the value is not Literal. In debug builds the panic message includes the content of self.

pub fn literal(self) -> Option<&'a InterpolatedStringLiteralElement>

Returns Some if self is of variant Literal, and None otherwise.