LiteralExpressionRef

Enum LiteralExpressionRef 

pub enum LiteralExpressionRef<'a> {
    StringLiteral(&'a ExprStringLiteral),
    BytesLiteral(&'a ExprBytesLiteral),
    NumberLiteral(&'a ExprNumberLiteral),
    BooleanLiteral(&'a ExprBooleanLiteral),
    NoneLiteral(&'a ExprNoneLiteral),
    EllipsisLiteral(&'a ExprEllipsisLiteral),
}
Unowned pendant to all the literal variants of ast::Expr that stores a reference instead of an owned value.

Variants



StringLiteral(&'a ExprStringLiteral)



BytesLiteral(&'a ExprBytesLiteral)



NumberLiteral(&'a ExprNumberLiteral)



BooleanLiteral(&'a ExprBooleanLiteral)



NoneLiteral(&'a ExprNoneLiteral)



EllipsisLiteral(&'a ExprEllipsisLiteral)

Implementations

Source

impl<'a> LiteralExpressionRef<'a>

pub const fn is_string_literal(&self) -> bool

Returns true if self is of variant StringLiteral.

pub fn as_string_literal(&self) -> Option<&&'a ExprStringLiteral>

Returns Some if self is a reference of variant StringLiteral, and None otherwise.

pub fn as_mut_string_literal(&mut self) -> Option<&mut &'a ExprStringLiteral>

Returns Some if self is a mutable reference of variant StringLiteral, and None otherwise.

pub fn expect_string_literal(self) -> &'a ExprStringLiteral

Unwraps the value, yielding the content of StringLiteral.

Panics

Panics if the value is not StringLiteral. In debug builds the panic message includes the content of self.

pub fn string_literal(self) -> Option<&'a ExprStringLiteral>

Returns Some if self is of variant StringLiteral, and None otherwise.

pub const fn is_bytes_literal(&self) -> bool

Returns true if self is of variant BytesLiteral.

pub fn as_bytes_literal(&self) -> Option<&&'a ExprBytesLiteral>

Returns Some if self is a reference of variant BytesLiteral, and None otherwise.

pub fn as_mut_bytes_literal(&mut self) -> Option<&mut &'a ExprBytesLiteral>

Returns Some if self is a mutable reference of variant BytesLiteral, and None otherwise.

pub fn expect_bytes_literal(self) -> &'a ExprBytesLiteral

Unwraps the value, yielding the content of BytesLiteral.

Panics

Panics if the value is not BytesLiteral. In debug builds the panic message includes the content of self.

pub fn bytes_literal(self) -> Option<&'a ExprBytesLiteral>

Returns Some if self is of variant BytesLiteral, and None otherwise.

pub const fn is_number_literal(&self) -> bool

Returns true if self is of variant NumberLiteral.

pub fn as_number_literal(&self) -> Option<&&'a ExprNumberLiteral>

Returns Some if self is a reference of variant NumberLiteral, and None otherwise.

pub fn as_mut_number_literal(&mut self) -> Option<&mut &'a ExprNumberLiteral>

Returns Some if self is a mutable reference of variant NumberLiteral, and None otherwise.

pub fn expect_number_literal(self) -> &'a ExprNumberLiteral

Unwraps the value, yielding the content of NumberLiteral.

Panics

Panics if the value is not NumberLiteral. In debug builds the panic message includes the content of self.

pub fn number_literal(self) -> Option<&'a ExprNumberLiteral>

Returns Some if self is of variant NumberLiteral, and None otherwise.

pub const fn is_boolean_literal(&self) -> bool

Returns true if self is of variant BooleanLiteral.

pub fn as_boolean_literal(&self) -> Option<&&'a ExprBooleanLiteral>

Returns Some if self is a reference of variant BooleanLiteral, and None otherwise.

pub fn as_mut_boolean_literal(&mut self) -> Option<&mut &'a ExprBooleanLiteral>

Returns Some if self is a mutable reference of variant BooleanLiteral, and None otherwise.

pub fn expect_boolean_literal(self) -> &'a ExprBooleanLiteral

Unwraps the value, yielding the content of BooleanLiteral.

Panics

Panics if the value is not BooleanLiteral. In debug builds the panic message includes the content of self.

pub fn boolean_literal(self) -> Option<&'a ExprBooleanLiteral>

Returns Some if self is of variant BooleanLiteral, and None otherwise.

pub const fn is_none_literal(&self) -> bool

Returns true if self is of variant NoneLiteral.

pub fn as_none_literal(&self) -> Option<&&'a ExprNoneLiteral>

Returns Some if self is a reference of variant NoneLiteral, and None otherwise.

pub fn as_mut_none_literal(&mut self) -> Option<&mut &'a ExprNoneLiteral>

Returns Some if self is a mutable reference of variant NoneLiteral, and None otherwise.

pub fn expect_none_literal(self) -> &'a ExprNoneLiteral

Unwraps the value, yielding the content of NoneLiteral.

Panics

Panics if the value is not NoneLiteral. In debug builds the panic message includes the content of self.

pub fn none_literal(self) -> Option<&'a ExprNoneLiteral>

Returns Some if self is of variant NoneLiteral, and None otherwise.

pub const fn is_ellipsis_literal(&self) -> bool

Returns true if self is of variant EllipsisLiteral.

pub fn as_ellipsis_literal(&self) -> Option<&&'a ExprEllipsisLiteral>

Returns Some if self is a reference of variant EllipsisLiteral, and None otherwise.

pub fn as_mut_ellipsis_literal( &mut self, ) -> Option<&mut &'a ExprEllipsisLiteral>

Returns Some if self is a mutable reference of variant EllipsisLiteral, and None otherwise.

pub fn expect_ellipsis_literal(self) -> &'a ExprEllipsisLiteral

Unwraps the value, yielding the content of EllipsisLiteral.

Panics

Panics if the value is not EllipsisLiteral. In debug builds the panic message includes the content of self.

pub fn ellipsis_literal(self) -> Option<&'a ExprEllipsisLiteral>

Returns Some if self is of variant EllipsisLiteral, and None otherwise.

Source

impl LiteralExpressionRef<'_>

pub fn is_implicit_concatenated(&self) -> bool

Returns true if the literal is either a string or bytes literal that is implicitly concatenated.