ModRef

Enum ModRef 

pub enum ModRef<'a> {
    Module(&'a ModModule),
    Expression(&'a ModExpression),
}
See also mod

Variants



Module(&'a ModModule)



Expression(&'a ModExpression)

Implementations

Source

impl<'a> ModRef<'a>

pub const fn is_module(&self) -> bool

Returns true if self is of variant Module.

pub fn as_module(&self) -> Option<&&'a ModModule>

Returns Some if self is a reference of variant Module, and None otherwise.

pub fn as_mut_module(&mut self) -> Option<&mut &'a ModModule>

Returns Some if self is a mutable reference of variant Module, and None otherwise.

pub fn expect_module(self) -> &'a ModModule
where ModRef<'a>: Debug,

Unwraps the value, yielding the content of Module.

Panics

Panics if the value is not Module. In debug builds the panic message includes the content of self.

pub fn module(self) -> Option<&'a ModModule>

Returns Some if self is of variant Module, and None otherwise.

pub const fn is_expression(&self) -> bool

Returns true if self is of variant Expression.

pub fn as_expression(&self) -> Option<&&'a ModExpression>

Returns Some if self is a reference of variant Expression, and None otherwise.

pub fn as_mut_expression(&mut self) -> Option<&mut &'a ModExpression>

Returns Some if self is a mutable reference of variant Expression, and None otherwise.

pub fn expect_expression(self) -> &'a ModExpression
where ModRef<'a>: Debug,

Unwraps the value, yielding the content of Expression.

Panics

Panics if the value is not Expression. In debug builds the panic message includes the content of self.

pub fn expression(self) -> Option<&'a ModExpression>

Returns Some if self is of variant Expression, and None otherwise.