PatternRef

Enum PatternRef 

pub enum PatternRef<'a> {
    MatchValue(&'a PatternMatchValue),
    MatchSingleton(&'a PatternMatchSingleton),
    MatchSequence(&'a PatternMatchSequence),
    MatchMapping(&'a PatternMatchMapping),
    MatchClass(&'a PatternMatchClass),
    MatchStar(&'a PatternMatchStar),
    MatchAs(&'a PatternMatchAs),
    MatchOr(&'a PatternMatchOr),
}
See also pattern

Variants



MatchValue(&'a PatternMatchValue)



MatchSingleton(&'a PatternMatchSingleton)



MatchSequence(&'a PatternMatchSequence)



MatchMapping(&'a PatternMatchMapping)



MatchClass(&'a PatternMatchClass)



MatchStar(&'a PatternMatchStar)



MatchAs(&'a PatternMatchAs)



MatchOr(&'a PatternMatchOr)

Implementations

Source

impl<'a> PatternRef<'a>

pub const fn is_match_value(&self) -> bool

Returns true if self is of variant MatchValue.

pub fn as_match_value(&self) -> Option<&&'a PatternMatchValue>

Returns Some if self is a reference of variant MatchValue, and None otherwise.

pub fn as_mut_match_value(&mut self) -> Option<&mut &'a PatternMatchValue>

Returns Some if self is a mutable reference of variant MatchValue, and None otherwise.

pub fn expect_match_value(self) -> &'a PatternMatchValue
where PatternRef<'a>: Debug,

Unwraps the value, yielding the content of MatchValue.

Panics

Panics if the value is not MatchValue. In debug builds the panic message includes the content of self.

pub fn match_value(self) -> Option<&'a PatternMatchValue>

Returns Some if self is of variant MatchValue, and None otherwise.

pub const fn is_match_singleton(&self) -> bool

Returns true if self is of variant MatchSingleton.

pub fn as_match_singleton(&self) -> Option<&&'a PatternMatchSingleton>

Returns Some if self is a reference of variant MatchSingleton, and None otherwise.

pub fn as_mut_match_singleton( &mut self, ) -> Option<&mut &'a PatternMatchSingleton>

Returns Some if self is a mutable reference of variant MatchSingleton, and None otherwise.

pub fn expect_match_singleton(self) -> &'a PatternMatchSingleton
where PatternRef<'a>: Debug,

Unwraps the value, yielding the content of MatchSingleton.

Panics

Panics if the value is not MatchSingleton. In debug builds the panic message includes the content of self.

pub fn match_singleton(self) -> Option<&'a PatternMatchSingleton>

Returns Some if self is of variant MatchSingleton, and None otherwise.

pub const fn is_match_sequence(&self) -> bool

Returns true if self is of variant MatchSequence.

pub fn as_match_sequence(&self) -> Option<&&'a PatternMatchSequence>

Returns Some if self is a reference of variant MatchSequence, and None otherwise.

pub fn as_mut_match_sequence(&mut self) -> Option<&mut &'a PatternMatchSequence>

Returns Some if self is a mutable reference of variant MatchSequence, and None otherwise.

pub fn expect_match_sequence(self) -> &'a PatternMatchSequence
where PatternRef<'a>: Debug,

Unwraps the value, yielding the content of MatchSequence.

Panics

Panics if the value is not MatchSequence. In debug builds the panic message includes the content of self.

pub fn match_sequence(self) -> Option<&'a PatternMatchSequence>

Returns Some if self is of variant MatchSequence, and None otherwise.

pub const fn is_match_mapping(&self) -> bool

Returns true if self is of variant MatchMapping.

pub fn as_match_mapping(&self) -> Option<&&'a PatternMatchMapping>

Returns Some if self is a reference of variant MatchMapping, and None otherwise.

pub fn as_mut_match_mapping(&mut self) -> Option<&mut &'a PatternMatchMapping>

Returns Some if self is a mutable reference of variant MatchMapping, and None otherwise.

pub fn expect_match_mapping(self) -> &'a PatternMatchMapping
where PatternRef<'a>: Debug,

Unwraps the value, yielding the content of MatchMapping.

Panics

Panics if the value is not MatchMapping. In debug builds the panic message includes the content of self.

pub fn match_mapping(self) -> Option<&'a PatternMatchMapping>

Returns Some if self is of variant MatchMapping, and None otherwise.

pub const fn is_match_class(&self) -> bool

Returns true if self is of variant MatchClass.

pub fn as_match_class(&self) -> Option<&&'a PatternMatchClass>

Returns Some if self is a reference of variant MatchClass, and None otherwise.

pub fn as_mut_match_class(&mut self) -> Option<&mut &'a PatternMatchClass>

Returns Some if self is a mutable reference of variant MatchClass, and None otherwise.

pub fn expect_match_class(self) -> &'a PatternMatchClass
where PatternRef<'a>: Debug,

Unwraps the value, yielding the content of MatchClass.

Panics

Panics if the value is not MatchClass. In debug builds the panic message includes the content of self.

pub fn match_class(self) -> Option<&'a PatternMatchClass>

Returns Some if self is of variant MatchClass, and None otherwise.

pub const fn is_match_star(&self) -> bool

Returns true if self is of variant MatchStar.

pub fn as_match_star(&self) -> Option<&&'a PatternMatchStar>

Returns Some if self is a reference of variant MatchStar, and None otherwise.

pub fn as_mut_match_star(&mut self) -> Option<&mut &'a PatternMatchStar>

Returns Some if self is a mutable reference of variant MatchStar, and None otherwise.

pub fn expect_match_star(self) -> &'a PatternMatchStar
where PatternRef<'a>: Debug,

Unwraps the value, yielding the content of MatchStar.

Panics

Panics if the value is not MatchStar. In debug builds the panic message includes the content of self.

pub fn match_star(self) -> Option<&'a PatternMatchStar>

Returns Some if self is of variant MatchStar, and None otherwise.

pub const fn is_match_as(&self) -> bool

Returns true if self is of variant MatchAs.

pub fn as_match_as(&self) -> Option<&&'a PatternMatchAs>

Returns Some if self is a reference of variant MatchAs, and None otherwise.

pub fn as_mut_match_as(&mut self) -> Option<&mut &'a PatternMatchAs>

Returns Some if self is a mutable reference of variant MatchAs, and None otherwise.

pub fn expect_match_as(self) -> &'a PatternMatchAs
where PatternRef<'a>: Debug,

Unwraps the value, yielding the content of MatchAs.

Panics

Panics if the value is not MatchAs. In debug builds the panic message includes the content of self.

pub fn match_as(self) -> Option<&'a PatternMatchAs>

Returns Some if self is of variant MatchAs, and None otherwise.

pub const fn is_match_or(&self) -> bool

Returns true if self is of variant MatchOr.

pub fn as_match_or(&self) -> Option<&&'a PatternMatchOr>

Returns Some if self is a reference of variant MatchOr, and None otherwise.

pub fn as_mut_match_or(&mut self) -> Option<&mut &'a PatternMatchOr>

Returns Some if self is a mutable reference of variant MatchOr, and None otherwise.

pub fn expect_match_or(self) -> &'a PatternMatchOr
where PatternRef<'a>: Debug,

Unwraps the value, yielding the content of MatchOr.

Panics

Panics if the value is not MatchOr. In debug builds the panic message includes the content of self.

pub fn match_or(self) -> Option<&'a PatternMatchOr>

Returns Some if self is of variant MatchOr, and None otherwise.