SourceType

Enum SourceType 

pub enum SourceType {
    Python(PySourceType),
    Toml(TomlSourceType),
    Markdown,
}
The type of a source file.

Variants



Python(PySourceType)

The file contains Python source code.



Toml(TomlSourceType)

The file contains TOML.



Markdown

The file contains Markdown.

Implementations

Source

impl SourceType

pub const fn is_python(&self) -> bool

Returns true if self is of variant Python.

pub fn as_python(&self) -> Option<&PySourceType>

Returns Some if self is a reference of variant Python, and None otherwise.

pub fn as_mut_python(&mut self) -> Option<&mut PySourceType>

Returns Some if self is a mutable reference of variant Python, and None otherwise.

pub fn expect_python(self) -> PySourceType

Unwraps the value, yielding the content of Python.

Panics

Panics if the value is not Python, with a panic message including the content of self.

pub fn python(self) -> Option<PySourceType>

Returns Some if self is of variant Python, and None otherwise.

pub const fn is_toml(&self) -> bool

Returns true if self is of variant Toml.

pub fn as_toml(&self) -> Option<&TomlSourceType>

Returns Some if self is a reference of variant Toml, and None otherwise.

pub fn as_mut_toml(&mut self) -> Option<&mut TomlSourceType>

Returns Some if self is a mutable reference of variant Toml, and None otherwise.

pub fn expect_toml(self) -> TomlSourceType

Unwraps the value, yielding the content of Toml.

Panics

Panics if the value is not Toml, with a panic message including the content of self.

pub fn toml(self) -> Option<TomlSourceType>

Returns Some if self is of variant Toml, and None otherwise.

pub const fn is_markdown(&self) -> bool

Returns true if self is of variant Markdown.

Source

impl SourceType