TypeParamRef

Enum TypeParamRef 

pub enum TypeParamRef<'a> {
    TypeVar(&'a TypeParamTypeVar),
    TypeVarTuple(&'a TypeParamTypeVarTuple),
    ParamSpec(&'a TypeParamParamSpec),
}
See also type_param

Variants



TypeVar(&'a TypeParamTypeVar)



TypeVarTuple(&'a TypeParamTypeVarTuple)



ParamSpec(&'a TypeParamParamSpec)

Implementations

Source

impl<'a> TypeParamRef<'a>

pub const fn is_type_var(&self) -> bool

Returns true if self is of variant TypeVar.

pub fn as_type_var(&self) -> Option<&&'a TypeParamTypeVar>

Returns Some if self is a reference of variant TypeVar, and None otherwise.

pub fn as_mut_type_var(&mut self) -> Option<&mut &'a TypeParamTypeVar>

Returns Some if self is a mutable reference of variant TypeVar, and None otherwise.

pub fn expect_type_var(self) -> &'a TypeParamTypeVar
where TypeParamRef<'a>: Debug,

Unwraps the value, yielding the content of TypeVar.

Panics

Panics if the value is not TypeVar. In debug builds the panic message includes the content of self.

pub fn type_var(self) -> Option<&'a TypeParamTypeVar>

Returns Some if self is of variant TypeVar, and None otherwise.

pub const fn is_type_var_tuple(&self) -> bool

Returns true if self is of variant TypeVarTuple.

pub fn as_type_var_tuple(&self) -> Option<&&'a TypeParamTypeVarTuple>

Returns Some if self is a reference of variant TypeVarTuple, and None otherwise.

pub fn as_mut_type_var_tuple( &mut self, ) -> Option<&mut &'a TypeParamTypeVarTuple>

Returns Some if self is a mutable reference of variant TypeVarTuple, and None otherwise.

pub fn expect_type_var_tuple(self) -> &'a TypeParamTypeVarTuple
where TypeParamRef<'a>: Debug,

Unwraps the value, yielding the content of TypeVarTuple.

Panics

Panics if the value is not TypeVarTuple. In debug builds the panic message includes the content of self.

pub fn type_var_tuple(self) -> Option<&'a TypeParamTypeVarTuple>

Returns Some if self is of variant TypeVarTuple, and None otherwise.

pub const fn is_param_spec(&self) -> bool

Returns true if self is of variant ParamSpec.

pub fn as_param_spec(&self) -> Option<&&'a TypeParamParamSpec>

Returns Some if self is a reference of variant ParamSpec, and None otherwise.

pub fn as_mut_param_spec(&mut self) -> Option<&mut &'a TypeParamParamSpec>

Returns Some if self is a mutable reference of variant ParamSpec, and None otherwise.

pub fn expect_param_spec(self) -> &'a TypeParamParamSpec
where TypeParamRef<'a>: Debug,

Unwraps the value, yielding the content of ParamSpec.

Panics

Panics if the value is not ParamSpec. In debug builds the panic message includes the content of self.

pub fn param_spec(self) -> Option<&'a TypeParamParamSpec>

Returns Some if self is of variant ParamSpec, and None otherwise.