covering_node

Function covering_node 

pub fn covering_node(root: AnyNodeRef<'_>, range: TextRange) -> CoveringNode<'_>
Returns the node with a minimal range that fully contains range.

If range is empty and falls within a parser synthesized node generated during error recovery, then the first node with the given range is returned.

Panics

Panics if range is not contained within root.