CoveringNode

Struct CoveringNode 

pub struct CoveringNode<'a> { /* private fields */ }
The node with a minimal range that fully contains the search range.

Implementations

Source

impl<'a> CoveringNode<'a>

pub fn from_ancestors(ancestors: Vec<AnyNodeRef<'a>>) -> CoveringNode<'a>

Creates a new CoveringNode from a list of ancestor nodes. The ancestors should be ordered from root to the covering node.

pub fn node(&self) -> AnyNodeRef<'a>

Returns the covering node found.

pub fn parent(&self) -> Option<AnyNodeRef<'a>>

Returns the node’s parent.

pub fn find_first( self, f: impl Fn(AnyNodeRef<'a>) -> bool, ) -> Result<CoveringNode<'a>, CoveringNode<'a>>

Finds the first node that fully covers the range and fulfills the given predicate.

The “first” here means that the node closest to a leaf is returned.

pub fn find_last( self, f: impl Fn(AnyNodeRef<'a>) -> bool, ) -> Result<CoveringNode<'a>, CoveringNode<'a>>

Finds the last node that fully covers the range and fulfills the given predicate.

The “last” here means that after finding the “first” such node, the highest ancestor found satisfying the given predicate is returned. Note that this is not the same as finding the node closest to the root that satisfies the given predictate.

pub fn ancestors(&self) -> impl DoubleEndedIterator

Returns an iterator over the ancestor nodes, starting with the node itself and walking towards the root.