pub struct ScriptTag { /* private fields */ }Expand description
PEP 723 metadata as parsed from a script comment block.
See: https://peps.python.org/pep-0723/
Vendored from: https://github.com/astral-sh/uv/blob/debe67ffdb0cd7835734100e909b2d8f79613743/crates/uv-scripts/src/lib.rs#L283
Implementations
Sourceimpl ScriptTag
impl ScriptTag
Sourcepub fn parse(contents: &[u8]) -> Option<ScriptTag>
pub fn parse(contents: &[u8]) -> Option<ScriptTag>
Given the contents of a Python file, extract the script metadata block with leading
comment hashes removed, any preceding shebang or content (prelude), and the remaining Python
script.
Given the following input string representing the contents of a Python script:
#!/usr/bin/env python3
# /// script
# requires-python = '>=3.11'
# dependencies = [
# 'requests<3',
# 'rich',
# ]
# ///
import requests
print("Hello, World!")This function would return:
- Preamble:
#!/usr/bin/env python3\n - Metadata:
requires-python = '>=3.11'\ndependencies = [\n 'requests<3',\n 'rich',\n] - Postlude:
import requests\n\nprint("Hello, World!")\n