pub fn raw_contents(contents: &str) -> Option<&str>Expand description
Strip the leading and trailing quotes from a string. Assumes that the string is a valid string literal, but does not verify that the string is a “simple” string literal (i.e., that it does not contain any implicit concatenations).