ByteStringPrefix

Enum ByteStringPrefix 

pub enum ByteStringPrefix {
    Regular,
    Raw {
        uppercase_r: bool,
    },
}
Enumeration of the valid prefixes a bytestring literal can have.

Variants



Regular

Just a regular bytestring with no other prefixes, e.g. b"foo"



Raw

A “raw” bytestring, that has an r or R prefix, e.g. Rb"foo" or rb"foo"

Fields

uppercase_r: bool

Implementations

Source

impl ByteStringPrefix

pub const fn as_str(self) -> &'static str

Return a str representation of the prefix

pub const fn text_len(self) -> TextSize

pub const fn is_raw(self) -> bool

Return true if this prefix indicates a “raw bytestring”, e.g. rb"foo" or Rb"foo"