pub struct Alias {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub name: Identifier,
pub asname: Option<Identifier>,
}Expand description
See also alias
Fields
range: TextRangenode_index: AtomicNodeIndexname: Identifierasname: Option<Identifier>Trait Implementations
Sourceimpl<'a> From<&'a Alias> for AnyNodeRef<'a>
impl<'a> From<&'a Alias> for AnyNodeRef<'a>
Sourcefn from(node: &'a Alias) -> AnyNodeRef<'a>
fn from(node: &'a Alias) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a Alias> for AnyRootNodeRef<'a>
impl<'a> From<&'a Alias> for AnyRootNodeRef<'a>
Sourcefn from(node: &'a Alias) -> AnyRootNodeRef<'a>
fn from(node: &'a Alias) -> AnyRootNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a Alias> for ComparableAlias<'a>
impl<'a> From<&'a Alias> for ComparableAlias<'a>
Sourcefn from(alias: &'a Alias) -> ComparableAlias<'a>
fn from(alias: &'a Alias) -> ComparableAlias<'a>
Converts to this type from the input type.
Sourceimpl GetSize for Alias
impl GetSize for Alias
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for Alias
impl HasNodeIndex for Alias
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl Identifier for Alias
impl Identifier for Alias
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a Alias
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a Alias
impl StructuralPartialEq for Alias