pub struct BytesLiteralValue { /* private fields */ }Expand description
The value representing a ExprBytesLiteral.
Implementations
Sourceimpl BytesLiteralValue
impl BytesLiteralValue
Sourcepub fn single(value: BytesLiteral) -> BytesLiteralValue
pub fn single(value: BytesLiteral) -> BytesLiteralValue
Create a new bytestring literal with a single BytesLiteral part.
Sourcepub fn concatenated(values: Vec<BytesLiteral>) -> BytesLiteralValue
pub fn concatenated(values: Vec<BytesLiteral>) -> BytesLiteralValue
Creates a new bytestring literal with the given values that represents an implicitly concatenated bytestring.
Panics
Panics if values has less than 2 elements.
Use BytesLiteralValue::single instead.
Sourcepub const fn is_implicit_concatenated(&self) -> bool
pub const fn is_implicit_concatenated(&self) -> bool
Returns true if the bytestring is implicitly concatenated.
Sourcepub fn as_slice(&self) -> &[BytesLiteral]
pub fn as_slice(&self) -> &[BytesLiteral]
Returns a slice of all the BytesLiteral parts contained in this value.
Sourcepub fn iter(&self) -> Iter<'_, BytesLiteral>
pub fn iter(&self) -> Iter<'_, BytesLiteral>
Returns an iterator over all the BytesLiteral parts contained in this value.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, BytesLiteral>
pub fn iter_mut(&mut self) -> IterMut<'_, BytesLiteral>
Returns an iterator over all the BytesLiteral parts contained in this value
that allows modification.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Return true if the node represents an empty bytestring.
Note that a BytesLiteralValue node will always have >=1 BytesLiteral parts
inside it. This method checks whether the value of the concatenated parts is equal
to the empty bytestring, not whether the bytestring has 0 parts inside it.