pub struct Decorator {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub expression: Expr,
}Expand description
See also decorator
Fields
range: TextRangenode_index: AtomicNodeIndexexpression: ExprTrait Implementations
Sourceimpl<'a> From<&'a Decorator> for AnyNodeRef<'a>
impl<'a> From<&'a Decorator> for AnyNodeRef<'a>
Sourcefn from(node: &'a Decorator) -> AnyNodeRef<'a>
fn from(node: &'a Decorator) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a Decorator> for AnyRootNodeRef<'a>
impl<'a> From<&'a Decorator> for AnyRootNodeRef<'a>
Sourcefn from(node: &'a Decorator) -> AnyRootNodeRef<'a>
fn from(node: &'a Decorator) -> AnyRootNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a Decorator> for ComparableDecorator<'a>
impl<'a> From<&'a Decorator> for ComparableDecorator<'a>
Sourcefn from(decorator: &'a Decorator) -> ComparableDecorator<'a>
fn from(decorator: &'a Decorator) -> ComparableDecorator<'a>
Converts to this type from the input type.
Sourceimpl GetSize for Decorator
impl GetSize for Decorator
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for Decorator
impl HasNodeIndex for Decorator
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a Decorator
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a Decorator
impl StructuralPartialEq for Decorator