pub struct DictItem {
pub key: Option<Expr>,
pub value: Expr,
}Expand description
Represents an item in a dictionary literal display.
Consider the following Python dictionary literal:
{key1: value1, **other_dictionary}In our AST, this would be represented using an ExprDict node containing
two DictItem nodes inside it:
ⓘ
[
DictItem {
key: Some(Expr::Name(ExprName { id: "key1" })),
value: Expr::Name(ExprName { id: "value1" }),
},
DictItem {
key: None,
value: Expr::Name(ExprName { id: "other_dictionary" }),
}
]Fields
key: Option<Expr>value: ExprTrait Implementations
Sourceimpl<'a> From<&'a DictItem> for ComparableDictItem<'a>
impl<'a> From<&'a DictItem> for ComparableDictItem<'a>
Sourcefn from(_: &'a DictItem) -> ComparableDictItem<'a>
fn from(_: &'a DictItem) -> ComparableDictItem<'a>
Converts to this type from the input type.
Sourceimpl GetSize for DictItem
impl GetSize for DictItem
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreimpl StructuralPartialEq for DictItem