pub struct ElifElseClause {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub test: Option<Expr>,
pub body: Vec<Stmt>,
}Fields
range: TextRangenode_index: AtomicNodeIndextest: Option<Expr>body: Vec<Stmt>Trait Implementations
Sourceimpl Clone for ElifElseClause
impl Clone for ElifElseClause
Sourcefn clone(&self) -> ElifElseClause
fn clone(&self) -> ElifElseClause
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElifElseClause
impl Debug for ElifElseClause
Sourceimpl<'a> From<&'a ElifElseClause> for AnyNodeRef<'a>
impl<'a> From<&'a ElifElseClause> for AnyNodeRef<'a>
Sourcefn from(node: &'a ElifElseClause) -> AnyNodeRef<'a>
fn from(node: &'a ElifElseClause) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ElifElseClause> for AnyRootNodeRef<'a>
impl<'a> From<&'a ElifElseClause> for AnyRootNodeRef<'a>
Sourcefn from(node: &'a ElifElseClause) -> AnyRootNodeRef<'a>
fn from(node: &'a ElifElseClause) -> AnyRootNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ElifElseClause> for ComparableElifElseClause<'a>
impl<'a> From<&'a ElifElseClause> for ComparableElifElseClause<'a>
Sourcefn from(elif_else_clause: &'a ElifElseClause) -> ComparableElifElseClause<'a>
fn from(elif_else_clause: &'a ElifElseClause) -> ComparableElifElseClause<'a>
Converts to this type from the input type.
Sourceimpl GetSize for ElifElseClause
impl GetSize for ElifElseClause
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ElifElseClause
impl HasNodeIndex for ElifElseClause
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ElifElseClause
impl PartialEq for ElifElseClause
Sourceimpl Ranged for ElifElseClause
impl Ranged for ElifElseClause
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ElifElseClause
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ElifElseClause
impl StructuralPartialEq for ElifElseClause