pub struct ExprAttribute {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: Box<Expr>,
pub attr: Identifier,
pub ctx: ExprContext,
}Expand description
See also Attribute
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: Box<Expr>attr: Identifierctx: ExprContextTrait Implementations
Sourceimpl Clone for ExprAttribute
impl Clone for ExprAttribute
Sourcefn clone(&self) -> ExprAttribute
fn clone(&self) -> ExprAttribute
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprAttribute
impl Debug for ExprAttribute
Sourceimpl<'a> From<&'a ExprAttribute> for AnyNodeRef<'a>
impl<'a> From<&'a ExprAttribute> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprAttribute) -> AnyNodeRef<'a>
fn from(node: &'a ExprAttribute) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprAttribute> for ExprRef<'a>
impl<'a> From<&'a ExprAttribute> for ExprRef<'a>
Sourcefn from(node: &'a ExprAttribute) -> ExprRef<'a>
fn from(node: &'a ExprAttribute) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprAttribute> for Expr
impl From<ExprAttribute> for Expr
Sourcefn from(node: ExprAttribute) -> Expr
fn from(node: ExprAttribute) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprAttribute
impl GetSize for ExprAttribute
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprAttribute
impl HasNodeIndex for ExprAttribute
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprAttribute
impl PartialEq for ExprAttribute
Sourceimpl Ranged for ExprAttribute
impl Ranged for ExprAttribute
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprAttribute
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprAttribute
impl StructuralPartialEq for ExprAttribute