pub struct ExprBoolOp {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub op: BoolOp,
pub values: Vec<Expr>,
}Expand description
See also BoolOp
Fields
node_index: AtomicNodeIndexrange: TextRangeop: BoolOpvalues: Vec<Expr>Trait Implementations
Sourceimpl Clone for ExprBoolOp
impl Clone for ExprBoolOp
Sourcefn clone(&self) -> ExprBoolOp
fn clone(&self) -> ExprBoolOp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprBoolOp
impl Debug for ExprBoolOp
Sourceimpl<'a> From<&'a ExprBoolOp> for AnyNodeRef<'a>
impl<'a> From<&'a ExprBoolOp> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprBoolOp) -> AnyNodeRef<'a>
fn from(node: &'a ExprBoolOp) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprBoolOp> for ExprRef<'a>
impl<'a> From<&'a ExprBoolOp> for ExprRef<'a>
Sourcefn from(node: &'a ExprBoolOp) -> ExprRef<'a>
fn from(node: &'a ExprBoolOp) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprBoolOp> for Expr
impl From<ExprBoolOp> for Expr
Sourcefn from(node: ExprBoolOp) -> Expr
fn from(node: ExprBoolOp) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprBoolOp
impl GetSize for ExprBoolOp
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprBoolOp
impl HasNodeIndex for ExprBoolOp
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprBoolOp
impl PartialEq for ExprBoolOp
Sourceimpl Ranged for ExprBoolOp
impl Ranged for ExprBoolOp
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprBoolOp
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprBoolOp
impl StructuralPartialEq for ExprBoolOp