pub struct ExprBooleanLiteral {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: bool,
}Fields
node_index: AtomicNodeIndexrange: TextRangevalue: boolTrait Implementations
Sourceimpl Clone for ExprBooleanLiteral
impl Clone for ExprBooleanLiteral
Sourcefn clone(&self) -> ExprBooleanLiteral
fn clone(&self) -> ExprBooleanLiteral
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprBooleanLiteral
impl Debug for ExprBooleanLiteral
Sourceimpl Default for ExprBooleanLiteral
impl Default for ExprBooleanLiteral
Sourcefn default() -> ExprBooleanLiteral
fn default() -> ExprBooleanLiteral
Returns the “default value” for a type. Read more
Sourceimpl<'a> From<&'a ExprBooleanLiteral> for AnyNodeRef<'a>
impl<'a> From<&'a ExprBooleanLiteral> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprBooleanLiteral) -> AnyNodeRef<'a>
fn from(node: &'a ExprBooleanLiteral) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprBooleanLiteral> for ExprRef<'a>
impl<'a> From<&'a ExprBooleanLiteral> for ExprRef<'a>
Sourcefn from(node: &'a ExprBooleanLiteral) -> ExprRef<'a>
fn from(node: &'a ExprBooleanLiteral) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprBooleanLiteral> for Expr
impl From<ExprBooleanLiteral> for Expr
Sourcefn from(node: ExprBooleanLiteral) -> Expr
fn from(node: ExprBooleanLiteral) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprBooleanLiteral
impl GetSize for ExprBooleanLiteral
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprBooleanLiteral
impl HasNodeIndex for ExprBooleanLiteral
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprBooleanLiteral
impl PartialEq for ExprBooleanLiteral
Sourceimpl Ranged for ExprBooleanLiteral
impl Ranged for ExprBooleanLiteral
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprBooleanLiteral
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprBooleanLiteral
impl StructuralPartialEq for ExprBooleanLiteral