pub struct ExprBytesLiteral {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: BytesLiteralValue,
}Expand description
An AST node that represents either a single-part bytestring literal or an implicitly concatenated bytestring literal.
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: BytesLiteralValueImplementations
Sourceimpl ExprBytesLiteral
impl ExprBytesLiteral
Sourcepub const fn as_single_part_bytestring(&self) -> Option<&BytesLiteral>
pub const fn as_single_part_bytestring(&self) -> Option<&BytesLiteral>
Return Some(literal) if the bytestring only consists of a single BytesLiteral part
(indicating that it is not implicitly concatenated). Otherwise, return None.