pub struct ExprCall {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub func: Box<Expr>,
pub arguments: Arguments,
}Expand description
See also Call
Fields
node_index: AtomicNodeIndexrange: TextRangefunc: Box<Expr>arguments: ArgumentsTrait Implementations
Sourceimpl<'a> From<&'a ExprCall> for AnyNodeRef<'a>
impl<'a> From<&'a ExprCall> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprCall) -> AnyNodeRef<'a>
fn from(node: &'a ExprCall) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl GetSize for ExprCall
impl GetSize for ExprCall
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprCall
impl HasNodeIndex for ExprCall
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprCall
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprCall
impl StructuralPartialEq for ExprCall