pub struct ExprConstant {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: ConstantValue,
pub kind: Option<Box<str>>,
pub invalid_type: Option<Box<str>>,
}Expand description
See also Constant
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: ConstantValuekind: Option<Box<str>>invalid_type: Option<Box<str>>Trait Implementations
Sourceimpl Clone for ExprConstant
impl Clone for ExprConstant
Sourcefn clone(&self) -> ExprConstant
fn clone(&self) -> ExprConstant
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprConstant
impl Debug for ExprConstant
Sourceimpl<'a> From<&'a ExprConstant> for ExprRef<'a>
impl<'a> From<&'a ExprConstant> for ExprRef<'a>
Sourcefn from(node: &'a ExprConstant) -> ExprRef<'a>
fn from(node: &'a ExprConstant) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprConstant> for AnyNodeRef<'a>
impl<'a> From<&'a ExprConstant> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprConstant) -> AnyNodeRef<'a>
fn from(node: &'a ExprConstant) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprConstant> for Expr
impl From<ExprConstant> for Expr
Sourcefn from(node: ExprConstant) -> Expr
fn from(node: ExprConstant) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprConstant
impl GetSize for ExprConstant
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprConstant
impl HasNodeIndex for ExprConstant
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprConstant
impl PartialEq for ExprConstant
Sourceimpl Ranged for ExprConstant
impl Ranged for ExprConstant
impl StructuralPartialEq for ExprConstant
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprConstant
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprConstant