pub struct ExprDictComp {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub key: Box<Expr>,
pub value: Box<Expr>,
pub generators: Vec<Comprehension>,
}Expand description
See also DictComp
Fields
node_index: AtomicNodeIndexrange: TextRangekey: Box<Expr>value: Box<Expr>generators: Vec<Comprehension>Trait Implementations
Sourceimpl Clone for ExprDictComp
impl Clone for ExprDictComp
Sourcefn clone(&self) -> ExprDictComp
fn clone(&self) -> ExprDictComp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprDictComp
impl Debug for ExprDictComp
Sourceimpl<'a> From<&'a ExprDictComp> for AnyNodeRef<'a>
impl<'a> From<&'a ExprDictComp> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprDictComp) -> AnyNodeRef<'a>
fn from(node: &'a ExprDictComp) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprDictComp> for ExprRef<'a>
impl<'a> From<&'a ExprDictComp> for ExprRef<'a>
Sourcefn from(node: &'a ExprDictComp) -> ExprRef<'a>
fn from(node: &'a ExprDictComp) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprDictComp> for Expr
impl From<ExprDictComp> for Expr
Sourcefn from(node: ExprDictComp) -> Expr
fn from(node: ExprDictComp) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprDictComp
impl GetSize for ExprDictComp
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprDictComp
impl HasNodeIndex for ExprDictComp
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprDictComp
impl PartialEq for ExprDictComp
Sourceimpl Ranged for ExprDictComp
impl Ranged for ExprDictComp
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprDictComp
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprDictComp
impl StructuralPartialEq for ExprDictComp