pub struct ExprGenerator {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub elt: Box<Expr>,
pub generators: Vec<Comprehension>,
pub parenthesized: bool,
}Expand description
See also GeneratorExp
Fields
node_index: AtomicNodeIndexrange: TextRangeelt: Box<Expr>generators: Vec<Comprehension>parenthesized: boolTrait Implementations
Sourceimpl Clone for ExprGenerator
impl Clone for ExprGenerator
Sourcefn clone(&self) -> ExprGenerator
fn clone(&self) -> ExprGenerator
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprGenerator
impl Debug for ExprGenerator
Sourceimpl<'a> From<&'a ExprGenerator> for AnyNodeRef<'a>
impl<'a> From<&'a ExprGenerator> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprGenerator) -> AnyNodeRef<'a>
fn from(node: &'a ExprGenerator) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprGenerator> for ExprRef<'a>
impl<'a> From<&'a ExprGenerator> for ExprRef<'a>
Sourcefn from(node: &'a ExprGenerator) -> ExprRef<'a>
fn from(node: &'a ExprGenerator) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprGenerator> for Expr
impl From<ExprGenerator> for Expr
Sourcefn from(node: ExprGenerator) -> Expr
fn from(node: ExprGenerator) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprGenerator
impl GetSize for ExprGenerator
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprGenerator
impl HasNodeIndex for ExprGenerator
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprGenerator
impl PartialEq for ExprGenerator
Sourceimpl Ranged for ExprGenerator
impl Ranged for ExprGenerator
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprGenerator
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprGenerator
impl StructuralPartialEq for ExprGenerator