pub struct ExprIf {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub test: Box<Expr>,
pub body: Box<Expr>,
pub orelse: Box<Expr>,
}Expand description
See also IfExp
Fields
node_index: AtomicNodeIndexrange: TextRangetest: Box<Expr>body: Box<Expr>orelse: Box<Expr>Trait Implementations
Sourceimpl<'a> From<&'a ExprIf> for AnyNodeRef<'a>
impl<'a> From<&'a ExprIf> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprIf) -> AnyNodeRef<'a>
fn from(node: &'a ExprIf) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl GetSize for ExprIf
impl GetSize for ExprIf
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprIf
impl HasNodeIndex for ExprIf
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprIf
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprIf
impl StructuralPartialEq for ExprIf