pub struct ExprIpyEscapeCommand {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub kind: IpyEscapeKind,
pub value: Box<str>,
}Expand description
An AST node used to represent a IPython escape command at the expression level.
For example,
dir = !pwdHere, the escape kind can only be ! or % otherwise it is a syntax error.
For more information related to terminology and syntax of escape commands,
see StmtIpyEscapeCommand.
Fields
node_index: AtomicNodeIndexrange: TextRangekind: IpyEscapeKindvalue: Box<str>Trait Implementations
Sourceimpl Clone for ExprIpyEscapeCommand
impl Clone for ExprIpyEscapeCommand
Sourcefn clone(&self) -> ExprIpyEscapeCommand
fn clone(&self) -> ExprIpyEscapeCommand
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprIpyEscapeCommand
impl Debug for ExprIpyEscapeCommand
Sourceimpl<'a> From<&'a ExprIpyEscapeCommand> for AnyNodeRef<'a>
impl<'a> From<&'a ExprIpyEscapeCommand> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprIpyEscapeCommand) -> AnyNodeRef<'a>
fn from(node: &'a ExprIpyEscapeCommand) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprIpyEscapeCommand> for ExprRef<'a>
impl<'a> From<&'a ExprIpyEscapeCommand> for ExprRef<'a>
Sourcefn from(node: &'a ExprIpyEscapeCommand) -> ExprRef<'a>
fn from(node: &'a ExprIpyEscapeCommand) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprIpyEscapeCommand> for Expr
impl From<ExprIpyEscapeCommand> for Expr
Sourcefn from(node: ExprIpyEscapeCommand) -> Expr
fn from(node: ExprIpyEscapeCommand) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprIpyEscapeCommand
impl GetSize for ExprIpyEscapeCommand
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprIpyEscapeCommand
impl HasNodeIndex for ExprIpyEscapeCommand
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprIpyEscapeCommand
impl PartialEq for ExprIpyEscapeCommand
Sourceimpl Ranged for ExprIpyEscapeCommand
impl Ranged for ExprIpyEscapeCommand
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprIpyEscapeCommand
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprIpyEscapeCommand
impl StructuralPartialEq for ExprIpyEscapeCommand