pub struct ExprLambda {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub parameters: Option<Box<Parameters>>,
pub body: Box<Expr>,
}Expand description
See also Lambda
Fields
node_index: AtomicNodeIndexrange: TextRangeparameters: Option<Box<Parameters>>body: Box<Expr>Trait Implementations
Sourceimpl Clone for ExprLambda
impl Clone for ExprLambda
Sourcefn clone(&self) -> ExprLambda
fn clone(&self) -> ExprLambda
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprLambda
impl Debug for ExprLambda
Sourceimpl<'a> From<&'a ExprLambda> for AnyNodeRef<'a>
impl<'a> From<&'a ExprLambda> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprLambda) -> AnyNodeRef<'a>
fn from(node: &'a ExprLambda) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprLambda> for ExprRef<'a>
impl<'a> From<&'a ExprLambda> for ExprRef<'a>
Sourcefn from(node: &'a ExprLambda) -> ExprRef<'a>
fn from(node: &'a ExprLambda) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprLambda> for Expr
impl From<ExprLambda> for Expr
Sourcefn from(node: ExprLambda) -> Expr
fn from(node: ExprLambda) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprLambda
impl GetSize for ExprLambda
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprLambda
impl HasNodeIndex for ExprLambda
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprLambda
impl PartialEq for ExprLambda
Sourceimpl Ranged for ExprLambda
impl Ranged for ExprLambda
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprLambda
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprLambda
impl StructuralPartialEq for ExprLambda