pub struct ExprListComp {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub elt: Box<Expr>,
pub generators: Vec<Comprehension>,
}Expand description
See also ListComp
Fields
node_index: AtomicNodeIndexrange: TextRangeelt: Box<Expr>generators: Vec<Comprehension>Trait Implementations
Sourceimpl Clone for ExprListComp
impl Clone for ExprListComp
Sourcefn clone(&self) -> ExprListComp
fn clone(&self) -> ExprListComp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprListComp
impl Debug for ExprListComp
Sourceimpl<'a> From<&'a ExprListComp> for AnyNodeRef<'a>
impl<'a> From<&'a ExprListComp> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprListComp) -> AnyNodeRef<'a>
fn from(node: &'a ExprListComp) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprListComp> for ExprRef<'a>
impl<'a> From<&'a ExprListComp> for ExprRef<'a>
Sourcefn from(node: &'a ExprListComp) -> ExprRef<'a>
fn from(node: &'a ExprListComp) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprListComp> for Expr
impl From<ExprListComp> for Expr
Sourcefn from(node: ExprListComp) -> Expr
fn from(node: ExprListComp) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprListComp
impl GetSize for ExprListComp
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprListComp
impl HasNodeIndex for ExprListComp
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprListComp
impl PartialEq for ExprListComp
Sourceimpl Ranged for ExprListComp
impl Ranged for ExprListComp
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprListComp
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprListComp
impl StructuralPartialEq for ExprListComp