pub struct ExprNumberLiteral {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: Number,
}Fields
node_index: AtomicNodeIndexrange: TextRangevalue: NumberTrait Implementations
Sourceimpl Clone for ExprNumberLiteral
impl Clone for ExprNumberLiteral
Sourcefn clone(&self) -> ExprNumberLiteral
fn clone(&self) -> ExprNumberLiteral
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprNumberLiteral
impl Debug for ExprNumberLiteral
Sourceimpl<'a> From<&'a ExprNumberLiteral> for AnyNodeRef<'a>
impl<'a> From<&'a ExprNumberLiteral> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprNumberLiteral) -> AnyNodeRef<'a>
fn from(node: &'a ExprNumberLiteral) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprNumberLiteral> for ExprRef<'a>
impl<'a> From<&'a ExprNumberLiteral> for ExprRef<'a>
Sourcefn from(node: &'a ExprNumberLiteral) -> ExprRef<'a>
fn from(node: &'a ExprNumberLiteral) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprNumberLiteral> for Expr
impl From<ExprNumberLiteral> for Expr
Sourcefn from(node: ExprNumberLiteral) -> Expr
fn from(node: ExprNumberLiteral) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprNumberLiteral
impl GetSize for ExprNumberLiteral
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprNumberLiteral
impl HasNodeIndex for ExprNumberLiteral
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprNumberLiteral
impl PartialEq for ExprNumberLiteral
Sourceimpl Ranged for ExprNumberLiteral
impl Ranged for ExprNumberLiteral
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprNumberLiteral
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprNumberLiteral
impl StructuralPartialEq for ExprNumberLiteral