pub struct ExprSetComp {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub elt: Box<Expr>,
pub generators: Vec<Comprehension>,
}Expand description
See also SetComp
Fields
node_index: AtomicNodeIndexrange: TextRangeelt: Box<Expr>generators: Vec<Comprehension>Trait Implementations
Sourceimpl Clone for ExprSetComp
impl Clone for ExprSetComp
Sourcefn clone(&self) -> ExprSetComp
fn clone(&self) -> ExprSetComp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprSetComp
impl Debug for ExprSetComp
Sourceimpl<'a> From<&'a ExprSetComp> for AnyNodeRef<'a>
impl<'a> From<&'a ExprSetComp> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprSetComp) -> AnyNodeRef<'a>
fn from(node: &'a ExprSetComp) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprSetComp> for ExprRef<'a>
impl<'a> From<&'a ExprSetComp> for ExprRef<'a>
Sourcefn from(node: &'a ExprSetComp) -> ExprRef<'a>
fn from(node: &'a ExprSetComp) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprSetComp> for Expr
impl From<ExprSetComp> for Expr
Sourcefn from(node: ExprSetComp) -> Expr
fn from(node: ExprSetComp) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprSetComp
impl GetSize for ExprSetComp
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprSetComp
impl HasNodeIndex for ExprSetComp
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprSetComp
impl PartialEq for ExprSetComp
Sourceimpl Ranged for ExprSetComp
impl Ranged for ExprSetComp
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprSetComp
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprSetComp
impl StructuralPartialEq for ExprSetComp