pub struct ExprSubscript {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: Box<Expr>,
pub slice: Box<Expr>,
pub ctx: ExprContext,
}Expand description
See also Subscript
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: Box<Expr>slice: Box<Expr>ctx: ExprContextTrait Implementations
Sourceimpl Clone for ExprSubscript
impl Clone for ExprSubscript
Sourcefn clone(&self) -> ExprSubscript
fn clone(&self) -> ExprSubscript
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprSubscript
impl Debug for ExprSubscript
Sourceimpl<'a> From<&'a ExprSubscript> for AnyNodeRef<'a>
impl<'a> From<&'a ExprSubscript> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprSubscript) -> AnyNodeRef<'a>
fn from(node: &'a ExprSubscript) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprSubscript> for ExprRef<'a>
impl<'a> From<&'a ExprSubscript> for ExprRef<'a>
Sourcefn from(node: &'a ExprSubscript) -> ExprRef<'a>
fn from(node: &'a ExprSubscript) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprSubscript> for Expr
impl From<ExprSubscript> for Expr
Sourcefn from(node: ExprSubscript) -> Expr
fn from(node: ExprSubscript) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprSubscript
impl GetSize for ExprSubscript
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprSubscript
impl HasNodeIndex for ExprSubscript
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprSubscript
impl PartialEq for ExprSubscript
Sourceimpl Ranged for ExprSubscript
impl Ranged for ExprSubscript
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprSubscript
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprSubscript
impl StructuralPartialEq for ExprSubscript