pub struct ExprTString {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: TStringValue,
}Expand description
An AST node that represents either a single-part t-string literal or an implicitly concatenated t-string literal.
This type differs from the original Python AST TemplateStr in that it
doesn’t join the implicitly concatenated parts into a single string. Instead,
it keeps them separate and provide various methods to access the parts.
See also TemplateStr
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: TStringValueImplementations
Sourceimpl ExprTString
impl ExprTString