pub struct ExprUnaryOp {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub op: UnaryOp,
pub operand: Box<Expr>,
}Expand description
See also UnaryOp
Fields
node_index: AtomicNodeIndexrange: TextRangeop: UnaryOpoperand: Box<Expr>Trait Implementations
Sourceimpl Clone for ExprUnaryOp
impl Clone for ExprUnaryOp
Sourcefn clone(&self) -> ExprUnaryOp
fn clone(&self) -> ExprUnaryOp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExprUnaryOp
impl Debug for ExprUnaryOp
Sourceimpl<'a> From<&'a ExprUnaryOp> for AnyNodeRef<'a>
impl<'a> From<&'a ExprUnaryOp> for AnyNodeRef<'a>
Sourcefn from(node: &'a ExprUnaryOp) -> AnyNodeRef<'a>
fn from(node: &'a ExprUnaryOp) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ExprUnaryOp> for ExprRef<'a>
impl<'a> From<&'a ExprUnaryOp> for ExprRef<'a>
Sourcefn from(node: &'a ExprUnaryOp) -> ExprRef<'a>
fn from(node: &'a ExprUnaryOp) -> ExprRef<'a>
Converts to this type from the input type.
Sourceimpl From<ExprUnaryOp> for Expr
impl From<ExprUnaryOp> for Expr
Sourcefn from(node: ExprUnaryOp) -> Expr
fn from(node: ExprUnaryOp) -> Expr
Converts to this type from the input type.
Sourceimpl GetSize for ExprUnaryOp
impl GetSize for ExprUnaryOp
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ExprUnaryOp
impl HasNodeIndex for ExprUnaryOp
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ExprUnaryOp
impl PartialEq for ExprUnaryOp
Sourceimpl Ranged for ExprUnaryOp
impl Ranged for ExprUnaryOp
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprUnaryOp
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ExprUnaryOp
impl StructuralPartialEq for ExprUnaryOp