pub struct FString {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub elements: InterpolatedStringElements,
pub flags: FStringFlags,
}Expand description
An AST node that represents a single f-string which is part of an ExprFString.
Fields
range: TextRangenode_index: AtomicNodeIndexelements: InterpolatedStringElementsflags: FStringFlagsTrait Implementations
Sourceimpl<'a> From<&'a FString> for AnyNodeRef<'a>
impl<'a> From<&'a FString> for AnyNodeRef<'a>
Sourcefn from(node: &'a FString) -> AnyNodeRef<'a>
fn from(node: &'a FString) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a FString> for AnyRootNodeRef<'a>
impl<'a> From<&'a FString> for AnyRootNodeRef<'a>
Sourcefn from(node: &'a FString) -> AnyRootNodeRef<'a>
fn from(node: &'a FString) -> AnyRootNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a FString> for StringLikePart<'a>
impl<'a> From<&'a FString> for StringLikePart<'a>
Sourcefn from(value: &'a FString) -> StringLikePart<'a>
fn from(value: &'a FString) -> StringLikePart<'a>
Converts to this type from the input type.
Sourceimpl GetSize for FString
impl GetSize for FString
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for FString
impl HasNodeIndex for FString
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a FString
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a FString
impl StructuralPartialEq for FString