pub struct InterpolatedElement {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub expression: Box<Expr>,
pub debug_text: Option<DebugText>,
pub conversion: ConversionFlag,
pub format_spec: Option<Box<InterpolatedStringFormatSpec>>,
}Expand description
See also FormattedValue
Fields
range: TextRangenode_index: AtomicNodeIndexexpression: Box<Expr>debug_text: Option<DebugText>conversion: ConversionFlagformat_spec: Option<Box<InterpolatedStringFormatSpec>>Trait Implementations
Sourceimpl Clone for InterpolatedElement
impl Clone for InterpolatedElement
Sourcefn clone(&self) -> InterpolatedElement
fn clone(&self) -> InterpolatedElement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InterpolatedElement
impl Debug for InterpolatedElement
Sourceimpl<'a> From<&'a InterpolatedElement> for AnyNodeRef<'a>
impl<'a> From<&'a InterpolatedElement> for AnyNodeRef<'a>
Sourcefn from(node: &'a InterpolatedElement) -> AnyNodeRef<'a>
fn from(node: &'a InterpolatedElement) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a InterpolatedElement> for ComparableInterpolatedStringElement<'a>
impl<'a> From<&'a InterpolatedElement> for ComparableInterpolatedStringElement<'a>
Sourcefn from(
interpolated_element: &'a InterpolatedElement,
) -> ComparableInterpolatedStringElement<'a>
fn from( interpolated_element: &'a InterpolatedElement, ) -> ComparableInterpolatedStringElement<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a InterpolatedElement> for InterpolatedElement<'a>
impl<'a> From<&'a InterpolatedElement> for InterpolatedElement<'a>
Sourcefn from(
interpolated_element: &'a InterpolatedElement,
) -> InterpolatedElement<'a>
fn from( interpolated_element: &'a InterpolatedElement, ) -> InterpolatedElement<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a InterpolatedElement> for InterpolatedStringElementRef<'a>
impl<'a> From<&'a InterpolatedElement> for InterpolatedStringElementRef<'a>
Sourcefn from(node: &'a InterpolatedElement) -> InterpolatedStringElementRef<'a>
fn from(node: &'a InterpolatedElement) -> InterpolatedStringElementRef<'a>
Converts to this type from the input type.
Sourceimpl From<InterpolatedElement> for InterpolatedStringElement
impl From<InterpolatedElement> for InterpolatedStringElement
Sourcefn from(node: InterpolatedElement) -> InterpolatedStringElement
fn from(node: InterpolatedElement) -> InterpolatedStringElement
Converts to this type from the input type.
Sourceimpl GetSize for InterpolatedElement
impl GetSize for InterpolatedElement
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for InterpolatedElement
impl HasNodeIndex for InterpolatedElement
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for InterpolatedElement
impl PartialEq for InterpolatedElement
Sourceimpl Ranged for InterpolatedElement
impl Ranged for InterpolatedElement
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a InterpolatedElement
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a InterpolatedElement
impl StructuralPartialEq for InterpolatedElement