pub struct InterpolatedStringFormatSpec {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub elements: InterpolatedStringElements,
}Fields
range: TextRangenode_index: AtomicNodeIndexelements: InterpolatedStringElementsTrait Implementations
Sourceimpl Clone for InterpolatedStringFormatSpec
impl Clone for InterpolatedStringFormatSpec
Sourcefn clone(&self) -> InterpolatedStringFormatSpec
fn clone(&self) -> InterpolatedStringFormatSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InterpolatedStringFormatSpec
impl Debug for InterpolatedStringFormatSpec
Sourceimpl<'a> From<&'a InterpolatedStringFormatSpec> for AnyNodeRef<'a>
impl<'a> From<&'a InterpolatedStringFormatSpec> for AnyNodeRef<'a>
Sourcefn from(node: &'a InterpolatedStringFormatSpec) -> AnyNodeRef<'a>
fn from(node: &'a InterpolatedStringFormatSpec) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a InterpolatedStringFormatSpec> for AnyRootNodeRef<'a>
impl<'a> From<&'a InterpolatedStringFormatSpec> for AnyRootNodeRef<'a>
Sourcefn from(node: &'a InterpolatedStringFormatSpec) -> AnyRootNodeRef<'a>
fn from(node: &'a InterpolatedStringFormatSpec) -> AnyRootNodeRef<'a>
Converts to this type from the input type.
Sourceimpl GetSize for InterpolatedStringFormatSpec
impl GetSize for InterpolatedStringFormatSpec
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for InterpolatedStringFormatSpec
impl HasNodeIndex for InterpolatedStringFormatSpec
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for InterpolatedStringFormatSpec
impl PartialEq for InterpolatedStringFormatSpec
Sourcefn eq(&self, other: &InterpolatedStringFormatSpec) -> bool
fn eq(&self, other: &InterpolatedStringFormatSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a InterpolatedStringFormatSpec
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a InterpolatedStringFormatSpec
impl StructuralPartialEq for InterpolatedStringFormatSpec