pub struct Keyword {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub arg: Option<Identifier>,
pub value: Expr,
}Expand description
See also keyword
Fields
range: TextRangenode_index: AtomicNodeIndexarg: Option<Identifier>value: ExprTrait Implementations
Sourceimpl<'a> From<&'a Keyword> for AnyNodeRef<'a>
impl<'a> From<&'a Keyword> for AnyNodeRef<'a>
Sourcefn from(node: &'a Keyword) -> AnyNodeRef<'a>
fn from(node: &'a Keyword) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a Keyword> for AnyRootNodeRef<'a>
impl<'a> From<&'a Keyword> for AnyRootNodeRef<'a>
Sourcefn from(node: &'a Keyword) -> AnyRootNodeRef<'a>
fn from(node: &'a Keyword) -> AnyRootNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a Keyword> for ArgOrKeyword<'a>
impl<'a> From<&'a Keyword> for ArgOrKeyword<'a>
Sourcefn from(keyword: &'a Keyword) -> ArgOrKeyword<'a>
fn from(keyword: &'a Keyword) -> ArgOrKeyword<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a Keyword> for ComparableKeyword<'a>
impl<'a> From<&'a Keyword> for ComparableKeyword<'a>
Sourcefn from(keyword: &'a Keyword) -> ComparableKeyword<'a>
fn from(keyword: &'a Keyword) -> ComparableKeyword<'a>
Converts to this type from the input type.
Sourceimpl GetSize for Keyword
impl GetSize for Keyword
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for Keyword
impl HasNodeIndex for Keyword
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a Keyword
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a Keyword
impl StructuralPartialEq for Keyword