pub struct MatchCase {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub pattern: Pattern,
pub guard: Option<Box<Expr>>,
pub body: Vec<Stmt>,
}Expand description
See also match_case
Fields
range: TextRangenode_index: AtomicNodeIndexpattern: Patternguard: Option<Box<Expr>>body: Vec<Stmt>Trait Implementations
Sourceimpl<'a> From<&'a MatchCase> for AnyNodeRef<'a>
impl<'a> From<&'a MatchCase> for AnyNodeRef<'a>
Sourcefn from(node: &'a MatchCase) -> AnyNodeRef<'a>
fn from(node: &'a MatchCase) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a MatchCase> for AnyRootNodeRef<'a>
impl<'a> From<&'a MatchCase> for AnyRootNodeRef<'a>
Sourcefn from(node: &'a MatchCase) -> AnyRootNodeRef<'a>
fn from(node: &'a MatchCase) -> AnyRootNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a MatchCase> for ComparableMatchCase<'a>
impl<'a> From<&'a MatchCase> for ComparableMatchCase<'a>
Sourcefn from(match_case: &'a MatchCase) -> ComparableMatchCase<'a>
fn from(match_case: &'a MatchCase) -> ComparableMatchCase<'a>
Converts to this type from the input type.
Sourceimpl GetSize for MatchCase
impl GetSize for MatchCase
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for MatchCase
impl HasNodeIndex for MatchCase
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a MatchCase
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a MatchCase
impl StructuralPartialEq for MatchCase