pub struct ModExpression {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub body: Box<Expr>,
}Expand description
See also Module
Fields
node_index: AtomicNodeIndexrange: TextRangebody: Box<Expr>Trait Implementations
Sourceimpl Clone for ModExpression
impl Clone for ModExpression
Sourcefn clone(&self) -> ModExpression
fn clone(&self) -> ModExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModExpression
impl Debug for ModExpression
Sourceimpl<'a> From<&'a ModExpression> for AnyNodeRef<'a>
impl<'a> From<&'a ModExpression> for AnyNodeRef<'a>
Sourcefn from(node: &'a ModExpression) -> AnyNodeRef<'a>
fn from(node: &'a ModExpression) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ModExpression> for ComparableModExpression<'a>
impl<'a> From<&'a ModExpression> for ComparableModExpression<'a>
Sourcefn from(expr: &'a ModExpression) -> ComparableModExpression<'a>
fn from(expr: &'a ModExpression) -> ComparableModExpression<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ModExpression> for ModRef<'a>
impl<'a> From<&'a ModExpression> for ModRef<'a>
Sourcefn from(node: &'a ModExpression) -> ModRef<'a>
fn from(node: &'a ModExpression) -> ModRef<'a>
Converts to this type from the input type.
Sourceimpl From<ModExpression> for Mod
impl From<ModExpression> for Mod
Sourcefn from(node: ModExpression) -> Mod
fn from(node: ModExpression) -> Mod
Converts to this type from the input type.
Sourceimpl GetSize for ModExpression
impl GetSize for ModExpression
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ModExpression
impl HasNodeIndex for ModExpression
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for ModExpression
impl PartialEq for ModExpression
Sourceimpl Ranged for ModExpression
impl Ranged for ModExpression
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ModExpression
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ModExpression
impl StructuralPartialEq for ModExpression