pub struct ModModule {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub body: Vec<Stmt>,
}Expand description
See also Module
Fields
node_index: AtomicNodeIndexrange: TextRangebody: Vec<Stmt>Trait Implementations
Sourceimpl<'a> From<&'a ModModule> for AnyNodeRef<'a>
impl<'a> From<&'a ModModule> for AnyNodeRef<'a>
Sourcefn from(node: &'a ModModule) -> AnyNodeRef<'a>
fn from(node: &'a ModModule) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a ModModule> for ComparableModModule<'a>
impl<'a> From<&'a ModModule> for ComparableModModule<'a>
Sourcefn from(module: &'a ModModule) -> ComparableModModule<'a>
fn from(module: &'a ModModule) -> ComparableModModule<'a>
Converts to this type from the input type.
Sourceimpl GetSize for ModModule
impl GetSize for ModModule
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for ModModule
impl HasNodeIndex for ModModule
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ModModule
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a ModModule
impl StructuralPartialEq for ModModule