NodeIndex

Struct NodeIndex 

pub struct NodeIndex(/* private fields */);
A unique index for a node within an AST.

Our encoding of 32-bit AST node indices is as follows:

  • u32::MAX (1111…1) is reserved as a forbidden value (mapped to 0 for NonZero)
  • u32::MAX - 1 (1111…0) is reserved for NodeIndex::NONE
  • The top two bits encode the sub-AST level:
    • 00 is top-level AST
    • 01 is sub-AST (string annotation)
    • 10 is sub-sub-AST (string annotation in string annotation)
    • 11 is forbidden (well, it only appears in the above reserved values)
  • The remaining 30 bits are the real (sub)-AST node index

To get the first sub-index of a node’s sub-AST we:

  • increment the sub-AST level in the high-bits
  • at level 1, multiply the real index by 256
  • at level 2, multiply the real index by 8

The multiplication gives each node a reserved space of 256 nodes for its sub-AST to work with (“should be enough for anybody”), and 8 nodes for a sub-sub-AST (enough for an identifier and maybe some simple unions).

Here are some implications:

  • We have 2^30 top-level AST nodes (1 billion)
  • To have a string annotation, the parent node needs to be multiplied by 256 without overflowing 30 bits, so string annotations cannot be used after 2^22 nodes (4 million), which would be like, a million lines of code.
  • To have a sub-string annotation, the top-level node needs to be multiplied by 256 * 8, so sub-string annotations cannot be used after 2^19 nodes (500 thousand), or about 100k lines of code.

This feels like a pretty reasonable compromise that will work well in practice, although it creates some very wonky boundary conditions that will be very unpleasant if someone runs into them.

That said, string annotations are in many regards “legacy” and so new code ideally doesn’t have to use them, and there’s never a real reason to use sub-annotation let-alone a sub-sub-annotation.

Implementations

Source

impl NodeIndex

pub const NONE: NodeIndex

A placeholder NodeIndex.

pub fn as_u32(self) -> Option<u32>

Returns the index as a u32. or None for NodeIndex::NONE.