pub struct Parameters {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub posonlyargs: Vec<ParameterWithDefault>,
pub args: Vec<ParameterWithDefault>,
pub vararg: Option<Box<Parameter>>,
pub kwonlyargs: Vec<ParameterWithDefault>,
pub kwarg: Option<Box<Parameter>>,
}Expand description
An alternative type of AST arguments. This is ruff_python_parser-friendly and human-friendly definition of function arguments.
This form also has advantage to implement pre-order traverse.
defaults and kw_defaults fields are removed and the default values are placed under each ParameterWithDefault typed argument.
vararg and kwarg are still typed as arg because they never can have a default value.
The original Python-style AST type orders kwonlyargs fields by default existence; Parameters has location-ordered kwonlyargs fields.
NOTE: This type differs from the original Python AST. See: arguments.
Fields
range: TextRangenode_index: AtomicNodeIndexposonlyargs: Vec<ParameterWithDefault>args: Vec<ParameterWithDefault>vararg: Option<Box<Parameter>>kwonlyargs: Vec<ParameterWithDefault>kwarg: Option<Box<Parameter>>Implementations
Sourceimpl Parameters
impl Parameters
Sourcepub fn iter_non_variadic_params(
&self,
) -> impl Iterator<Item = &ParameterWithDefault>
pub fn iter_non_variadic_params( &self, ) -> impl Iterator<Item = &ParameterWithDefault>
Returns an iterator over all non-variadic parameters included in this Parameters node.
The variadic parameters (.vararg and .kwarg) can never have default values;
non-variadic parameters sometimes will.
Sourcepub fn find(&self, name: &str) -> Option<&ParameterWithDefault>
pub fn find(&self, name: &str) -> Option<&ParameterWithDefault>
Returns the ParameterWithDefault with the given name, or None if no such ParameterWithDefault exists.
Sourcepub fn index(&self, name: &str) -> Option<usize>
pub fn index(&self, name: &str) -> Option<usize>
Returns the index of the parameter with the given name
Sourcepub fn iter(&self) -> ParametersIterator<'_> ⓘ
pub fn iter(&self) -> ParametersIterator<'_> ⓘ
Returns an iterator over all parameters included in this Parameters node.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the total number of parameters included in this Parameters node.
Sourcepub fn includes(&self, name: &str) -> bool
pub fn includes(&self, name: &str) -> bool
Returns true if a parameter with the given name is included in this Parameters.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the Parameters is empty.
Sourcepub fn iter_source_order(&self) -> ParametersSourceOrderIterator<'_> ⓘ
pub fn iter_source_order(&self) -> ParametersSourceOrderIterator<'_> ⓘ
Returns an iterator over all parameters in source order.
This differs from Parameters::iter which returns parameters
in type-based order (positional-only, regular, variadic, keyword-only,
keyword). For well-formed Python the two orderings are identical, but
error recovery can produce ASTs where variadic parameters appear before
non-variadic ones (e.g. def foo(**kwargs, a):).