pub struct PatternArguments {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub patterns: Vec<Pattern>,
pub keywords: Vec<PatternKeyword>,
}Expand description
An AST node to represent the arguments to a crate::PatternMatchClass, i.e., the
parenthesized contents in case Point(1, x=0, y=0).
Like Arguments, but for crate::PatternMatchClass.
Fields
range: TextRangenode_index: AtomicNodeIndexpatterns: Vec<Pattern>keywords: Vec<PatternKeyword>Implementations
Sourceimpl PatternArguments
impl PatternArguments
Sourcepub fn patterns_source_order(&self) -> PatternArgumentsSourceOrder<'_> ⓘ
pub fn patterns_source_order(&self) -> PatternArgumentsSourceOrder<'_> ⓘ
Returns an iterator over the patterns and keywords in source order.