pub struct PatternMatchAs {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub pattern: Option<Box<Pattern>>,
pub name: Option<Identifier>,
}Expand description
See also MatchAs
Fields
node_index: AtomicNodeIndexrange: TextRangepattern: Option<Box<Pattern>>name: Option<Identifier>Trait Implementations
Sourceimpl Clone for PatternMatchAs
impl Clone for PatternMatchAs
Sourcefn clone(&self) -> PatternMatchAs
fn clone(&self) -> PatternMatchAs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatternMatchAs
impl Debug for PatternMatchAs
Sourceimpl<'a> From<&'a PatternMatchAs> for AnyNodeRef<'a>
impl<'a> From<&'a PatternMatchAs> for AnyNodeRef<'a>
Sourcefn from(node: &'a PatternMatchAs) -> AnyNodeRef<'a>
fn from(node: &'a PatternMatchAs) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a PatternMatchAs> for PatternRef<'a>
impl<'a> From<&'a PatternMatchAs> for PatternRef<'a>
Sourcefn from(node: &'a PatternMatchAs) -> PatternRef<'a>
fn from(node: &'a PatternMatchAs) -> PatternRef<'a>
Converts to this type from the input type.
Sourceimpl From<PatternMatchAs> for Pattern
impl From<PatternMatchAs> for Pattern
Sourcefn from(node: PatternMatchAs) -> Pattern
fn from(node: PatternMatchAs) -> Pattern
Converts to this type from the input type.
Sourceimpl GetSize for PatternMatchAs
impl GetSize for PatternMatchAs
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for PatternMatchAs
impl HasNodeIndex for PatternMatchAs
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for PatternMatchAs
impl PartialEq for PatternMatchAs
Sourceimpl Ranged for PatternMatchAs
impl Ranged for PatternMatchAs
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchAs
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchAs
impl StructuralPartialEq for PatternMatchAs