pub struct PatternMatchClass {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub cls: Box<Expr>,
pub arguments: PatternArguments,
}Expand description
See also MatchClass
Fields
node_index: AtomicNodeIndexrange: TextRangecls: Box<Expr>arguments: PatternArgumentsTrait Implementations
Sourceimpl Clone for PatternMatchClass
impl Clone for PatternMatchClass
Sourcefn clone(&self) -> PatternMatchClass
fn clone(&self) -> PatternMatchClass
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatternMatchClass
impl Debug for PatternMatchClass
Sourceimpl<'a> From<&'a PatternMatchClass> for AnyNodeRef<'a>
impl<'a> From<&'a PatternMatchClass> for AnyNodeRef<'a>
Sourcefn from(node: &'a PatternMatchClass) -> AnyNodeRef<'a>
fn from(node: &'a PatternMatchClass) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a PatternMatchClass> for PatternRef<'a>
impl<'a> From<&'a PatternMatchClass> for PatternRef<'a>
Sourcefn from(node: &'a PatternMatchClass) -> PatternRef<'a>
fn from(node: &'a PatternMatchClass) -> PatternRef<'a>
Converts to this type from the input type.
Sourceimpl From<PatternMatchClass> for Pattern
impl From<PatternMatchClass> for Pattern
Sourcefn from(node: PatternMatchClass) -> Pattern
fn from(node: PatternMatchClass) -> Pattern
Converts to this type from the input type.
Sourceimpl GetSize for PatternMatchClass
impl GetSize for PatternMatchClass
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for PatternMatchClass
impl HasNodeIndex for PatternMatchClass
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for PatternMatchClass
impl PartialEq for PatternMatchClass
Sourceimpl Ranged for PatternMatchClass
impl Ranged for PatternMatchClass
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchClass
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchClass
impl StructuralPartialEq for PatternMatchClass