pub struct PatternMatchMapping {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub keys: Vec<Expr>,
pub patterns: Vec<Pattern>,
pub rest: Option<Identifier>,
}Expand description
See also MatchMapping
Fields
node_index: AtomicNodeIndexrange: TextRangekeys: Vec<Expr>patterns: Vec<Pattern>rest: Option<Identifier>Trait Implementations
Sourceimpl Clone for PatternMatchMapping
impl Clone for PatternMatchMapping
Sourcefn clone(&self) -> PatternMatchMapping
fn clone(&self) -> PatternMatchMapping
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatternMatchMapping
impl Debug for PatternMatchMapping
Sourceimpl<'a> From<&'a PatternMatchMapping> for AnyNodeRef<'a>
impl<'a> From<&'a PatternMatchMapping> for AnyNodeRef<'a>
Sourcefn from(node: &'a PatternMatchMapping) -> AnyNodeRef<'a>
fn from(node: &'a PatternMatchMapping) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a PatternMatchMapping> for PatternRef<'a>
impl<'a> From<&'a PatternMatchMapping> for PatternRef<'a>
Sourcefn from(node: &'a PatternMatchMapping) -> PatternRef<'a>
fn from(node: &'a PatternMatchMapping) -> PatternRef<'a>
Converts to this type from the input type.
Sourceimpl From<PatternMatchMapping> for Pattern
impl From<PatternMatchMapping> for Pattern
Sourcefn from(node: PatternMatchMapping) -> Pattern
fn from(node: PatternMatchMapping) -> Pattern
Converts to this type from the input type.
Sourceimpl GetSize for PatternMatchMapping
impl GetSize for PatternMatchMapping
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for PatternMatchMapping
impl HasNodeIndex for PatternMatchMapping
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for PatternMatchMapping
impl PartialEq for PatternMatchMapping
Sourceimpl Ranged for PatternMatchMapping
impl Ranged for PatternMatchMapping
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchMapping
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchMapping
impl StructuralPartialEq for PatternMatchMapping