pub struct PatternMatchOr {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub patterns: Vec<Pattern>,
}Expand description
See also MatchOr
Fields
node_index: AtomicNodeIndexrange: TextRangepatterns: Vec<Pattern>Trait Implementations
Sourceimpl Clone for PatternMatchOr
impl Clone for PatternMatchOr
Sourcefn clone(&self) -> PatternMatchOr
fn clone(&self) -> PatternMatchOr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatternMatchOr
impl Debug for PatternMatchOr
Sourceimpl<'a> From<&'a PatternMatchOr> for AnyNodeRef<'a>
impl<'a> From<&'a PatternMatchOr> for AnyNodeRef<'a>
Sourcefn from(node: &'a PatternMatchOr) -> AnyNodeRef<'a>
fn from(node: &'a PatternMatchOr) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a PatternMatchOr> for PatternRef<'a>
impl<'a> From<&'a PatternMatchOr> for PatternRef<'a>
Sourcefn from(node: &'a PatternMatchOr) -> PatternRef<'a>
fn from(node: &'a PatternMatchOr) -> PatternRef<'a>
Converts to this type from the input type.
Sourceimpl From<PatternMatchOr> for Pattern
impl From<PatternMatchOr> for Pattern
Sourcefn from(node: PatternMatchOr) -> Pattern
fn from(node: PatternMatchOr) -> Pattern
Converts to this type from the input type.
Sourceimpl GetSize for PatternMatchOr
impl GetSize for PatternMatchOr
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for PatternMatchOr
impl HasNodeIndex for PatternMatchOr
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for PatternMatchOr
impl PartialEq for PatternMatchOr
Sourceimpl Ranged for PatternMatchOr
impl Ranged for PatternMatchOr
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchOr
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchOr
impl StructuralPartialEq for PatternMatchOr