pub struct PatternMatchSingleton {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: Singleton,
}Expand description
See also MatchSingleton
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: SingletonTrait Implementations
Sourceimpl Clone for PatternMatchSingleton
impl Clone for PatternMatchSingleton
Sourcefn clone(&self) -> PatternMatchSingleton
fn clone(&self) -> PatternMatchSingleton
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatternMatchSingleton
impl Debug for PatternMatchSingleton
Sourceimpl<'a> From<&'a PatternMatchSingleton> for AnyNodeRef<'a>
impl<'a> From<&'a PatternMatchSingleton> for AnyNodeRef<'a>
Sourcefn from(node: &'a PatternMatchSingleton) -> AnyNodeRef<'a>
fn from(node: &'a PatternMatchSingleton) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a PatternMatchSingleton> for PatternRef<'a>
impl<'a> From<&'a PatternMatchSingleton> for PatternRef<'a>
Sourcefn from(node: &'a PatternMatchSingleton) -> PatternRef<'a>
fn from(node: &'a PatternMatchSingleton) -> PatternRef<'a>
Converts to this type from the input type.
Sourceimpl From<PatternMatchSingleton> for Pattern
impl From<PatternMatchSingleton> for Pattern
Sourcefn from(node: PatternMatchSingleton) -> Pattern
fn from(node: PatternMatchSingleton) -> Pattern
Converts to this type from the input type.
Sourceimpl GetSize for PatternMatchSingleton
impl GetSize for PatternMatchSingleton
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for PatternMatchSingleton
impl HasNodeIndex for PatternMatchSingleton
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for PatternMatchSingleton
impl PartialEq for PatternMatchSingleton
Sourceimpl Ranged for PatternMatchSingleton
impl Ranged for PatternMatchSingleton
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchSingleton
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchSingleton
impl StructuralPartialEq for PatternMatchSingleton