pub struct PatternMatchStar {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub name: Option<Identifier>,
}Expand description
See also MatchStar
Fields
node_index: AtomicNodeIndexrange: TextRangename: Option<Identifier>Trait Implementations
Sourceimpl Clone for PatternMatchStar
impl Clone for PatternMatchStar
Sourcefn clone(&self) -> PatternMatchStar
fn clone(&self) -> PatternMatchStar
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatternMatchStar
impl Debug for PatternMatchStar
Sourceimpl<'a> From<&'a PatternMatchStar> for AnyNodeRef<'a>
impl<'a> From<&'a PatternMatchStar> for AnyNodeRef<'a>
Sourcefn from(node: &'a PatternMatchStar) -> AnyNodeRef<'a>
fn from(node: &'a PatternMatchStar) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a PatternMatchStar> for PatternRef<'a>
impl<'a> From<&'a PatternMatchStar> for PatternRef<'a>
Sourcefn from(node: &'a PatternMatchStar) -> PatternRef<'a>
fn from(node: &'a PatternMatchStar) -> PatternRef<'a>
Converts to this type from the input type.
Sourceimpl From<PatternMatchStar> for Pattern
impl From<PatternMatchStar> for Pattern
Sourcefn from(node: PatternMatchStar) -> Pattern
fn from(node: PatternMatchStar) -> Pattern
Converts to this type from the input type.
Sourceimpl GetSize for PatternMatchStar
impl GetSize for PatternMatchStar
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for PatternMatchStar
impl HasNodeIndex for PatternMatchStar
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for PatternMatchStar
impl PartialEq for PatternMatchStar
Sourceimpl Ranged for PatternMatchStar
impl Ranged for PatternMatchStar
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchStar
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchStar
impl StructuralPartialEq for PatternMatchStar