pub struct PatternMatchValue {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: Box<Expr>,
}Expand description
See also MatchValue
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: Box<Expr>Trait Implementations
Sourceimpl Clone for PatternMatchValue
impl Clone for PatternMatchValue
Sourcefn clone(&self) -> PatternMatchValue
fn clone(&self) -> PatternMatchValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatternMatchValue
impl Debug for PatternMatchValue
Sourceimpl<'a> From<&'a PatternMatchValue> for AnyNodeRef<'a>
impl<'a> From<&'a PatternMatchValue> for AnyNodeRef<'a>
Sourcefn from(node: &'a PatternMatchValue) -> AnyNodeRef<'a>
fn from(node: &'a PatternMatchValue) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a PatternMatchValue> for PatternRef<'a>
impl<'a> From<&'a PatternMatchValue> for PatternRef<'a>
Sourcefn from(node: &'a PatternMatchValue) -> PatternRef<'a>
fn from(node: &'a PatternMatchValue) -> PatternRef<'a>
Converts to this type from the input type.
Sourceimpl From<PatternMatchValue> for Pattern
impl From<PatternMatchValue> for Pattern
Sourcefn from(node: PatternMatchValue) -> Pattern
fn from(node: PatternMatchValue) -> Pattern
Converts to this type from the input type.
Sourceimpl GetSize for PatternMatchValue
impl GetSize for PatternMatchValue
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for PatternMatchValue
impl HasNodeIndex for PatternMatchValue
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for PatternMatchValue
impl PartialEq for PatternMatchValue
Sourceimpl Ranged for PatternMatchValue
impl Ranged for PatternMatchValue
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchValue
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a PatternMatchValue
impl StructuralPartialEq for PatternMatchValue