pub struct StmtAnnAssign {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub target: Box<Expr>,
pub annotation: Box<Expr>,
pub value: Option<Box<Expr>>,
pub simple: bool,
}Expand description
See also AnnAssign
Fields
node_index: AtomicNodeIndexrange: TextRangetarget: Box<Expr>annotation: Box<Expr>value: Option<Box<Expr>>simple: boolTrait Implementations
Sourceimpl Clone for StmtAnnAssign
impl Clone for StmtAnnAssign
Sourcefn clone(&self) -> StmtAnnAssign
fn clone(&self) -> StmtAnnAssign
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtAnnAssign
impl Debug for StmtAnnAssign
Sourceimpl<'a> From<&'a StmtAnnAssign> for AnyNodeRef<'a>
impl<'a> From<&'a StmtAnnAssign> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtAnnAssign) -> AnyNodeRef<'a>
fn from(node: &'a StmtAnnAssign) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtAnnAssign> for StmtRef<'a>
impl<'a> From<&'a StmtAnnAssign> for StmtRef<'a>
Sourcefn from(node: &'a StmtAnnAssign) -> StmtRef<'a>
fn from(node: &'a StmtAnnAssign) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtAnnAssign> for Stmt
impl From<StmtAnnAssign> for Stmt
Sourcefn from(node: StmtAnnAssign) -> Stmt
fn from(node: StmtAnnAssign) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtAnnAssign
impl GetSize for StmtAnnAssign
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtAnnAssign
impl HasNodeIndex for StmtAnnAssign
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtAnnAssign
impl PartialEq for StmtAnnAssign
Sourceimpl Ranged for StmtAnnAssign
impl Ranged for StmtAnnAssign
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtAnnAssign
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtAnnAssign
impl StructuralPartialEq for StmtAnnAssign