pub struct StmtAssert {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub test: Box<Expr>,
pub msg: Option<Box<Expr>>,
}Expand description
See also Assert
Fields
node_index: AtomicNodeIndexrange: TextRangetest: Box<Expr>msg: Option<Box<Expr>>Trait Implementations
Sourceimpl Clone for StmtAssert
impl Clone for StmtAssert
Sourcefn clone(&self) -> StmtAssert
fn clone(&self) -> StmtAssert
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtAssert
impl Debug for StmtAssert
Sourceimpl<'a> From<&'a StmtAssert> for AnyNodeRef<'a>
impl<'a> From<&'a StmtAssert> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtAssert) -> AnyNodeRef<'a>
fn from(node: &'a StmtAssert) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtAssert> for StmtRef<'a>
impl<'a> From<&'a StmtAssert> for StmtRef<'a>
Sourcefn from(node: &'a StmtAssert) -> StmtRef<'a>
fn from(node: &'a StmtAssert) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtAssert> for Stmt
impl From<StmtAssert> for Stmt
Sourcefn from(node: StmtAssert) -> Stmt
fn from(node: StmtAssert) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtAssert
impl GetSize for StmtAssert
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtAssert
impl HasNodeIndex for StmtAssert
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtAssert
impl PartialEq for StmtAssert
Sourceimpl Ranged for StmtAssert
impl Ranged for StmtAssert
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtAssert
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtAssert
impl StructuralPartialEq for StmtAssert