pub struct StmtAssign {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub targets: Vec<Expr>,
pub value: Box<Expr>,
}Expand description
See also Assign
Fields
node_index: AtomicNodeIndexrange: TextRangetargets: Vec<Expr>value: Box<Expr>Trait Implementations
Sourceimpl Clone for StmtAssign
impl Clone for StmtAssign
Sourcefn clone(&self) -> StmtAssign
fn clone(&self) -> StmtAssign
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtAssign
impl Debug for StmtAssign
Sourceimpl<'a> From<&'a StmtAssign> for AnyNodeRef<'a>
impl<'a> From<&'a StmtAssign> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtAssign) -> AnyNodeRef<'a>
fn from(node: &'a StmtAssign) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtAssign> for StmtRef<'a>
impl<'a> From<&'a StmtAssign> for StmtRef<'a>
Sourcefn from(node: &'a StmtAssign) -> StmtRef<'a>
fn from(node: &'a StmtAssign) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtAssign> for Stmt
impl From<StmtAssign> for Stmt
Sourcefn from(node: StmtAssign) -> Stmt
fn from(node: StmtAssign) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtAssign
impl GetSize for StmtAssign
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtAssign
impl HasNodeIndex for StmtAssign
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtAssign
impl PartialEq for StmtAssign
Sourceimpl Ranged for StmtAssign
impl Ranged for StmtAssign
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtAssign
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtAssign
impl StructuralPartialEq for StmtAssign