pub struct StmtAugAssign {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub target: Box<Expr>,
pub op: Operator,
pub value: Box<Expr>,
}Expand description
See also AugAssign
Fields
node_index: AtomicNodeIndexrange: TextRangetarget: Box<Expr>op: Operatorvalue: Box<Expr>Trait Implementations
Sourceimpl Clone for StmtAugAssign
impl Clone for StmtAugAssign
Sourcefn clone(&self) -> StmtAugAssign
fn clone(&self) -> StmtAugAssign
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtAugAssign
impl Debug for StmtAugAssign
Sourceimpl<'a> From<&'a StmtAugAssign> for AnyNodeRef<'a>
impl<'a> From<&'a StmtAugAssign> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtAugAssign) -> AnyNodeRef<'a>
fn from(node: &'a StmtAugAssign) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtAugAssign> for StmtRef<'a>
impl<'a> From<&'a StmtAugAssign> for StmtRef<'a>
Sourcefn from(node: &'a StmtAugAssign) -> StmtRef<'a>
fn from(node: &'a StmtAugAssign) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtAugAssign> for Stmt
impl From<StmtAugAssign> for Stmt
Sourcefn from(node: StmtAugAssign) -> Stmt
fn from(node: StmtAugAssign) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtAugAssign
impl GetSize for StmtAugAssign
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtAugAssign
impl HasNodeIndex for StmtAugAssign
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtAugAssign
impl PartialEq for StmtAugAssign
Sourceimpl Ranged for StmtAugAssign
impl Ranged for StmtAugAssign
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtAugAssign
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtAugAssign
impl StructuralPartialEq for StmtAugAssign