pub struct StmtContinue {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
}Expand description
See also Continue
Fields
node_index: AtomicNodeIndexrange: TextRangeTrait Implementations
Sourceimpl Clone for StmtContinue
impl Clone for StmtContinue
Sourcefn clone(&self) -> StmtContinue
fn clone(&self) -> StmtContinue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtContinue
impl Debug for StmtContinue
Sourceimpl<'a> From<&'a StmtContinue> for AnyNodeRef<'a>
impl<'a> From<&'a StmtContinue> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtContinue) -> AnyNodeRef<'a>
fn from(node: &'a StmtContinue) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtContinue> for StmtRef<'a>
impl<'a> From<&'a StmtContinue> for StmtRef<'a>
Sourcefn from(node: &'a StmtContinue) -> StmtRef<'a>
fn from(node: &'a StmtContinue) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtContinue> for Stmt
impl From<StmtContinue> for Stmt
Sourcefn from(node: StmtContinue) -> Stmt
fn from(node: StmtContinue) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtContinue
impl GetSize for StmtContinue
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtContinue
impl HasNodeIndex for StmtContinue
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtContinue
impl PartialEq for StmtContinue
Sourceimpl Ranged for StmtContinue
impl Ranged for StmtContinue
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtContinue
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtContinue
impl StructuralPartialEq for StmtContinue