pub struct StmtDelete {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub targets: Vec<Expr>,
}Expand description
See also Delete
Fields
node_index: AtomicNodeIndexrange: TextRangetargets: Vec<Expr>Trait Implementations
Sourceimpl Clone for StmtDelete
impl Clone for StmtDelete
Sourcefn clone(&self) -> StmtDelete
fn clone(&self) -> StmtDelete
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtDelete
impl Debug for StmtDelete
Sourceimpl<'a> From<&'a StmtDelete> for AnyNodeRef<'a>
impl<'a> From<&'a StmtDelete> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtDelete) -> AnyNodeRef<'a>
fn from(node: &'a StmtDelete) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtDelete> for StmtRef<'a>
impl<'a> From<&'a StmtDelete> for StmtRef<'a>
Sourcefn from(node: &'a StmtDelete) -> StmtRef<'a>
fn from(node: &'a StmtDelete) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtDelete> for Stmt
impl From<StmtDelete> for Stmt
Sourcefn from(node: StmtDelete) -> Stmt
fn from(node: StmtDelete) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtDelete
impl GetSize for StmtDelete
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtDelete
impl HasNodeIndex for StmtDelete
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtDelete
impl PartialEq for StmtDelete
Sourceimpl Ranged for StmtDelete
impl Ranged for StmtDelete
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtDelete
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtDelete
impl StructuralPartialEq for StmtDelete