pub struct StmtFor {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub is_async: bool,
pub target: Box<Expr>,
pub iter: Box<Expr>,
pub body: Vec<Stmt>,
pub orelse: Vec<Stmt>,
}Expand description
Fields
node_index: AtomicNodeIndexrange: TextRangeis_async: booltarget: Box<Expr>iter: Box<Expr>body: Vec<Stmt>orelse: Vec<Stmt>Trait Implementations
Sourceimpl<'a> From<&'a StmtFor> for AnyNodeRef<'a>
impl<'a> From<&'a StmtFor> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtFor) -> AnyNodeRef<'a>
fn from(node: &'a StmtFor) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl GetSize for StmtFor
impl GetSize for StmtFor
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtFor
impl HasNodeIndex for StmtFor
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtFor
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtFor
impl StructuralPartialEq for StmtFor