pub struct StmtFunctionDef {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub is_async: bool,
pub decorator_list: Vec<Decorator>,
pub name: Identifier,
pub type_params: Option<Box<TypeParams>>,
pub parameters: Box<Parameters>,
pub returns: Option<Box<Expr>>,
pub body: Vec<Stmt>,
}Expand description
See also FunctionDef and AsyncFunctionDef.
This type differs from the original Python AST, as it collapses the synchronous and asynchronous variants into a single type.
Fields
node_index: AtomicNodeIndexrange: TextRangeis_async: booldecorator_list: Vec<Decorator>name: Identifiertype_params: Option<Box<TypeParams>>parameters: Box<Parameters>returns: Option<Box<Expr>>body: Vec<Stmt>Trait Implementations
Sourceimpl Clone for StmtFunctionDef
impl Clone for StmtFunctionDef
Sourcefn clone(&self) -> StmtFunctionDef
fn clone(&self) -> StmtFunctionDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtFunctionDef
impl Debug for StmtFunctionDef
Sourceimpl<'a> From<&'a StmtFunctionDef> for AnyNodeRef<'a>
impl<'a> From<&'a StmtFunctionDef> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtFunctionDef) -> AnyNodeRef<'a>
fn from(node: &'a StmtFunctionDef) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtFunctionDef> for StmtRef<'a>
impl<'a> From<&'a StmtFunctionDef> for StmtRef<'a>
Sourcefn from(node: &'a StmtFunctionDef) -> StmtRef<'a>
fn from(node: &'a StmtFunctionDef) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtFunctionDef> for Stmt
impl From<StmtFunctionDef> for Stmt
Sourcefn from(node: StmtFunctionDef) -> Stmt
fn from(node: StmtFunctionDef) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtFunctionDef
impl GetSize for StmtFunctionDef
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtFunctionDef
impl HasNodeIndex for StmtFunctionDef
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl Identifier for StmtFunctionDef
impl Identifier for StmtFunctionDef
Sourcefn identifier(&self) -> TextRange
fn identifier(&self) -> TextRange
Return the TextRange of the identifier in the given function definition.
For example, return the range of f in:
def f():
...Sourceimpl PartialEq for StmtFunctionDef
impl PartialEq for StmtFunctionDef
Sourceimpl Ranged for StmtFunctionDef
impl Ranged for StmtFunctionDef
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtFunctionDef
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtFunctionDef
impl StructuralPartialEq for StmtFunctionDef