pub struct StmtNonlocal {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub names: Vec<Identifier>,
}Expand description
See also Nonlocal
Fields
node_index: AtomicNodeIndexrange: TextRangenames: Vec<Identifier>Trait Implementations
Sourceimpl Clone for StmtNonlocal
impl Clone for StmtNonlocal
Sourcefn clone(&self) -> StmtNonlocal
fn clone(&self) -> StmtNonlocal
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtNonlocal
impl Debug for StmtNonlocal
Sourceimpl<'a> From<&'a StmtNonlocal> for AnyNodeRef<'a>
impl<'a> From<&'a StmtNonlocal> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtNonlocal) -> AnyNodeRef<'a>
fn from(node: &'a StmtNonlocal) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtNonlocal> for StmtRef<'a>
impl<'a> From<&'a StmtNonlocal> for StmtRef<'a>
Sourcefn from(node: &'a StmtNonlocal) -> StmtRef<'a>
fn from(node: &'a StmtNonlocal) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtNonlocal> for Stmt
impl From<StmtNonlocal> for Stmt
Sourcefn from(node: StmtNonlocal) -> Stmt
fn from(node: StmtNonlocal) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtNonlocal
impl GetSize for StmtNonlocal
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtNonlocal
impl HasNodeIndex for StmtNonlocal
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtNonlocal
impl PartialEq for StmtNonlocal
Sourceimpl Ranged for StmtNonlocal
impl Ranged for StmtNonlocal
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtNonlocal
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtNonlocal
impl StructuralPartialEq for StmtNonlocal