pub struct StmtRaise {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub exc: Option<Box<Expr>>,
pub cause: Option<Box<Expr>>,
}Expand description
See also Raise
Fields
node_index: AtomicNodeIndexrange: TextRangeexc: Option<Box<Expr>>cause: Option<Box<Expr>>Trait Implementations
Sourceimpl<'a> From<&'a StmtRaise> for AnyNodeRef<'a>
impl<'a> From<&'a StmtRaise> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtRaise) -> AnyNodeRef<'a>
fn from(node: &'a StmtRaise) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl GetSize for StmtRaise
impl GetSize for StmtRaise
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtRaise
impl HasNodeIndex for StmtRaise
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtRaise
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtRaise
impl StructuralPartialEq for StmtRaise