pub struct StmtReturn {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: Option<Box<Expr>>,
}Expand description
See also Return
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: Option<Box<Expr>>Trait Implementations
Sourceimpl Clone for StmtReturn
impl Clone for StmtReturn
Sourcefn clone(&self) -> StmtReturn
fn clone(&self) -> StmtReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtReturn
impl Debug for StmtReturn
Sourceimpl<'a> From<&'a StmtReturn> for AnyNodeRef<'a>
impl<'a> From<&'a StmtReturn> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtReturn) -> AnyNodeRef<'a>
fn from(node: &'a StmtReturn) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtReturn> for StmtRef<'a>
impl<'a> From<&'a StmtReturn> for StmtRef<'a>
Sourcefn from(node: &'a StmtReturn) -> StmtRef<'a>
fn from(node: &'a StmtReturn) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtReturn> for Stmt
impl From<StmtReturn> for Stmt
Sourcefn from(node: StmtReturn) -> Stmt
fn from(node: StmtReturn) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtReturn
impl GetSize for StmtReturn
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtReturn
impl HasNodeIndex for StmtReturn
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtReturn
impl PartialEq for StmtReturn
Sourceimpl Ranged for StmtReturn
impl Ranged for StmtReturn
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtReturn
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtReturn
impl StructuralPartialEq for StmtReturn