pub struct StmtTry {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub body: Vec<Stmt>,
pub handlers: Vec<ExceptHandler>,
pub orelse: Vec<Stmt>,
pub finalbody: Vec<Stmt>,
pub is_star: bool,
}Fields
node_index: AtomicNodeIndexrange: TextRangebody: Vec<Stmt>handlers: Vec<ExceptHandler>orelse: Vec<Stmt>finalbody: Vec<Stmt>is_star: boolTrait Implementations
Sourceimpl<'a> From<&'a StmtTry> for AnyNodeRef<'a>
impl<'a> From<&'a StmtTry> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtTry) -> AnyNodeRef<'a>
fn from(node: &'a StmtTry) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl GetSize for StmtTry
impl GetSize for StmtTry
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtTry
impl HasNodeIndex for StmtTry
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtTry
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtTry
impl StructuralPartialEq for StmtTry