pub struct StmtTypeAlias {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub name: Box<Expr>,
pub type_params: Option<Box<TypeParams>>,
pub value: Box<Expr>,
}Expand description
See also TypeAlias
Fields
node_index: AtomicNodeIndexrange: TextRangename: Box<Expr>type_params: Option<Box<TypeParams>>value: Box<Expr>Trait Implementations
Sourceimpl Clone for StmtTypeAlias
impl Clone for StmtTypeAlias
Sourcefn clone(&self) -> StmtTypeAlias
fn clone(&self) -> StmtTypeAlias
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StmtTypeAlias
impl Debug for StmtTypeAlias
Sourceimpl<'a> From<&'a StmtTypeAlias> for AnyNodeRef<'a>
impl<'a> From<&'a StmtTypeAlias> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtTypeAlias) -> AnyNodeRef<'a>
fn from(node: &'a StmtTypeAlias) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a StmtTypeAlias> for StmtRef<'a>
impl<'a> From<&'a StmtTypeAlias> for StmtRef<'a>
Sourcefn from(node: &'a StmtTypeAlias) -> StmtRef<'a>
fn from(node: &'a StmtTypeAlias) -> StmtRef<'a>
Converts to this type from the input type.
Sourceimpl From<StmtTypeAlias> for Stmt
impl From<StmtTypeAlias> for Stmt
Sourcefn from(node: StmtTypeAlias) -> Stmt
fn from(node: StmtTypeAlias) -> Stmt
Converts to this type from the input type.
Sourceimpl GetSize for StmtTypeAlias
impl GetSize for StmtTypeAlias
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtTypeAlias
impl HasNodeIndex for StmtTypeAlias
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for StmtTypeAlias
impl PartialEq for StmtTypeAlias
Sourceimpl Ranged for StmtTypeAlias
impl Ranged for StmtTypeAlias
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtTypeAlias
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtTypeAlias
impl StructuralPartialEq for StmtTypeAlias