pub struct StmtWhile {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub test: Box<Expr>,
pub body: Vec<Stmt>,
pub orelse: Vec<Stmt>,
}Expand description
See also While and AsyncWhile.
Fields
node_index: AtomicNodeIndexrange: TextRangetest: Box<Expr>body: Vec<Stmt>orelse: Vec<Stmt>Trait Implementations
Sourceimpl<'a> From<&'a StmtWhile> for AnyNodeRef<'a>
impl<'a> From<&'a StmtWhile> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtWhile) -> AnyNodeRef<'a>
fn from(node: &'a StmtWhile) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl GetSize for StmtWhile
impl GetSize for StmtWhile
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtWhile
impl HasNodeIndex for StmtWhile
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtWhile
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtWhile
impl StructuralPartialEq for StmtWhile