pub struct StmtWith {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub is_async: bool,
pub items: Vec<WithItem>,
pub body: Vec<Stmt>,
}Expand description
Fields
node_index: AtomicNodeIndexrange: TextRangeis_async: boolitems: Vec<WithItem>body: Vec<Stmt>Trait Implementations
Sourceimpl<'a> From<&'a StmtWith> for AnyNodeRef<'a>
impl<'a> From<&'a StmtWith> for AnyNodeRef<'a>
Sourcefn from(node: &'a StmtWith) -> AnyNodeRef<'a>
fn from(node: &'a StmtWith) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl GetSize for StmtWith
impl GetSize for StmtWith
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for StmtWith
impl HasNodeIndex for StmtWith
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtWith
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a StmtWith
impl StructuralPartialEq for StmtWith