StringLiteralValue

Struct StringLiteralValue 

pub struct StringLiteralValue { /* private fields */ }
The value representing a ExprStringLiteral.

Implementations

Source

impl StringLiteralValue

pub fn single(string: StringLiteral) -> StringLiteralValue

Creates a new string literal with a single StringLiteral part.

pub fn first_literal_flags(&self) -> StringLiteralFlags

Returns the StringLiteralFlags associated with this string literal.

For an implicitly concatenated string, it returns the flags for the first literal.

pub fn concatenated(strings: Vec<StringLiteral>) -> StringLiteralValue

Creates a new string literal with the given values that represents an implicitly concatenated strings.

Panics

Panics if strings has less than 2 elements. Use StringLiteralValue::single instead.

pub const fn is_implicit_concatenated(&self) -> bool

Returns true if the string literal is implicitly concatenated.

pub fn is_unicode(&self) -> bool

Returns true if the string literal has a u prefix, e.g. u"foo".

Although all strings in Python 3 are valid unicode (and the u prefix is only retained for backwards compatibility), these strings are known as “unicode strings”.

For an implicitly concatenated string, it returns true only if the first StringLiteral has the u prefix.

pub fn as_slice(&self) -> &[StringLiteral]

Returns a slice of all the StringLiteral parts contained in this value.

pub fn iter(&self) -> Iter<'_, StringLiteral>

Returns an iterator over all the StringLiteral parts contained in this value.

pub fn iter_mut(&mut self) -> IterMut<'_, StringLiteral>

Returns an iterator over all the StringLiteral parts contained in this value that allows modification.

pub fn is_empty(&self) -> bool

Returns true if the node represents an empty string.

Note that a StringLiteralValue node will always have >=1 StringLiteral parts inside it. This method checks whether the value of the concatenated parts is equal to the empty string, not whether the string has 0 parts inside it.

pub fn len(&self) -> usize

Returns the total length of the string literal value, in bytes, not chars or graphemes.

pub fn chars(&self) -> impl Iterator<Item = char> + Clone

Returns an iterator over the chars of each string literal part.

pub fn to_str(&self) -> &str

Returns the concatenated string value as a str.

Note that this will perform an allocation on the first invocation if the string value is implicitly concatenated.