TStringValue

Struct TStringValue 

pub struct TStringValue { /* private fields */ }
The value representing an ExprTString.

Implementations

Source

impl TStringValue

pub fn single(value: TString) -> TStringValue

Creates a new t-string literal with a single TString part.

pub fn concatenated(values: Vec<TString>) -> TStringValue

Creates a new t-string with the given values that represents an implicitly concatenated t-string.

Panics

Panics if values has less than 2 elements. Use TStringValue::single instead.

pub fn is_implicit_concatenated(&self) -> bool

Returns true if the t-string is implicitly concatenated, false otherwise.

pub fn as_slice(&self) -> &[TString]

Returns a slice of all the TStrings contained in this value.

pub fn iter(&self) -> Iter<'_, TString>

Returns an iterator over all the TStrings contained in this value.

pub fn iter_mut(&mut self) -> IterMut<'_, TString>

Returns an iterator over all the TStrings contained in this value that allows modification.

pub fn elements(&self) -> impl Iterator<Item = &InterpolatedStringElement>

Returns an iterator over all the InterpolatedStringElement contained in this value.

An interpolated string element is what makes up an TString i.e., it is either a string literal or an interpolation. In the following example,

t"foo" t"bar {x}" t"baz" t"qux"

The interpolated string elements returned would be string literal ("bar "), interpolation (x) and string literal ("qux").

pub fn is_empty_iterable(&self) -> bool

Returns true if the node represents an empty t-string in the sense that __iter__ returns an empty iterable.

Beware that empty t-strings are still truthy, i.e. bool(t"") == True.

Note that a TStringValue node will always contain at least one TString node. This method checks whether each of the constituent t-strings (in an implicitly concatenated t-string) are empty in the above sense.