pub struct TypeParamTypeVarTuple {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub name: Identifier,
pub default: Option<Box<Expr>>,
}Expand description
See also TypeVarTuple
Fields
node_index: AtomicNodeIndexrange: TextRangename: Identifierdefault: Option<Box<Expr>>Trait Implementations
Sourceimpl Clone for TypeParamTypeVarTuple
impl Clone for TypeParamTypeVarTuple
Sourcefn clone(&self) -> TypeParamTypeVarTuple
fn clone(&self) -> TypeParamTypeVarTuple
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypeParamTypeVarTuple
impl Debug for TypeParamTypeVarTuple
Sourceimpl<'a> From<&'a TypeParamTypeVarTuple> for AnyNodeRef<'a>
impl<'a> From<&'a TypeParamTypeVarTuple> for AnyNodeRef<'a>
Sourcefn from(node: &'a TypeParamTypeVarTuple) -> AnyNodeRef<'a>
fn from(node: &'a TypeParamTypeVarTuple) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a TypeParamTypeVarTuple> for TypeParamRef<'a>
impl<'a> From<&'a TypeParamTypeVarTuple> for TypeParamRef<'a>
Sourcefn from(node: &'a TypeParamTypeVarTuple) -> TypeParamRef<'a>
fn from(node: &'a TypeParamTypeVarTuple) -> TypeParamRef<'a>
Converts to this type from the input type.
Sourceimpl From<TypeParamTypeVarTuple> for TypeParam
impl From<TypeParamTypeVarTuple> for TypeParam
Sourcefn from(node: TypeParamTypeVarTuple) -> TypeParam
fn from(node: TypeParamTypeVarTuple) -> TypeParam
Converts to this type from the input type.
Sourceimpl GetSize for TypeParamTypeVarTuple
impl GetSize for TypeParamTypeVarTuple
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for TypeParamTypeVarTuple
impl HasNodeIndex for TypeParamTypeVarTuple
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl PartialEq for TypeParamTypeVarTuple
impl PartialEq for TypeParamTypeVarTuple
Sourceimpl Ranged for TypeParamTypeVarTuple
impl Ranged for TypeParamTypeVarTuple
Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a TypeParamTypeVarTuple
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a TypeParamTypeVarTuple
impl StructuralPartialEq for TypeParamTypeVarTuple