pub struct WithItem {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub context_expr: Expr,
pub optional_vars: Option<Box<Expr>>,
}Expand description
See also withitem
Fields
range: TextRangenode_index: AtomicNodeIndexcontext_expr: Exproptional_vars: Option<Box<Expr>>Trait Implementations
Sourceimpl<'a> From<&'a WithItem> for AnyNodeRef<'a>
impl<'a> From<&'a WithItem> for AnyNodeRef<'a>
Sourcefn from(node: &'a WithItem) -> AnyNodeRef<'a>
fn from(node: &'a WithItem) -> AnyNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a WithItem> for AnyRootNodeRef<'a>
impl<'a> From<&'a WithItem> for AnyRootNodeRef<'a>
Sourcefn from(node: &'a WithItem) -> AnyRootNodeRef<'a>
fn from(node: &'a WithItem) -> AnyRootNodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a WithItem> for ComparableWithItem<'a>
impl<'a> From<&'a WithItem> for ComparableWithItem<'a>
Sourcefn from(with_item: &'a WithItem) -> ComparableWithItem<'a>
fn from(with_item: &'a WithItem) -> ComparableWithItem<'a>
Converts to this type from the input type.
Sourceimpl GetSize for WithItem
impl GetSize for WithItem
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
fn get_heap_size_with_tracker<TRACKER>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)where
TRACKER: GetSizeTracker,
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl HasNodeIndex for WithItem
impl HasNodeIndex for WithItem
Sourcefn node_index(&self) -> &AtomicNodeIndex
fn node_index(&self) -> &AtomicNodeIndex
Returns the
AtomicNodeIndex for this node.Sourceimpl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a WithItem
impl<'a> TryFrom<AnyRootNodeRef<'a>> for &'a WithItem
impl StructuralPartialEq for WithItem