pub struct TokenFlags(/* private fields */);Implementations
Sourceimpl TokenFlags
impl TokenFlags
Sourcepub const DOUBLE_QUOTES: TokenFlags
pub const DOUBLE_QUOTES: TokenFlags
The token is a string with double quotes (").
Sourcepub const TRIPLE_QUOTED_STRING: TokenFlags
pub const TRIPLE_QUOTED_STRING: TokenFlags
The token is a triple-quoted string i.e., it starts and ends with three consecutive
quote characters (""" or ''').
Sourcepub const UNICODE_STRING: TokenFlags
pub const UNICODE_STRING: TokenFlags
The token is a unicode string i.e., prefixed with u or U
Sourcepub const BYTE_STRING: TokenFlags
pub const BYTE_STRING: TokenFlags
The token is a byte string i.e., prefixed with b or B
Sourcepub const F_STRING: TokenFlags
pub const F_STRING: TokenFlags
The token is an f-string i.e., prefixed with f or F
Sourcepub const T_STRING: TokenFlags
pub const T_STRING: TokenFlags
The token is a t-string i.e., prefixed with t or T
Sourcepub const RAW_STRING_LOWERCASE: TokenFlags
pub const RAW_STRING_LOWERCASE: TokenFlags
The token is a raw string and the prefix character is in lowercase.
Sourcepub const RAW_STRING_UPPERCASE: TokenFlags
pub const RAW_STRING_UPPERCASE: TokenFlags
The token is a raw string and the prefix character is in uppercase.
Sourcepub const UNCLOSED_STRING: TokenFlags
pub const UNCLOSED_STRING: TokenFlags
String without matching closing quote(s)
Sourcepub const RAW_STRING: TokenFlags
pub const RAW_STRING: TokenFlags
The token is a raw string i.e., prefixed with r or R
Sourceimpl TokenFlags
impl TokenFlags
Sourcepub const fn empty() -> TokenFlags
pub const fn empty() -> TokenFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> TokenFlags
pub const fn all() -> TokenFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<TokenFlags>
pub const fn from_bits(bits: u16) -> Option<TokenFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> TokenFlags
pub const fn from_bits_truncate(bits: u16) -> TokenFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> TokenFlags
pub const fn from_bits_retain(bits: u16) -> TokenFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<TokenFlags>
pub fn from_name(name: &str) -> Option<TokenFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: TokenFlags) -> bool
pub const fn intersects(&self, other: TokenFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: TokenFlags) -> bool
pub const fn contains(&self, other: TokenFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: TokenFlags)
pub fn insert(&mut self, other: TokenFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: TokenFlags)
pub fn remove(&mut self, other: TokenFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: TokenFlags)
pub fn toggle(&mut self, other: TokenFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: TokenFlags, value: bool)
pub fn set(&mut self, other: TokenFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: TokenFlags) -> TokenFlags
pub const fn intersection(self, other: TokenFlags) -> TokenFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: TokenFlags) -> TokenFlags
pub const fn union(self, other: TokenFlags) -> TokenFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: TokenFlags) -> TokenFlags
pub const fn difference(self, other: TokenFlags) -> TokenFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: TokenFlags) -> TokenFlags
pub const fn symmetric_difference(self, other: TokenFlags) -> TokenFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> TokenFlags
pub const fn complement(self) -> TokenFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl TokenFlags
impl TokenFlags
Sourcepub const fn iter(&self) -> Iter<TokenFlags>
pub const fn iter(&self) -> Iter<TokenFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TokenFlags>
pub const fn iter_names(&self) -> IterNames<TokenFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl TokenFlags
impl TokenFlags
Sourcepub const fn is_f_string(self) -> bool
pub const fn is_f_string(self) -> bool
Returns true if the token is an f-string.
Sourcepub const fn is_t_string(self) -> bool
pub const fn is_t_string(self) -> bool
Returns true if the token is a t-string.
Sourcepub const fn is_interpolated_string(self) -> bool
pub const fn is_interpolated_string(self) -> bool
Returns true if the token is a t-string.
Sourcepub fn is_triple_quoted_interpolated_string(self) -> bool
pub fn is_triple_quoted_interpolated_string(self) -> bool
Returns true if the token is a triple-quoted t-string.
Sourcepub const fn is_raw_string(self) -> bool
pub const fn is_raw_string(self) -> bool
Returns true if the token is a raw string.