Crate codegen

Crate codegen 

Compile a Python AST or source code into bytecode consumable by RustPython.

Modules

compile
Take an AST and transform it into bytecode
error
ir
preprocess
symboltable

Structs

CompileOpts

Traits

ToPythonName

Functions

decorated_definition_range
The range a decorated definition covers from its def/class keyword on.
interpolated_string_literal_value
The value of a literal written between the interpolations of an f-string or a t-string.
interpolation_debug_text
The text a {expr=} interpolation puts in front of its value, and the range that text covers.
string_literal_part_value
The value of one of the literals a string literal is written as.
string_literal_value
The value of a string literal.