Module compile

Module compile 

Structs

CodegenOutput
Unoptimized instruction sequence and the metadata needed by optimize_cfg.
CompileOpts
FBlockInfo
PatternContext
The pattern context holds information about captured names and jump targets.

Enums

FBlockDatum
Stores additional data for fblock unwinding
FBlockType
FutureFeature
A Python __future__ feature flag imported via from __future__ import <feature>.

Functions

compile_block_expression
compile_codegen
compile.c _PyCompile_CodeGen
compile_expression
compile_program
Compile a standard Python program to bytecode
compile_program_single
Compile a Python program to bytecode for the context of a REPL
compile_top
Compile an Mod produced from ruff parser
compile_top_with_syntax_warning_handler
ruff_int_to_bigint

Type Aliases

SyntaxWarningHandler