pub fn compile_program_single(
ast: &ModModule,
source_file: SourceFile,
opts: CompileOpts,
) -> Result<CodeObject, CodegenError>Expand description
Compile a Python program to bytecode for the context of a REPL
pub fn compile_program_single(
ast: &ModModule,
source_file: SourceFile,
opts: CompileOpts,
) -> Result<CodeObject, CodegenError>Compile a Python program to bytecode for the context of a REPL