pub struct PatternContext {
pub stores: Vec<String>,
pub allow_irrefutable: bool,
pub fail_pop: Vec<BlockIdx>,
pub on_top: usize,
}Expand description
The pattern context holds information about captured names and jump targets.
Fields
stores: Vec<String>A list of names captured by the pattern.
allow_irrefutable: boolIf false, then any name captures against our subject will raise.
fail_pop: Vec<BlockIdx>A list of jump target labels used on pattern failure.
on_top: usizeThe number of items on top of the stack that should remain.
Implementations
Sourceimpl PatternContext
impl PatternContext
pub const fn new() -> PatternContext
pub fn fail_pop_size(&self) -> usize