pub fn string_literal_part_value(
source_file: &SourceFile,
string: &StringLiteral,
) -> Wtf8BufExpand description
The value of one of the literals a string literal is written as.
pub fn string_literal_part_value(
source_file: &SourceFile,
string: &StringLiteral,
) -> Wtf8BufThe value of one of the literals a string literal is written as.