pub struct Block {
pub instructions: Vec<InstructionInfo>,
pub next: BlockIdx,
pub except_handler: bool,
pub preserve_lasti: bool,
pub start_depth: Option<u32>,
pub cold: bool,
}Fields
instructions: Vec<InstructionInfo>next: BlockIdxexcept_handler: boolWhether this block is an exception handler target (b_except_handler)
preserve_lasti: boolWhether to preserve lasti for this handler block (b_preserve_lasti)
start_depth: Option<u32>Stack depth at block entry, set by stack depth analysis
cold: boolWhether this block is only reachable via exception table (b_cold)