Crate core

Crate core 

Modules

bytecode
Implement python as a virtual machine with bytecode. This module implements bytecode structure.
frozen
marshal
varint
Variable-length integer encoding utilities.

Structs

LineIndex
Index for fast byte offset to LineColumn conversions.
OneIndexed
Type-safe wrapper for a value whose logical range starts at 1, for instance the line or column numbers in a file
SourceFile
A source file that is identified by its name. Optionally stores the source code and LineIndex.
SourceFileBuilder
A Builder for constructing a SourceFile
SourceLocation
A position into a source file represented by the line number and the offset to that character relative to the start of that line.

Enums

Mode
PositionEncoding