pub enum AnyInstruction {
Real(Instruction),
Pseudo(PseudoInstruction),
}Variants
Real(Instruction)
Pseudo(PseudoInstruction)
Implementations
Sourceimpl AnyInstruction
impl AnyInstruction
pub const fn is_unconditional_jump(&self) -> bool
pub const fn is_scope_exit(&self) -> bool
pub const fn is_terminator(&self) -> bool
pub const fn is_no_fallthrough(&self) -> bool
pub const fn has_target(&self) -> bool
pub const fn has_jump(&self) -> bool
pub const fn has_arg(&self) -> bool
pub const fn has_const(&self) -> bool
pub const fn has_eval_break(&self) -> bool
pub const fn is_assembler(&self) -> bool
pub fn stack_effect(&self, oparg: u32) -> i32
pub fn stack_effect_jump(&self, oparg: u32) -> i32
pub fn stack_effect_info(&self, oparg: u32) -> StackEffect
Sourceimpl AnyInstruction
impl AnyInstruction
Sourcepub const fn real(self) -> Option<Instruction>
pub const fn real(self) -> Option<Instruction>
Inner value of Self::Real.
Sourcepub const fn pseudo(self) -> Option<PseudoInstruction>
pub const fn pseudo(self) -> Option<PseudoInstruction>
Inner value of Self::Pseudo.
Sourcepub const fn real_opcode(self) -> Option<Opcode>
pub const fn real_opcode(self) -> Option<Opcode>
Get Self::Real as Opcode.
Sourcepub const fn pseudo_opcode(self) -> Option<PseudoOpcode>
pub const fn pseudo_opcode(self) -> Option<PseudoOpcode>
Get Self::Pseudo as PseudoOpcode.
Sourcepub const fn expect_real(self) -> Instruction
pub const fn expect_real(self) -> Instruction
Same as Self::real but panics if wasn’t called on Self::Real.
Panics
If was called on something else other than Self::Real.
Sourcepub const fn expect_pseudo(self) -> PseudoInstruction
pub const fn expect_pseudo(self) -> PseudoInstruction
Same as Self::pseudo but panics if wasn’t called on Self::Pseudo.
Panics
If was called on something else other than Self::Pseudo.
Sourcepub const fn is_pop_block(self) -> bool
pub const fn is_pop_block(self) -> bool
Returns true if this is a PseudoInstruction::PopBlock.
Sourcepub const fn is_block_push(self) -> bool
pub const fn is_block_push(self) -> bool