Structs
- Const
Idx - Label
- Load
Attr - Load
Super Attr - Make
Function Flags - OpArg
- Full 32-bit op_arg, including any possible ExtendedArg extension.
- OpArg
Byte - Opcode argument that may be extended by a prior ExtendedArg.
- OpArg
State - Resume
Context - Context for
Instruction::Resume. - Unpack
ExArgs - VarNum
- VarNums
Enums
- Binary
Operator - The possible Binary operators
- Build
Slice ArgCount - Specifies if a slice is built with either 2 or 3 arguments.
- Common
Constant - Common constants for LOAD_COMMON_CONSTANT opcode. pycore_opcode_utils.h CONSTANT_*
- Comparison
Operator COMPARE_OParg is(cmp_index << 5) | mask. Only the upper 3 bits identify the comparison; the lower 5 bits are an inline cache mask for adaptive specialization.- Convert
Value Oparg - Oparg values for
Instruction::ConvertValue. - Intrinsic
Function1 - Intrinsic function for CALL_INTRINSIC_1
- Intrinsic
Function2 - Intrinsic function for CALL_INTRINSIC_2
- Invert
- Whether or not to invert the operation.
- Make
Function Flag SET_FUNCTION_ATTRIBUTEflags. Bitmask: Defaults=0x01, KwOnly=0x02, Annotations=0x04, Closure=0x08, TypeParams=0x10, Annotate=0x20. Stored as bit position (0-5) bybitflag!macro.- Raise
Kind - The kind of Raise that occurred.
- Resume
Location - Special
Method - Special method for LOAD_SPECIAL opcode (context managers).