dont_imply_dedent_source_error

Function dont_imply_dedent_source_error 

pub fn dont_imply_dedent_source_error(
    source_file: &SourceFile,
) -> Option<CompileError>
Detect input that only parses because Ruff’s lexer closes indentation at EOF.

PyCF_DONT_IMPLY_DEDENT is used by codeop and interactive compile paths to keep an indented block incomplete until a terminating newline is seen.