InterpolatedStringErrorType

Enum InterpolatedStringErrorType 

pub enum InterpolatedStringErrorType {
    UnclosedLbrace,
    InvalidConversionFlag,
    SingleRbrace,
    UnterminatedString,
    UnterminatedTripleQuotedString,
    LambdaWithoutParentheses,
    ConversionFlagNotImmediatelyAfterExclamation,
    NewlineInFormatSpec,
}
Represents the different types of errors that can occur during parsing of an f-string or t-string.

Variants



UnclosedLbrace

Expected a right brace after an opened left brace.



InvalidConversionFlag

An invalid conversion flag was encountered.



SingleRbrace

A single right brace was encountered.



UnterminatedString

Unterminated string.



UnterminatedTripleQuotedString

Unterminated triple-quoted string.



LambdaWithoutParentheses

A lambda expression without parentheses was encountered.



ConversionFlagNotImmediatelyAfterExclamation

Conversion flag does not immediately follow exclamation.



NewlineInFormatSpec

Newline inside of a format spec for a single quoted f- or t-string.