SemanticSyntaxChecker

Struct SemanticSyntaxChecker 

pub struct SemanticSyntaxChecker { /* private fields */ }

Implementations

Source

impl SemanticSyntaxChecker

Source

impl SemanticSyntaxChecker

pub fn visit_stmt<Ctx>(&mut self, stmt: &Stmt, ctx: &Ctx)

Check stmt for semantic syntax errors and update the checker’s internal state.

Note that this method should only be called when traversing stmt and its children. For example, if traversal of function bodies needs to be deferred, avoid calling visit_stmt on the function itself until the deferred body is visited too. Failing to defer visit_stmt in this case will break any internal state that depends on function scopes, such as async context detection.

pub fn visit_expr<Ctx>(&mut self, expr: &Expr, ctx: &Ctx)

Check expr for semantic syntax errors and update the checker’s internal state.