Parsed

Struct Parsed 

pub struct Parsed<T> { /* private fields */ }
Represents the parsed source code.

Implementations

Source

impl<T> Parsed<T>

pub fn syntax(&self) -> &T

Returns the syntax node represented by this parsed output.

pub fn tokens(&self) -> &Tokens

Returns all the tokens for the parsed output.

pub fn errors(&self) -> &[ParseError]

Returns a list of syntax errors found during parsing.

pub fn unsupported_syntax_errors(&self) -> &[UnsupportedSyntaxError]

Returns a list of version-related syntax errors found during parsing.

pub fn into_syntax(self) -> T

Consumes the Parsed output and returns the contained syntax node.

pub fn into_errors(self) -> Vec<ParseError>

Consumes the Parsed output and returns a list of syntax errors found during parsing.

pub fn has_valid_syntax(&self) -> bool

Returns true if the parsed source code is valid i.e., it has no ParseErrors.

Note that this does not include version-related UnsupportedSyntaxErrors.

See Parsed::has_no_syntax_errors for a version that takes these into account.

pub fn has_invalid_syntax(&self) -> bool

Returns true if the parsed source code is invalid i.e., it has ParseErrors.

Note that this does not include version-related UnsupportedSyntaxErrors.

See Parsed::has_no_syntax_errors for a version that takes these into account.

pub fn has_no_syntax_errors(&self) -> bool

Returns true if the parsed source code does not contain any ParseErrors or UnsupportedSyntaxErrors.

See Parsed::has_valid_syntax for a version specific to ParseErrors.

pub fn has_syntax_errors(&self) -> bool

Returns true if the parsed source code contains any ParseErrors or UnsupportedSyntaxErrors.

See Parsed::has_invalid_syntax for a version specific to ParseErrors.

pub fn as_result(&self) -> Result<&Parsed<T>, &[ParseError]>

Returns the Parsed output as a Result, returning Ok if it has no syntax errors, or Err containing the first ParseError encountered.

Note that any unsupported_syntax_errors will not cause Err to be returned.

Source

impl Parsed<Mod>

pub fn try_into_module(self) -> Option<Parsed<ModModule>>

Attempts to convert the Parsed<Mod> into a Parsed<ModModule>.

This method checks if the syntax field of the output is a Mod::Module. If it is, the method returns Some(Parsed<ModModule>) with the contained module. Otherwise, it returns None.

pub fn try_into_expression(self) -> Option<Parsed<ModExpression>>

Attempts to convert the Parsed<Mod> into a Parsed<ModExpression>.

This method checks if the syntax field of the output is a Mod::Expression. If it is, the method returns Some(Parsed<ModExpression>) with the contained expression. Otherwise, it returns None.

Source

impl Parsed<ModModule>

pub fn suite(&self) -> &Vec<Stmt>

Returns the module body contained in this parsed output as a Suite.

pub fn into_suite(self) -> Vec<Stmt>

Consumes the Parsed output and returns the module body as a Suite.

Source

impl Parsed<ModExpression>

pub fn expr(&self) -> &Expr

Returns the expression contained in this parsed output.

pub fn expr_mut(&mut self) -> &mut Expr

Returns a mutable reference to the expression contained in this parsed output.

pub fn into_expr(self) -> Expr

Consumes the Parsed output and returns the contained Expr.