Module typing

Module typing 

This module takes care of parsing a type annotation.

Structs

ParsedAnnotation

Enums

AnnotationKind

Functions

parse_type_annotation
Parses the given string expression node as a type annotation. The given source is the entire source code.