pub enum AnnotationKind {
Simple,
Complex,
}Variants
Simple
The annotation is defined as part a simple string literal,
e.g. x: "List[int]" = []. Annotations within simple literals
can be accurately located. For example, we can underline specific
expressions within the annotation and apply automatic fixes, which is
not possible for complex string literals.
Complex
The annotation is defined as part of a complex string literal, such as
a literal containing an implicit concatenation or escaped characters,
e.g. x: "List" "[int]" = []. These are comparatively rare, but valid.
Implementations