pub struct CodeObject<C = ConstantData>where
C: Constant,{Show 19 fields
pub instructions: CodeUnits,
pub locations: Box<[(SourceLocation, SourceLocation)]>,
pub flags: CodeFlags,
pub posonlyarg_count: u32,
pub arg_count: u32,
pub kwonlyarg_count: u32,
pub source_path: <C as Constant>::Name,
pub first_line_number: Option<OneIndexed>,
pub max_stackdepth: u32,
pub obj_name: <C as Constant>::Name,
pub qualname: <C as Constant>::Name,
pub constants: Constants<C>,
pub names: Box<[<C as Constant>::Name]>,
pub varnames: Box<[<C as Constant>::Name]>,
pub cellvars: Box<[<C as Constant>::Name]>,
pub freevars: Box<[<C as Constant>::Name]>,
pub localspluskinds: Box<[u8]>,
pub linetable: Box<[u8]>,
pub exceptiontable: Box<[u8]>,
}Expand description
Primary container of a single code object. Each python function has a code object. Also a module has a code object.
Fields
instructions: CodeUnitslocations: Box<[(SourceLocation, SourceLocation)]>flags: CodeFlagsposonlyarg_count: u32Number of positional-only arguments
arg_count: u32kwonlyarg_count: u32source_path: <C as Constant>::Namefirst_line_number: Option<OneIndexed>max_stackdepth: u32obj_name: <C as Constant>::NameName of the object that created this code object
qualname: <C as Constant>::NameQualified name of the object (like CPython’s co_qualname)
constants: Constants<C>names: Box<[<C as Constant>::Name]>varnames: Box<[<C as Constant>::Name]>cellvars: Box<[<C as Constant>::Name]>freevars: Box<[<C as Constant>::Name]>localspluskinds: Box<[u8]>Per-slot kind flags: CO_FAST_LOCAL, CO_FAST_CELL, CO_FAST_FREE, CO_FAST_HIDDEN. Length = nlocalsplus (nlocals + ncells + nfrees).
linetable: Box<[u8]>Line number table (CPython 3.11+ format)
exceptiontable: Box<[u8]>Exception handling table
Implementations
Sourceimpl<C> CodeObject<C>where
C: Constant,
impl<C> CodeObject<C>where
C: Constant,
Sourcepub fn arg_names(&self) -> Arguments<'_, <C as Constant>::Name>
pub fn arg_names(&self) -> Arguments<'_, <C as Constant>::Name>
Get all arguments of the code object like inspect.getargs
Sourcepub fn label_targets(&self) -> BTreeSet<Label>
pub fn label_targets(&self) -> BTreeSet<Label>
Return the labels targeted by the instructions of this CodeObject
Sourcepub fn display_expand_code_objects(&self) -> impl Display
pub fn display_expand_code_objects(&self) -> impl Display
Recursively display this CodeObject
Sourcepub fn map_bag<Bag>(
self,
bag: Bag,
) -> CodeObject<<Bag as ConstantBag>::Constant>where
Bag: ConstantBag,
pub fn map_bag<Bag>(
self,
bag: Bag,
) -> CodeObject<<Bag as ConstantBag>::Constant>where
Bag: ConstantBag,
Map this CodeObject to one that holds a Bag::Constant
Sourcepub fn map_clone_bag<Bag>(
&self,
bag: &Bag,
) -> CodeObject<<Bag as ConstantBag>::Constant>where
Bag: ConstantBag,
pub fn map_clone_bag<Bag>(
&self,
bag: &Bag,
) -> CodeObject<<Bag as ConstantBag>::Constant>where
Bag: ConstantBag,
Same as map_bag but clones self