pub enum ExecutionResult {
Return(PyObjectRef),
Yield(PyObjectRef),
TailCall,
GenResume,
}Variants
Return(PyObjectRef)
Yield(PyObjectRef)
TailCall
The bytecode loop wants to tail-call into a new frame that has
already been prepared on the datastack. The trampoline reads the
pending frame pointer from vm.pending_tailcall_frame.
GenResume
The bytecode loop wants a generator or coroutine resumed in this same
eval loop rather than through a nested Coro::send. The trampoline
reads which one, the value to send it, and the continuation below
from vm.pending_gen_resume.