for_each_current_frame

Function for_each_current_frame 

pub fn for_each_current_frame(f: impl FnMut(&Py<FrameObject>))
Invoke f for each frame on the current thread’s chain, from the topmost frame down to the bottom.