FrameLocals

Struct FrameLocals 

pub struct FrameLocals { /* private fields */ }
Lazy locals dict for frames. For NEWLOCALS frames, the dict is only allocated on first access (most function frames never need it).

Implementations

Source

impl FrameLocals

pub fn get_or_create(&self, vm: &VirtualMachine) -> &ArgMapping

Get the locals mapping, creating it lazily if needed.

pub fn get(&self) -> Option<&ArgMapping>

Get the locals mapping if already created.

pub fn mapping(&self, vm: &VirtualMachine) -> PyMapping<'_>

pub fn clone_mapping(&self, vm: &VirtualMachine) -> ArgMapping

pub fn into_object(&self, vm: &VirtualMachine) -> PyObjectRef

pub fn as_object(&self, vm: &VirtualMachine) -> &PyObject