pub enum DefaultRepr {
None,
Bool(bool),
Int(i128),
Float(f64),
Str(&'static str),
Bytes(&'static [u8]),
Raw(&'static str),
Unrepresentable,
}Expand description
Python source for a parameter default, chosen so it can be rendered in a const context.
Variants
None
Bool(bool)
Int(i128)
Float(f64)
Str(&'static str)
Bytes(&'static [u8])
Raw(&'static str)
Verbatim Python source from py_default.
Unrepresentable
The argument may be omitted, and that state is not a Python value.