OptionalArg

Enum OptionalArg 

pub enum OptionalArg<T = PyObjectRef> {
    Present(T),
    Missing,
}
An argument that may or may not be provided by the caller.

This style of argument is not possible in pure Python.

Variants



Present(T)



Missing

Implementations

Source

impl<T> OptionalArg<T>

pub fn from_option(option: Option<T>) -> Self

pub fn into_option(self) -> Option<T>

pub fn as_option(&self) -> Option<&T>

pub fn as_option_mut(&mut self) -> Option<&mut T>

pub fn expect(self, msg: &str) -> T

pub fn unwrap(self) -> T

pub fn unwrap_or(self, default: T) -> T

pub fn unwrap_or_else<_Function: FnOnce() -> T>(self, f: _Function) -> T

pub fn ok_or<_Error>(self, err: _Error) -> Result<T, _Error>

pub fn ok_or_else<_Error, _Function: FnOnce() -> _Error>( self, err: _Function, ) -> Result<T, _Error>

pub fn filter<P: FnOnce(&T) -> bool>(self, predicate: P) -> Self

pub fn or(self, optb: Self) -> Self

pub fn or_else<_Function: FnOnce() -> Self>(self, f: _Function) -> Self

pub fn map_or<_Other, _Function: FnOnce(T) -> _Other>( self, default: _Other, f: _Function, ) -> _Other

pub fn xor(self, optb: Self) -> Self

pub fn get_or_insert(&mut self, v: T) -> &mut T

pub fn get_or_insert_with<_Function: FnOnce() -> T>( &mut self, f: _Function, ) -> &mut T

pub fn replace(&mut self, value: T) -> Self

Source

impl<T> OptionalArg<T>

pub fn as_ref(&self) -> OptionalArg<&T>

pub fn as_mut(&mut self) -> OptionalArg<&mut T>

pub fn map<_Other, _Function: FnOnce(T) -> _Other>( self, f: _Function, ) -> OptionalArg<_Other>

pub fn map_or_else<_Other, _Default: FnOnce() -> _Other, _Function: FnOnce(T) -> _Other>( self, default: _Default, f: _Function, ) -> _Other

pub fn iter(&self) -> impl Iterator<Item = &T>

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

pub fn and<_Other>(self, optb: OptionalArg<_Other>) -> OptionalArg<_Other>

pub fn and_then<_Other, _Function: FnOnce(T) -> OptionalArg<_Other>>( self, f: _Function, ) -> OptionalArg<_Other>

pub fn zip<_Other>(self, other: OptionalArg<_Other>) -> OptionalArg<(T, _Other)>

pub fn take(&mut self) -> Self
where T: Default,

pub fn unwrap_or_default(self) -> T
where T: Default,

Source

impl<T> OptionalArg<&T>
where T: Copy,

pub fn copied(self) -> OptionalArg<T>

Source

impl<T> OptionalArg<&mut T>
where T: Copy,

pub fn copied(self) -> OptionalArg<T>

Source

impl<T> OptionalArg<&T>
where T: Clone,

pub fn cloned(self) -> OptionalArg<T>

Source

impl<T> OptionalArg<&mut T>
where T: Clone,

pub fn cloned(self) -> OptionalArg<T>

Source

impl<T> OptionalArg<T>
where T: Deref,

pub fn as_deref(&self) -> OptionalArg<&T::Target>

Source

impl<T: DerefMut> OptionalArg<T>

pub fn as_deref_mut(&mut self) -> OptionalArg<&mut T::Target>

Source

impl<T, _Error> OptionalArg<Result<T, _Error>>

pub fn transpose(self) -> Result<OptionalArg<T>, _Error>

Source

impl<T> OptionalArg<T>

pub const fn is_present(&self) -> bool

Returns true if self is of variant Present.

pub fn as_present(&self) -> Option<&T>

Returns Some if self is a reference of variant Present, and None otherwise.

pub fn as_mut_present(&mut self) -> Option<&mut T>

Returns Some if self is a mutable reference of variant Present, and None otherwise.

pub fn expect_present(self) -> T
where Self: Debug,

Unwraps the value, yielding the content of Present.

Panics

Panics if the value is not Present. In debug builds the panic message includes the content of self.

pub fn present(self) -> Option<T>

Returns Some if self is of variant Present, and None otherwise.

pub const fn is_missing(&self) -> bool

Returns true if self is of variant Missing.

Source

impl OptionalArg<PyObjectRef>

Source

impl<T> OptionalArg<Option<T>>

pub fn flatten(self) -> Option<T>

Source

impl<T> OptionalArg<ArgStrictInt<T>>