PySetterValue

Enum PySetterValue 

pub enum PySetterValue<T = PyObjectRef> {
    Assign(T),
    Delete,
}

Variants



Assign(T)



Delete

Implementations

Source

impl<T> PySetterValue<T>

pub fn from_option(option: Option<T>) -> Self

pub fn into_option(self) -> Option<T>

pub fn as_option(&self) -> Option<&T>

pub fn as_option_mut(&mut self) -> Option<&mut T>

pub fn expect(self, msg: &str) -> T

pub fn unwrap(self) -> T

pub fn unwrap_or(self, default: T) -> T

pub fn unwrap_or_else<_Function: FnOnce() -> T>(self, f: _Function) -> T

pub fn ok_or<_Error>(self, err: _Error) -> Result<T, _Error>

pub fn ok_or_else<_Error, _Function: FnOnce() -> _Error>( self, err: _Function, ) -> Result<T, _Error>

pub fn filter<P: FnOnce(&T) -> bool>(self, predicate: P) -> Self

pub fn or(self, optb: Self) -> Self

pub fn or_else<_Function: FnOnce() -> Self>(self, f: _Function) -> Self

pub fn map_or<_Other, _Function: FnOnce(T) -> _Other>( self, default: _Other, f: _Function, ) -> _Other

pub fn xor(self, optb: Self) -> Self

pub fn get_or_insert(&mut self, v: T) -> &mut T

pub fn get_or_insert_with<_Function: FnOnce() -> T>( &mut self, f: _Function, ) -> &mut T

pub fn replace(&mut self, value: T) -> Self

Source

impl<T> PySetterValue<T>

pub fn as_ref(&self) -> PySetterValue<&T>

pub fn as_mut(&mut self) -> PySetterValue<&mut T>

pub fn map<_Other, _Function: FnOnce(T) -> _Other>( self, f: _Function, ) -> PySetterValue<_Other>

pub fn map_or_else<_Other, _Default: FnOnce() -> _Other, _Function: FnOnce(T) -> _Other>( self, default: _Default, f: _Function, ) -> _Other

pub fn iter(&self) -> impl Iterator<Item = &T>

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

pub fn and<_Other>(self, optb: PySetterValue<_Other>) -> PySetterValue<_Other>

pub fn and_then<_Other, _Function: FnOnce(T) -> PySetterValue<_Other>>( self, f: _Function, ) -> PySetterValue<_Other>

pub fn zip<_Other>( self, other: PySetterValue<_Other>, ) -> PySetterValue<(T, _Other)>

pub fn take(&mut self) -> Self
where T: Default,

pub fn unwrap_or_default(self) -> T
where T: Default,

Source

impl<T> PySetterValue<&T>
where T: Copy,

pub fn copied(self) -> PySetterValue<T>

Source

impl<T> PySetterValue<&mut T>
where T: Copy,

pub fn copied(self) -> PySetterValue<T>

Source

impl<T> PySetterValue<&T>
where T: Clone,

pub fn cloned(self) -> PySetterValue<T>

Source

impl<T> PySetterValue<&mut T>
where T: Clone,

pub fn cloned(self) -> PySetterValue<T>

Source

impl<T> PySetterValue<T>
where T: Deref,

pub fn as_deref(&self) -> PySetterValue<&T::Target>

Source

impl<T: DerefMut> PySetterValue<T>

pub fn as_deref_mut(&mut self) -> PySetterValue<&mut T::Target>

Source

impl<T, _Error> PySetterValue<Result<T, _Error>>

pub fn transpose(self) -> Result<PySetterValue<T>, _Error>

Source

impl<T> PySetterValue<T>

pub const fn is_assign(&self) -> bool

Returns true if self is of variant Assign.

pub fn as_assign(&self) -> Option<&T>

Returns Some if self is a reference of variant Assign, and None otherwise.

pub fn as_mut_assign(&mut self) -> Option<&mut T>

Returns Some if self is a mutable reference of variant Assign, and None otherwise.

pub fn expect_assign(self) -> T
where Self: Debug,

Unwraps the value, yielding the content of Assign.

Panics

Panics if the value is not Assign. In debug builds the panic message includes the content of self.

pub fn assign(self) -> Option<T>

Returns Some if self is of variant Assign, and None otherwise.

pub const fn is_delete(&self) -> bool

Returns true if self is of variant Delete.

Source

impl PySetterValue