pub const fn has_signature(args: &[SigArg]) -> boolExpand description
False when an argument is a destructured pattern whose type has no FromArgs::PARAMS.
pub const fn has_signature(args: &[SigArg]) -> boolFalse when an argument is a destructured pattern whose type has no FromArgs::PARAMS.