pub struct ArgIntoBool { /* private fields */ }Expand description
A Python bool-like object.
ArgIntoBool implements FromArgs so that a built-in function can accept
any object that can be transformed into a boolean.
By default an object is considered true unless its class defines either a
__bool__() method that returns False or a __len__() method that returns
zero, when called with the object.
Implementations
Sourceimpl ArgIntoBool
impl ArgIntoBool
pub const TRUE: Self
pub const FALSE: Self
pub fn into_bool(self) -> bool
pub const fn py_default(&self) -> DefaultRepr