pub struct ArgIntoFloat { /* private fields */ }Expand description
A Python float-like object.
ArgIntoFloat implements FromArgs so that a built-in function can accept
any object that can be transformed into a float.
If the object is not a Python floating point object but has a __float__()
method, this method will first be called to convert the object into a float.
If __float__() is not defined then it falls back to __index__().
Implementations
Sourceimpl ArgIntoFloat
impl ArgIntoFloat
pub fn into_float(self) -> f64
pub fn vec_into_f64(v: Vec<Self>) -> Vec<f64>