pub struct ArgIterable<T = PyObjectRef> { /* private fields */ }Expand description
An iterable Python object.
ArgIterable implements FromArgs so that a built-in function can accept
an object that is required to conform to the Python iterator protocol.
ArgIterable can optionally perform type checking and conversions on iterated
objects using a generic type parameter that implements TryFromObject.
Implementations
Sourceimpl<T> ArgIterable<T>
impl<T> ArgIterable<T>
Sourcepub fn iter<'a>(&self, vm: &'a VirtualMachine) -> PyResult<PyIterIter<'a, T>>
pub fn iter<'a>(&self, vm: &'a VirtualMachine) -> PyResult<PyIterIter<'a, T>>
Returns an iterator over this sequence of objects. See PyIter::iter
for why it does not ask how long the iterator is.
This operation may fail if an exception is raised while invoking the
__iter__ method of the iterable object.
Sourcepub fn iter_sized<'a>(
&self,
vm: &'a VirtualMachine,
) -> PyResult<PyIterIter<'a, T>>
pub fn iter_sized<'a>( &self, vm: &'a VirtualMachine, ) -> PyResult<PyIterIter<'a, T>>
Self::iter for a caller that fills a sized container from the
iterator, the way PySequence_Fast() does.