pub struct TimeoutSeconds { /* private fields */ }Expand description
A Python timeout value that accepts both float and int.
TimeoutSeconds implements FromArgs so that a built-in function can accept
timeout parameters given as either float or int, normalizing them to f64.
Implementations
Sourceimpl TimeoutSeconds
impl TimeoutSeconds
pub const fn new(secs: f64) -> Self
pub fn to_secs_f64(self) -> f64
pub const fn py_default(&self) -> DefaultRepr