pub struct PyLease<'a, T: PyPayload> { /* private fields */ }Expand description
A borrow of a reference to a Python object. This avoids having clone the PyRef<T>/
PyObjectRef, which isn’t that cheap as that increments the atomic reference counter.
Implementations
Methods from Deref<Target = Py<T>>
pub fn downgrade( &self, callback: Option<PyObjectRef>, vm: &VirtualMachine, ) -> PyResult<PyWeakRef<T>>
pub fn payload(&self) -> &T
Sourcepub fn upcast_ref<U: PyPayload + StaticType>(&self) -> &Py<U>where
T: StaticType,
pub fn upcast_ref<U: PyPayload + StaticType>(&self) -> &Py<U>where
T: StaticType,
Converts &Py<T> to &Py<U> where U is an ancestor type.