PyRef

Struct PyRef 

pub struct PyRef<T> { /* private fields */ }
A reference to a Python object.

Note that a PyRef<T> can only deref to a shared / immutable reference. It is the payload type’s responsibility to handle (possibly concurrent) mutability with locks or concurrent data structures if required.

A PyRef<T> can be directly returned from a built-in function to handle situations (such as when implementing in-place methods such as __iadd__) where a reference to the same object must be returned.

Implementations

Source

impl PyRef<PyStr>

pub fn is_empty(&self) -> bool

pub fn concat_in_place(&mut self, other: &Wtf8, vm: &VirtualMachine)

pub fn try_into_utf8(self, vm: &VirtualMachine) -> PyResult<PyRef<PyUtf8Str>>

Source

impl PyRef<PyUtf8Str>

pub fn into_wtf8(self) -> PyStrRef

Convert to PyStrRef. Safe because PyUtf8Str is a subtype of PyStr.

Source

impl PyRef<PyTraceback>

pub fn iter(&self) -> impl Iterator<Item = Self>

Source

impl PyRef<PyTuple<PyObjectRef>>

Source

impl<T: PyPayload> PyRef<PyTuple<PyRef<T>>>

Source

impl<T: PyPayload> PyRef<T>

pub const fn leak(pyref: Self) -> &'static Py<T>

Source

impl<T: PyPayload + MaybeTraverse + Debug> PyRef<T>

pub fn new_ref(payload: T, typ: PyTypeRef, dict: Option<PyDictRef>) -> Self

Source

impl<T: PySubclass + Debug> PyRef<T>
where T::Base: Debug,

pub fn into_base(self) -> PyRef<T::Base>

Converts this reference to the base type (ownership transfer).

Safety

T and T::Base must have compatible layouts in size_of::<T::Base>() bytes.

pub fn upcast<U: PyPayload + StaticType>(self) -> PyRef<U>
where T: StaticType,

Source

impl<T: PyPayload> PyRef<T>

pub fn into_exact_or( self, ctx: &Context, f: impl FnOnce(Self) -> PyRefExact<T>, ) -> PyRefExact<T>

Source

impl PyRef<VecBuffer>

Methods from Deref<Target = Py<T>>

pub fn downgrade( &self, callback: Option<PyObjectRef>, vm: &VirtualMachine, ) -> PyResult<PyWeakRef<T>>

pub fn payload(&self) -> &T

pub fn to_base(&self) -> &Py<T::Base>

Converts &Py<T> to &Py<T::Base>.

pub fn upcast_ref<U: PyPayload + StaticType>(&self) -> &Py<U>
where T: StaticType,

Converts &Py<T> to &Py<U> where U is an ancestor type.