pub struct BufferFlags(/* private fields */);Expand description
Capabilities a consumer asks a buffer exporter for, the flags argument of
bf_getbuffer and of __buffer__ (PyBUF_*).
The composite requests are supersets of the simpler ones, so
contains answers the REQ_* questions an exporter asks:
flags.contains(BufferFlags::C_CONTIGUOUS) is REQ_C_CONTIGUOUS(flags).
Implementations
Sourceimpl BufferFlags
impl BufferFlags
Sourceimpl BufferFlags
impl BufferFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl BufferFlags
impl BufferFlags
Sourcepub const fn iter(&self) -> Iter<BufferFlags> ⓘ
pub const fn iter(&self) -> Iter<BufferFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<BufferFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<BufferFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl BufferFlags
impl BufferFlags
Sourcepub const STRIDED_RO: Self = Self::STRIDES
pub const STRIDED_RO: Self = Self::STRIDES
PyBUF_STRIDED_RO
Sourcepub const RECORDS_RO: Self
pub const RECORDS_RO: Self
PyBUF_RECORDS_RO
Sourcepub const fn is_memory_access_mode(self) -> bool
pub const fn is_memory_access_mode(self) -> bool
Whether this request is really a PyMemoryView_FromMemory access mode,
which no exporter can serve.
Sourcepub const fn is_writable(self) -> bool
pub const fn is_writable(self) -> bool
Whether the consumer demands a writable buffer.
Sourcepub fn fill_info_check(
self,
readonly: bool,
vm: &VirtualMachine,
) -> PyResult<()>
pub fn fill_info_check( self, readonly: bool, vm: &VirtualMachine, ) -> PyResult<()>
The argument checks PyBuffer_FillInfo performs, for exporters that hand
out a flat block of bytes.
Sourcepub fn check_writable(
self,
readonly: bool,
message: &str,
vm: &VirtualMachine,
) -> PyResult<()>
pub fn check_writable( self, readonly: bool, message: &str, vm: &VirtualMachine, ) -> PyResult<()>
Reject a writable request against a read-only export.