Module readline

Module readline 

Readline interface for REPLs

This module provides a common interface for reading lines from the console, with support for history and completion. It uses the rustyline crate on non-WASM platforms and a custom implementation on WASM platforms.

Structs

Readline

Enums

ReadlineResult

Traits

Helper