Module types

Module types 

Re-exports

pub use slot_defs::SLOT_DEFS;
pub use slot_defs::SLOT_DEFS_COUNT;
pub use slot_defs::SlotAccessor;
pub use slot_defs::SlotDef;

Modules

slot_defs
Slot definitions array

Macros

atomic_func

Structs

AtomicPyTypeFlags
PyComparisonOp
PyTypeFlags
PyTypeSlots
StructSequenceNewArgs
The arguments every struct sequence constructor takes.
TypeDataRef
Read guard for type data access, using mapped guard for zero-cost deref.
TypeDataRefMut
Write guard for type data access, using mapped guard for zero-cost deref.
TypeDataSlot
Type-erased storage for extension module data attached to heap types.

Constants

STRUCT_SEQUENCE_PARAMS
Text signature (iterable=(), /) shared by every struct sequence.

Traits

AsBuffer
AsMapping
AsNumber
AsSequence
Callable
Comparable
Constructor
Trait for types that can be constructed via Python’s __new__ method.
DefaultConstructor
Destructor
GetAttr
GetDescriptor
Hashable
Initializer
IterNext
Iterable
PyStructSequence
Trait for Python struct sequence types.
PyStructSequenceData
Trait for Data structs that back a PyStructSequence.
Representable
SelfIter
SetAttr

Functions

hash_not_implemented
Marks a type as unhashable. Similar to PyObject_HashNotImplemented in CPython
struct_sequence_new
Create a new struct sequence instance from a sequence.

Type Aliases

DelNeededFunc
Predicate used by PyTypeSlots::del_needed.