pub struct TypeDataRef<'a, T: 'static> { /* private fields */ }Expand description
Read guard for type data access, using mapped guard for zero-cost deref.
Implementations
Sourceimpl<'a, T: Any + 'static> TypeDataRef<'a, T>
impl<'a, T: Any + 'static> TypeDataRef<'a, T>
Sourcepub fn try_new(
guard: PyRwLockReadGuard<'a, Option<TypeDataSlot>>,
) -> Option<Self>
pub fn try_new( guard: PyRwLockReadGuard<'a, Option<TypeDataSlot>>, ) -> Option<Self>
Try to create a TypeDataRef from a read guard. Returns None if the slot is empty or contains a different type.