TypeDataRefMut

Struct TypeDataRefMut 

pub struct TypeDataRefMut<'a, T: 'static> { /* private fields */ }
Write guard for type data access, using mapped guard for zero-cost deref.

Implementations

Source

impl<'a, T: Any + 'static> TypeDataRefMut<'a, T>

pub fn try_new( guard: PyRwLockWriteGuard<'a, Option<TypeDataSlot>>, ) -> Option<Self>

Try to create a TypeDataRefMut from a write guard. Returns None if the slot is empty or contains a different type.