Module vm

Module vm 

Implement virtual machine to run instructions.

See also: https://github.com/ProgVal/pythonvm-rust/blob/master/src/processor/mod.rs

Re-exports

pub use runtime::InterpFeatureFlags;
pub use runtime::InterpreterConfig;
pub use runtime::InterpreterGil;
pub use runtime::InterpreterInfo;
pub use runtime::InterpreterWhence;
pub use runtime::MAIN_INTERPRETER_ID;

Modules

crossinterp
Cross-interpreter object sharing and exception snapshots (XI data).
runtime
Process-global runtime support for multiple interpreters (PEP 734 preparation).
thread

Structs

Context
Interpreter
One isolated Python interpreter in the process (≈ CPython PyInterpreterState + main tstate).
InterpreterBuilder
Configuration builder for constructing an Interpreter.
Paths
Path configuration computed at runtime (like PyConfig path outputs)
PyConfig
Combined configuration: user settings + computed paths CPython directly exposes every fields under both of them. We separate them to maintain better ownership discipline.
PyGlobalState
Per-interpreter shared state (≈ CPython PyInterpreterState).
Settings
User-configurable settings for the python vm.
VirtualMachine
Per-thread execution context for a single interpreter (≈ CPython PyThreadState).

Enums

CheckHashPycsMode
VmCompileError

Constants

MAX_MEMORY_SIZE

Functions

resolve_frozen_alias
Resolve frozen module alias to its original name. Returns the original module name if an alias exists, otherwise returns the input name.