SharedValue

Enum SharedValue 

pub enum SharedValue {
Show 13 variants None, Bool(bool), Int(isize), Float(f64), Bytes(Vec<u8>), Str(Wtf8Buf), Tuple(Vec<Self>), Channel { cid: i64, end: i32, }, Queue(SharedQueueId), Buffer(Vec<u8>, BufferDescriptor), Code(Vec<u8>), Function(Vec<u8>), Pickled(PickledData),
}
Interpreter-neutral payload that can be materialized in any interpreter sharing the process-wide crate::Context.

Variants



None



Bool(bool)



Int(isize)



Float(f64)



Bytes(Vec<u8>)



Str(Wtf8Buf)



Tuple(Vec<Self>)



Channel

Fields

cid: i64
end: i32


Queue(SharedQueueId)



Buffer(Vec<u8>, BufferDescriptor)



Code(Vec<u8>)

Marshalled code object.



Function(Vec<u8>)

Marshalled code of a stateless function; rebuilt against __main__.



Pickled(PickledData)

pickle.dumps output, used by Fallback::Full.

Implementations

Source

impl SharedValue

pub fn from_object( obj: &PyObject, fallback: Fallback, vm: &VirtualMachine, ) -> PyResult<Self>

pub fn from_callable(obj: &PyObject, vm: &VirtualMachine) -> PyResult<Self>

_interp_call_pack’s handling of the callable: a stateless function travels as its code, anything else is pickled.

pub fn from_code(code: &Py<PyCode>, vm: &VirtualMachine) -> PyResult<Self>

_PyCode_GetXIData.

pub fn from_buffer_object(obj: &PyObject, vm: &VirtualMachine) -> PyResult<Self>

pub fn into_object(self, vm: &VirtualMachine) -> PyResult