pub struct ExcInfo {
pub type_name: String,
pub type_qualname: String,
pub type_module: String,
pub msg: Option<String>,
pub formatted: String,
pub errdisplay: String,
}Expand description
Snapshot of an exception that can be rebuilt in another interpreter.
Fields
type_name: Stringtype_qualname: Stringtype_module: Stringmsg: Option<String>formatted: Stringerrdisplay: StringImplementations
Sourceimpl ExcInfo
impl ExcInfo
pub fn capture(exc: &Py<PyBaseException>, vm: &VirtualMachine) -> Self
_PyXI_ApplyError for _PyXI_ERR_NOT_SHAREABLE: the snapshot is
re-raised as a plain Exception and becomes the cause.
pub fn into_namespace(self, vm: &VirtualMachine) -> PyObjectRef