pub fn set_current_frame(
frame: *const InterpreterFrame,
) -> *const InterpreterFrameExpand description
Set the current thread’s top InterpreterFrame pointer. Returns the previous pointer so it can be restored on pop.
pub fn set_current_frame(
frame: *const InterpreterFrame,
) -> *const InterpreterFrameSet the current thread’s top InterpreterFrame pointer. Returns the previous pointer so it can be restored on pop.