#[pystruct_sequence]Expand description
Attribute macro for defining Python struct sequence types.
This macro is applied to an empty struct to create a Python type that wraps a Data struct.
Example
ⓘ
#[pystruct_sequence_data]
struct StructTimeData {
pub tm_year: PyObjectRef,
#[pystruct_sequence(skip)]
pub tm_gmtoff: PyObjectRef,
}
#[pystruct_sequence(name = "struct_time", module = "time", data = "StructTimeData")]
struct PyStructTime;