Module builtins

Module builtins 

This package contains the python basic/builtin types 7 common PyRef type aliases are exposed - PyBytesRef, PyDictRef, PyIntRef, PyListRef, PyStrRef, PyTypeRef, PyTupleRef Do not add more PyRef type aliases. They will be rare enough to use directly PyRef<T>.

Re-exports

pub use descriptor::MemberAccess;
pub use descriptor::MemberKind;
pub use descriptor::PyDescriptorOwned;
pub use descriptor::PyMemberDef as DescriptorMemberDef;
pub use descriptor::PyMemberDescriptor;
pub use descriptor::PyMemberFlags;

Modules

descriptor

Structs

FrameLocalsProxy
PositionIterInternal
PyArithmeticError
PyAssertionError
PyAsyncGen
PyAttributeError
PyBaseException
PyBaseExceptionGroup
PyBaseObject
PyBlockingIOError
PyBool
PyBoundMethod
PyBrokenPipeError
PyBufferError
PyByteArray
PyBytes
PyBytesWarning
PyCallableIterator
PyCapsule
PyChildProcessError
PyClassMethod
PyCode
PyComplex
PyConnectionAbortedError
PyConnectionError
PyConnectionRefusedError
PyConnectionResetError
PyCoroutine
PyDeprecationWarning
PyDict
PyEOFError
PyEllipsis
PyEncodingWarning
PyEnumerate
PyException
PyFileExistsError
PyFileNotFoundError
PyFilter
PyFloat
PyFloatingPointError
PyFrozenSet
PyFunction
PyFutureWarning
PyGenerator
PyGeneratorExit
PyGenericAlias
PyGetSet
PyImportError
PyImportWarning
PyIncompleteInputError
PyIndentationError
PyIndexError
PyInt
PyInterpolation
PyInterruptedError
PyIsADirectoryError
PyKeyError
PyKeyboardInterrupt
PyList
PyLookupError
PyMap
PyMappingProxy
PyMemoryError
PyMemoryView
PyModule
PyModuleDef
PyModuleNotFoundError
PyModuleSlots
PyNameError
PyNamespace
PyNone
PyNotADirectoryError
PyNotImplemented
PyNotImplementedError
PyOSError
PyOverflowError
PyPendingDeprecationWarning
PyPermissionError
PyProcessLookupError
PyProperty
PyPythonFinalizationError
PyRange
PyRecursionError
PyReferenceError
PyResourceWarning
PyRuntimeError
PyRuntimeWarning
PySequenceIterator
PySet
PySlice
PyStaticMethod
PyStopAsyncIteration
PyStopIteration
PyStr
PySuper
PySyntaxError
PySyntaxWarning
PySystemError
PySystemExit
PyTabError
PyTemplate
PyTemplateIter
PyTimeoutError
PyTraceback
PyTuple
PyType
PyTypeError
PyUnboundLocalError
PyUnicodeDecodeError
PyUnicodeEncodeError
PyUnicodeError
PyUnicodeTranslateError
PyUnicodeWarning
PyUnion
PyUserWarning
PyUtf8Str
PyValueError
PyWarning
PyWeak
PyWeakCallableProxy
PyWeakProxy
PyZeroDivisionError
PyZip
WeakProxyNewArgs

Enums

IterStatus
Marks status of iterator.

Functions

builtins_iter
builtins_reversed
init
locked_next
PositionIterInternal::next with the release [locked_step] describes.
locked_rev_next
locked_next walking backwards.
make_union
object_generic_set_dict
= PyObject_GenericSetDict
object_get_dict
parse_float_from_string
try_bigint_to_f64
try_f64_to_bigint

Type Aliases

PyBaseExceptionRef
PyBytesRef
PyDictRef
PyIntRef
PyListRef
PyStrInterned
The unique reference of interned PyStr Always intended to be used as a static reference
PyStrRef
PyTupleRef
PyTypeRef
PyUtf8StrInterned
Interned PyUtf8Str — guaranteed UTF-8 at type level. Same layout as PyStrInterned due to #[repr(transparent)] on both PyInterned<T> and PyUtf8Str.
PyUtf8StrRef