PositionIterInternal

Struct PositionIterInternal 

pub struct PositionIterInternal<T> {
    pub status: IterStatus<T>,
    pub position: usize,
}

Fields

status: IterStatus<T>position: usize

Implementations

Source

impl<T> PositionIterInternal<T>

pub const fn new(obj: T, position: usize) -> Self

pub fn set_state<F>( &mut self, state: PyObjectRef, f: F, vm: &VirtualMachine, ) -> PyResult<()>
where F: FnOnce(&T, usize) -> usize,

pub fn reduce<F, E>( &self, func: PyObjectRef, active: F, empty: E, vm: &VirtualMachine, ) -> PyTupleRef

Build a pickle-compatible reduce tuple.

func must be resolved before acquiring any lock that guards this PositionIterInternal, so that the builtins lookup cannot trigger reentrant iterator access and deadlock.

pub fn next<F>(&mut self, f: F) -> PyResult<PyIterReturn>

pub fn rev_next<F>(&mut self, f: F) -> PyResult<PyIterReturn>

pub fn length_hint<F>(&self, f: F) -> usize
where F: FnOnce(&T) -> usize,

pub fn rev_length_hint<F>(&self, f: F) -> usize
where F: FnOnce(&T) -> usize,