pub struct PyCode {
pub code: CodeObject<Literal>,
pub instrumentation_version: AtomicU64,
pub monitoring_data: PyMutex<Option<CoMonitoringData>>,
pub quickened: AtomicBool,
/* private fields */
}Fields
code: CodeObject<Literal>instrumentation_version: AtomicU64Version counter for lazy re-instrumentation.
Compared against PyGlobalState::instrumentation_version at RESUME.
monitoring_data: PyMutex<Option<CoMonitoringData>>Side-table for INSTRUMENTED_LINE / INSTRUMENTED_INSTRUCTION.
quickened: AtomicBoolWhether adaptive counters have been initialized (lazy quickening).
Implementations
Sourceimpl PyCode
impl PyCode
pub fn new(code: CodeObject<Literal>) -> Self
pub fn source_path(&self) -> &'static PyStrInterned
pub fn set_source_path(&self, new: &'static PyStrInterned)
pub fn from_pyc_path(path: &Path, vm: &VirtualMachine) -> PyResult<PyRef<Self>>
pub fn from_pyc( pyc_bytes: &[u8], name: Option<&str>, bytecode_path: Option<&str>, source_path: Option<&str>, vm: &VirtualMachine, ) -> PyResult<PyRef<Self>>
Sourceimpl PyCode
impl PyCode
pub fn co_filename(&self) -> PyStrRef
pub fn co_cellvars(&self, vm: &VirtualMachine) -> PyTupleRef
pub fn co_varnames(&self, vm: &VirtualMachine) -> PyTupleRef
pub fn co_code(&self, vm: &VirtualMachine) -> PyBytesRef
pub fn _co_code_adaptive(&self, vm: &VirtualMachine) -> PyBytesRef
pub fn co_freevars(&self, vm: &VirtualMachine) -> PyTupleRef
pub fn co_linetable(&self, vm: &VirtualMachine) -> PyBytesRef
pub fn co_exceptiontable(&self, vm: &VirtualMachine) -> PyBytesRef
pub fn co_lines(&self, vm: &VirtualMachine) -> PyResult<PyObjectRef>
pub fn co_positions(&self, vm: &VirtualMachine) -> PyResult<PyObjectRef>
pub fn co_branches(&self, vm: &VirtualMachine) -> PyResult<PyObjectRef>
pub fn __replace__( &self, args: ReplaceArgs, vm: &VirtualMachine, ) -> PyResult<Self>
pub fn replace(&self, args: ReplaceArgs, vm: &VirtualMachine) -> PyResult<Self>
Methods from Deref<Target = CodeObject<Literal>>
Sourcepub fn arg_names(&self) -> Arguments<'_, <C as Constant>::Name>
pub fn arg_names(&self) -> Arguments<'_, <C as Constant>::Name>
Get all arguments of the code object like inspect.getargs
Sourcepub fn label_targets(&self) -> BTreeSet<Label>
pub fn label_targets(&self) -> BTreeSet<Label>
Return the labels targeted by the instructions of this CodeObject
Sourcepub fn display_expand_code_objects(&self) -> impl Display
pub fn display_expand_code_objects(&self) -> impl Display
Recursively display this CodeObject
Sourcepub fn map_clone_bag<Bag>(
&self,
bag: &Bag,
) -> CodeObject<<Bag as ConstantBag>::Constant>where
Bag: ConstantBag,
pub fn map_clone_bag<Bag>(
&self,
bag: &Bag,
) -> CodeObject<<Bag as ConstantBag>::Constant>where
Bag: ConstantBag,
Same as map_bag but clones self