pub struct PyDict { /* private fields */ }Implementations
Sourceimpl PyDict
impl PyDict
pub fn new_ref(ctx: &Context) -> PyRef<Self>
👎Deprecated:
use PyDict::default().into_ref() instead
Sourcepub fn keys_vec(&self) -> Vec<PyObjectRef>
pub fn keys_vec(&self) -> Vec<PyObjectRef>
Returns all keys as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.
Sourcepub fn values_vec(&self) -> Vec<PyObjectRef>
pub fn values_vec(&self) -> Vec<PyObjectRef>
Returns all values as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.
Sourcepub fn items_vec(&self) -> Vec<(PyObjectRef, PyObjectRef)>
pub fn items_vec(&self) -> Vec<(PyObjectRef, PyObjectRef)>
Returns all items as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.
pub fn merge_object( &self, other: PyObjectRef, vm: &VirtualMachine, ) -> PyResult<()>
pub fn merge_object_if_missing( &self, other: PyObjectRef, vm: &VirtualMachine, ) -> PyResult<()>
pub fn merge_from_seq2( &self, seq2: &PyObject, override_existing: bool, vm: &VirtualMachine, ) -> PyResult<()>
pub fn is_empty(&self) -> bool
Sourcepub fn inner_setitem<K: DictKey + ?Sized>(
&self,
key: &K,
value: PyObjectRef,
vm: &VirtualMachine,
) -> PyResult<()>
pub fn inner_setitem<K: DictKey + ?Sized>( &self, key: &K, value: PyObjectRef, vm: &VirtualMachine, ) -> PyResult<()>
Set item variant which can be called with multiple key types, such as str to name a notable one.
pub fn get_or_insert( &self, vm: &VirtualMachine, key: &PyObject, default: impl FnOnce() -> PyObjectRef, ) -> PyResult
pub fn from_attributes( attrs: IndexMap<&'static PyStrInterned, PyObjectRef, RandomState>, vm: &VirtualMachine, ) -> PyResult<Self>
pub fn contains_key<K: DictKey + ?Sized>( &self, key: &K, vm: &VirtualMachine, ) -> bool
pub fn size(&self) -> DictSize
pub fn next_entry( &self, position: usize, ) -> Option<(usize, PyObjectRef, PyObjectRef)>
pub fn inner_getitem_opt<K: DictKey + ?Sized>( &self, key: &K, vm: &VirtualMachine, ) -> PyResult<Option<PyObjectRef>>