PyDict

Struct PyDict 

pub struct PyDict { /* private fields */ }

Implementations

Source

impl PyDict

pub fn new_ref(ctx: &Context) -> PyRef<Self>

👎Deprecated:

use PyDict::default().into_ref() instead

pub fn keys_vec(&self) -> Vec<PyObjectRef>

Returns all keys as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.

pub fn values_vec(&self) -> Vec<PyObjectRef>

Returns all values as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.

pub fn items_vec(&self) -> Vec<(PyObjectRef, PyObjectRef)>

Returns all items as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.

pub fn is_empty(&self) -> bool

pub fn get_or_insert( &self, vm: &VirtualMachine, key: PyObjectRef, default: impl FnOnce() -> PyObjectRef, ) -> PyResult

pub fn from_attributes( attrs: IndexMap<&'static PyStrInterned, PyObjectRef, RandomState>, vm: &VirtualMachine, ) -> PyResult<Self>

pub fn contains_key<K: DictKey + ?Sized>( &self, key: &K, vm: &VirtualMachine, ) -> bool

pub fn size(&self) -> DictSize

Source

impl PyDict

pub fn __len__(&self) -> usize

pub fn clear(&self)

pub fn copy(&self) -> Self