pub struct PyDict { /* private fields */ }Implementations
Sourceimpl PyDict
impl PyDict
pub fn new_ref(ctx: &Context) -> PyRef<Self>
👎Deprecated:
use PyDict::default().into_ref() instead
Sourcepub fn keys_vec(&self) -> Vec<PyObjectRef>
pub fn keys_vec(&self) -> Vec<PyObjectRef>
Returns all keys as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.
Sourcepub fn values_vec(&self) -> Vec<PyObjectRef>
pub fn values_vec(&self) -> Vec<PyObjectRef>
Returns all values as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.
Sourcepub fn items_vec(&self) -> Vec<(PyObjectRef, PyObjectRef)>
pub fn items_vec(&self) -> Vec<(PyObjectRef, PyObjectRef)>
Returns all items as a Vec, atomically under a single read lock. Thread-safe: prevents “dictionary changed size during iteration” errors.
pub fn is_empty(&self) -> bool
pub fn get_or_insert( &self, vm: &VirtualMachine, key: PyObjectRef, default: impl FnOnce() -> PyObjectRef, ) -> PyResult
pub fn from_attributes( attrs: IndexMap<&'static PyStrInterned, PyObjectRef, RandomState>, vm: &VirtualMachine, ) -> PyResult<Self>
pub fn contains_key<K: DictKey + ?Sized>( &self, key: &K, vm: &VirtualMachine, ) -> bool
pub fn size(&self) -> DictSize