pub struct PyMemoryView { /* private fields */ }Implementations
Sourceimpl PyMemoryView
impl PyMemoryView
Sourcepub fn from_object(obj: &PyObject, vm: &VirtualMachine) -> PyResult<Self>
pub fn from_object(obj: &PyObject, vm: &VirtualMachine) -> PyResult<Self>
this should be the main entrance to create the memoryview to avoid the chained memoryview
Sourcepub fn from_buffer(buffer: PyBuffer, vm: &VirtualMachine) -> PyResult<Self>
pub fn from_buffer(buffer: PyBuffer, vm: &VirtualMachine) -> PyResult<Self>
don’t use this function to create the memoryview if the buffer is exporting via another memoryview, use PyMemoryView::new_view() or PyMemoryView::from_object to reduce the chain
Sourcepub fn from_buffer_range(
buffer: PyBuffer,
range: Range<usize>,
vm: &VirtualMachine,
) -> PyResult<Self>
pub fn from_buffer_range( buffer: PyBuffer, range: Range<usize>, vm: &VirtualMachine, ) -> PyResult<Self>
don’t use this function to create the memoryview if the buffer is exporting via another memoryview, use PyMemoryView::new_view() or PyMemoryView::from_object to reduce the chain
Sourcepub fn new_view(&self) -> Self
pub fn new_view(&self) -> Self
this should be the only way to create a memoryview from another memoryview
Sourcepub fn to_contiguous(&self, vm: &VirtualMachine) -> PyBuffer
pub fn to_contiguous(&self, vm: &VirtualMachine) -> PyBuffer
clone data from memoryview keep the shape, convert to contiguous
Sourceimpl PyMemoryView
impl PyMemoryView