pub struct PyType {
pub base: Option<PyTypeRef>,
pub bases: PyRwLock<Vec<PyTypeRef>>,
pub mro: PyRwLock<Vec<PyTypeRef>>,
pub subclasses: PyRwLock<Vec<PyRef<PyWeak>>>,
pub attributes: PyRwLock<IndexMap<&'static PyStrInterned, PyObjectRef, RandomState>>,
pub slots: PyTypeSlots,
pub heaptype_ext: Option<Pin<Box<HeapTypeExt>>>,
pub tp_version_tag: AtomicU32,
}Fields
base: Option<PyTypeRef>bases: PyRwLock<Vec<PyTypeRef>>mro: PyRwLock<Vec<PyTypeRef>>subclasses: PyRwLock<Vec<PyRef<PyWeak>>>attributes: PyRwLock<IndexMap<&'static PyStrInterned, PyObjectRef, RandomState>>slots: PyTypeSlotsheaptype_ext: Option<Pin<Box<HeapTypeExt>>>tp_version_tag: AtomicU32Type version tag for inline caching. 0 means unassigned/invalidated.
Implementations
Sourceimpl PyType
impl PyType
Sourcepub fn assign_version_tag(&self) -> u32
pub fn assign_version_tag(&self) -> u32
Assign a fresh version tag. Returns 0 if the version counter has been exhausted, in which case no new cache entries can be created.
pub fn new_simple_heap( name: &str, base: &Py<PyType>, ctx: &Context, ) -> Result<PyRef<Self>, String>
pub fn new_heap( name: &str, bases: Vec<PyRef<Self>>, attrs: IndexMap<&'static PyStrInterned, PyObjectRef, RandomState>, slots: PyTypeSlots, metaclass: PyRef<Self>, ctx: &Context, ) -> Result<PyRef<Self>, String>
pub fn new_static( base: PyRef<Self>, attrs: IndexMap<&'static PyStrInterned, PyObjectRef, RandomState>, slots: PyTypeSlots, metaclass: PyRef<Self>, ) -> Result<PyRef<Self>, String>
pub fn set_str_attr<V: Into<PyObjectRef>>( &self, attr_name: &str, value: V, ctx: impl AsRef<Context>, )
pub fn set_attr(&self, attr_name: &'static PyStrInterned, value: PyObjectRef)
Sourcepub fn get_attr(&self, attr_name: &'static PyStrInterned) -> Option<PyObjectRef>
pub fn get_attr(&self, attr_name: &'static PyStrInterned) -> Option<PyObjectRef>
Internal get_attr implementation for fast lookup on a class. Searches the full MRO (including self) with method cache acceleration.
pub fn get_direct_attr( &self, attr_name: &'static PyStrInterned, ) -> Option<PyObjectRef>
Sourcepub fn lookup_ref(
&self,
name: &Py<PyStr>,
vm: &VirtualMachine,
) -> Option<PyObjectRef>
pub fn lookup_ref( &self, name: &Py<PyStr>, vm: &VirtualMachine, ) -> Option<PyObjectRef>
_PyType_LookupRef: look up a name through the MRO without setting an exception.
pub fn get_super_attr( &self, attr_name: &'static PyStrInterned, ) -> Option<PyObjectRef>
Sourcepub fn has_attr(&self, attr_name: &'static PyStrInterned) -> bool
pub fn has_attr(&self, attr_name: &'static PyStrInterned) -> bool
Fast lookup for attribute existence on a class.
pub fn get_attributes( &self, ) -> IndexMap<&'static PyStrInterned, PyObjectRef, RandomState>
pub fn slot_name(&self) -> BorrowedValue<'_, str>
pub fn name(&self) -> BorrowedValue<'_, str>
Sourcepub fn init_type_data<T: Any + Send + Sync + 'static>(
&self,
data: T,
) -> Result<(), String>
pub fn init_type_data<T: Any + Send + Sync + 'static>( &self, data: T, ) -> Result<(), String>
Initialize type data for this type. Can only be called once. Returns an error if the type is not a heap type or if data is already initialized.
Sourcepub fn get_type_data<T: Any + 'static>(&self) -> Option<TypeDataRef<'_, T>>
pub fn get_type_data<T: Any + 'static>(&self) -> Option<TypeDataRef<'_, T>>
Get a read guard to the type data. Returns None if the type is not a heap type, has no data, or the data type doesn’t match.
Sourcepub fn get_type_data_mut<T: Any + 'static>(
&self,
) -> Option<TypeDataRefMut<'_, T>>
pub fn get_type_data_mut<T: Any + 'static>( &self, ) -> Option<TypeDataRefMut<'_, T>>
Get a write guard to the type data. Returns None if the type is not a heap type, has no data, or the data type doesn’t match.
Sourcepub fn has_type_data<T: Any + 'static>(&self) -> bool
pub fn has_type_data<T: Any + 'static>(&self) -> bool
Check if this type has type data of the given type.
Sourceimpl PyType
impl PyType
pub fn __name__(&self, vm: &VirtualMachine) -> PyStrRef
pub fn __qualname__(&self, vm: &VirtualMachine) -> PyObjectRef
pub fn __module__(&self, vm: &VirtualMachine) -> PyObjectRef
pub fn __ror__( zelf: PyObjectRef, other: PyObjectRef, vm: &VirtualMachine, ) -> PyResult
pub fn __or__( zelf: PyObjectRef, other: PyObjectRef, vm: &VirtualMachine, ) -> PyResult