#[repr(u16)]pub enum PseudoOpcode {
AnnotationsPlaceholder = 256,
Jump = 257,
JumpIfFalse = 258,
JumpIfTrue = 259,
JumpNoInterrupt = 260,
LoadClosure = 261,
PopBlock = 262,
SetupCleanup = 263,
SetupFinally = 264,
SetupWith = 265,
StoreFastMaybeNull = 266,
}Variants
AnnotationsPlaceholder = 256
Jump = 257
JumpIfFalse = 258
JumpIfTrue = 259
JumpNoInterrupt = 260
LoadClosure = 261
PopBlock = 262
SetupCleanup = 263
SetupFinally = 264
SetupWith = 265
StoreFastMaybeNull = 266
Implementations
Sourceimpl PseudoOpcode
impl PseudoOpcode
Sourcepub const fn as_instruction(&self) -> PseudoInstruction
pub const fn as_instruction(&self) -> PseudoInstruction
Converts this opcode to PseudoInstruction.
Sourcepub const fn deoptimize(self) -> PseudoOpcode
pub const fn deoptimize(self) -> PseudoOpcode
Map a specialized or instrumented opcode back to its adaptive (base) variant.
Sourceimpl PseudoOpcode
impl PseudoOpcode
pub const fn is_block_push(&self) -> bool
pub const fn is_scope_exit(&self) -> bool
pub const fn is_unconditional_jump(&self) -> bool
pub const fn is_assembler(&self) -> bool
Sourcepub const fn is_terminator(&self) -> bool
pub const fn is_terminator(&self) -> bool
CPython’s IS_TERMINATOR_OPCODE.
Sourcepub const fn is_no_fallthrough(&self) -> bool
pub const fn is_no_fallthrough(&self) -> bool
CPython’s IS_SCOPE_EXIT_OPCODE || IS_UNCONDITIONAL_JUMP_OPCODE.
Sourcepub const fn has_target(&self) -> bool
pub const fn has_target(&self) -> bool
CPython’s HAS_TARGET.
Sourcepub fn stack_effect(&self, oparg: u32) -> i32
pub fn stack_effect(&self, oparg: u32) -> i32
flowgraph.c get_stack_effects block-push non-jump case.
Sourcepub fn stack_effect_jump(&self, oparg: u32) -> i32
pub fn stack_effect_jump(&self, oparg: u32) -> i32
Handler entry effect for SETUP_* pseudo ops.
Fallthrough effect is 0 (NOPs), but when the branch is taken the handler block starts with extra values on the stack: SETUP_FINALLY: +1 (exc) SETUP_CLEANUP: +2 (lasti + exc) SETUP_WITH: +1 (pops enter result, pushes lasti + exc)
Sourceimpl PseudoOpcode
impl PseudoOpcode
pub const fn cache_entries(self) -> usize
pub const fn deopt(self) -> Option<PseudoOpcode>
Sourcepub const fn has_eval_break(self) -> bool
pub const fn has_eval_break(self) -> bool
Does this opcode have ‘HAS_EVAL_BREAK_FLAG’ set.
pub const fn is_instrumented(self) -> bool
pub fn stack_effect_info(&self, _oparg: u32) -> StackEffect
pub const fn to_base(self) -> Option<PseudoOpcode>
pub const fn to_instrumented(self) -> Option<PseudoOpcode>
pub const fn try_from_u16(value: u16) -> Result<PseudoOpcode, MarshalError>