Module compiler

Module compiler 

Modules

ast
codegen
Compile a Python AST or source code into bytecode consumable by RustPython.
core
parser
This crate can be used to parse Python source code into an Abstract Syntax Tree.

Structs

CodeObject
Primary container of a single code object. Each python function has a code object. Also a module has a code object.
CompileOpts
ParseError

Enums

CompileError
CompileErrorType
Mode

Functions

_compile_symtable
compile
Compile a given source code into a bytecode object.
compile_symtable