pub struct HashableExpr<'a>(/* private fields */);Expand description
Wrapper around Expr that implements Hash and PartialEq according to Python
semantics:
Values that compare equal (such as 1, 1.0, and True) can be used interchangeably to index the same dictionary entry.
For example, considers True, 1, and 1.0 to be equal, as they hash to the same value
in Python, along with False, 0, and 0.0.
See: https://docs.python.org/3/library/stdtypes.html#mapping-types-dict