pub enum FStringPart {
Literal(StringLiteral),
FString(FString),
}Expand description
An f-string part which is either a string literal or an f-string.
Variants
Literal(StringLiteral)
FString(FString)
Implementations
Sourceimpl FStringPart
impl FStringPart
Sourcepub const fn is_literal(&self) -> bool
pub const fn is_literal(&self) -> bool
Returns true if self is of variant Literal.
Sourcepub fn as_literal(&self) -> Option<&StringLiteral>
pub fn as_literal(&self) -> Option<&StringLiteral>
Returns Some if self is a reference of variant Literal, and None otherwise.
Sourcepub fn as_mut_literal(&mut self) -> Option<&mut StringLiteral>
pub fn as_mut_literal(&mut self) -> Option<&mut StringLiteral>
Returns Some if self is a mutable reference of variant Literal, and None otherwise.
Sourcepub fn expect_literal(self) -> StringLiteralwhere
FStringPart: Debug,
pub fn expect_literal(self) -> StringLiteralwhere
FStringPart: Debug,
Sourcepub fn literal(self) -> Option<StringLiteral>
pub fn literal(self) -> Option<StringLiteral>
Returns Some if self is of variant Literal, and None otherwise.
Sourcepub const fn is_f_string(&self) -> bool
pub const fn is_f_string(&self) -> bool
Returns true if self is of variant FString.
Sourcepub fn as_f_string(&self) -> Option<&FString>
pub fn as_f_string(&self) -> Option<&FString>
Returns Some if self is a reference of variant FString, and None otherwise.
Sourcepub fn as_mut_f_string(&mut self) -> Option<&mut FString>
pub fn as_mut_f_string(&mut self) -> Option<&mut FString>
Returns Some if self is a mutable reference of variant FString, and None otherwise.
Sourcepub fn expect_f_string(self) -> FStringwhere
FStringPart: Debug,
pub fn expect_f_string(self) -> FStringwhere
FStringPart: Debug,
Sourceimpl FStringPart
impl FStringPart
pub fn quote_style(&self) -> Quote
pub fn is_empty_literal(&self) -> bool