pub enum ModRef<'a> {
Module(&'a ModModule),
Expression(&'a ModExpression),
}Expand description
See also mod
Variants
Module(&'a ModModule)
Expression(&'a ModExpression)
Implementations
Sourceimpl<'a> ModRef<'a>
impl<'a> ModRef<'a>
Sourcepub fn as_module(&self) -> Option<&&'a ModModule>
pub fn as_module(&self) -> Option<&&'a ModModule>
Returns Some if self is a reference of variant Module, and None otherwise.
Sourcepub fn as_mut_module(&mut self) -> Option<&mut &'a ModModule>
pub fn as_mut_module(&mut self) -> Option<&mut &'a ModModule>
Returns Some if self is a mutable reference of variant Module, and None otherwise.
Sourcepub fn expect_module(self) -> &'a ModModule
pub fn expect_module(self) -> &'a ModModule
Sourcepub fn module(self) -> Option<&'a ModModule>
pub fn module(self) -> Option<&'a ModModule>
Returns Some if self is of variant Module, and None otherwise.
Sourcepub const fn is_expression(&self) -> bool
pub const fn is_expression(&self) -> bool
Returns true if self is of variant Expression.
Sourcepub fn as_expression(&self) -> Option<&&'a ModExpression>
pub fn as_expression(&self) -> Option<&&'a ModExpression>
Returns Some if self is a reference of variant Expression, and None otherwise.
Sourcepub fn as_mut_expression(&mut self) -> Option<&mut &'a ModExpression>
pub fn as_mut_expression(&mut self) -> Option<&mut &'a ModExpression>
Returns Some if self is a mutable reference of variant Expression, and None otherwise.
Sourcepub fn expect_expression(self) -> &'a ModExpression
pub fn expect_expression(self) -> &'a ModExpression
Unwraps the value, yielding the content of Expression.
Panics
Panics if the value is not Expression. In debug builds the panic message includes the content of self.
Sourcepub fn expression(self) -> Option<&'a ModExpression>
pub fn expression(self) -> Option<&'a ModExpression>
Returns Some if self is of variant Expression, and None otherwise.