pub enum Number {
Int(Int),
Float(f64),
Complex {
real: f64,
imag: f64,
},
}Variants
Implementations
Sourceimpl Number
impl Number
Sourcepub fn as_int(&self) -> Option<&Int>
pub fn as_int(&self) -> Option<&Int>
Returns Some if self is a reference of variant Int, and None otherwise.
Sourcepub fn as_mut_int(&mut self) -> Option<&mut Int>
pub fn as_mut_int(&mut self) -> Option<&mut Int>
Returns Some if self is a mutable reference of variant Int, and None otherwise.
Sourcepub fn expect_int(self) -> Int
pub fn expect_int(self) -> Int
Sourcepub fn as_float(&self) -> Option<&f64>
pub fn as_float(&self) -> Option<&f64>
Returns Some if self is a reference of variant Float, and None otherwise.
Sourcepub fn as_mut_float(&mut self) -> Option<&mut f64>
pub fn as_mut_float(&mut self) -> Option<&mut f64>
Returns Some if self is a mutable reference of variant Float, and None otherwise.
Sourcepub fn expect_float(self) -> f64
pub fn expect_float(self) -> f64
Sourcepub fn float(self) -> Option<f64>
pub fn float(self) -> Option<f64>
Returns Some if self is of variant Float, and None otherwise.
Sourcepub const fn is_complex(&self) -> bool
pub const fn is_complex(&self) -> bool
Returns true if self is of variant Complex.