pub enum PySourceType {
Python,
Stub,
Ipynb,
}Variants
Python
The source is a Python file (.py, .pyw).
Note: .pyw files contain Python code, but do not represent importable namespaces.
Consider adding a separate source type later if combining the two causes issues.
Stub
The source is a Python stub file (.pyi).
Ipynb
The source is a Jupyter notebook (.ipynb).
Implementations
Sourceimpl PySourceType
impl PySourceType
Sourcepub fn from_extension(extension: &str) -> PySourceType
pub fn from_extension(extension: &str) -> PySourceType
Infers the source type from the file extension.
Falls back to Python if the extension is not recognized.
Sourcepub fn try_from_extension(extension: &str) -> Option<PySourceType>
pub fn try_from_extension(extension: &str) -> Option<PySourceType>
Infers the source type from the file extension.
pub fn try_from_path(path: impl AsRef<Path>) -> Option<PySourceType>
pub const fn is_py_file(self) -> bool
pub const fn is_stub(self) -> bool
pub const fn is_py_file_or_stub(self) -> bool
pub const fn is_ipynb(self) -> bool