#[repr(u8)]pub enum RootNodeKind {
Show 27 variants
Mod = 0,
Stmt = 1,
Expr = 2,
ExceptHandler = 3,
InterpolatedStringElement = 4,
Pattern = 5,
TypeParam = 6,
InterpolatedStringFormatSpec = 7,
PatternArguments = 8,
PatternKeyword = 9,
Comprehension = 10,
Arguments = 11,
Parameters = 12,
Parameter = 13,
ParameterWithDefault = 14,
Keyword = 15,
Alias = 16,
WithItem = 17,
MatchCase = 18,
Decorator = 19,
ElifElseClause = 20,
TypeParams = 21,
FString = 22,
TString = 23,
StringLiteral = 24,
BytesLiteral = 25,
Identifier = 26,
}Expand description
The unflattened enum or struct type stored by an AnyRootNodeRef.
Unlike NodeKind, this does not distinguish variants of root enums such as Stmt
and Expr.
Variants
Mod = 0
Stmt = 1
Expr = 2
ExceptHandler = 3
InterpolatedStringElement = 4
Pattern = 5
TypeParam = 6
InterpolatedStringFormatSpec = 7
PatternArguments = 8
PatternKeyword = 9
Comprehension = 10
Arguments = 11
Parameters = 12
Parameter = 13
ParameterWithDefault = 14
Keyword = 15
Alias = 16
WithItem = 17
MatchCase = 18
Decorator = 19
ElifElseClause = 20
TypeParams = 21
FString = 22
TString = 23
StringLiteral = 24
BytesLiteral = 25
Identifier = 26
Implementations
Sourceimpl RootNodeKind
impl RootNodeKind
Sourcepub const ALL: &'static [RootNodeKind]
pub const ALL: &'static [RootNodeKind]
All root node kinds in discriminant order.
Sourcepub fn from_u8(value: u8) -> Option<RootNodeKind>
pub fn from_u8(value: u8) -> Option<RootNodeKind>
Returns the root node kind with the given discriminant.