StmtRef

Enum StmtRef 

pub enum StmtRef<'a> {
Show 25 variants FunctionDef(&'a StmtFunctionDef), ClassDef(&'a StmtClassDef), Return(&'a StmtReturn), Delete(&'a StmtDelete), TypeAlias(&'a StmtTypeAlias), Assign(&'a StmtAssign), AugAssign(&'a StmtAugAssign), AnnAssign(&'a StmtAnnAssign), For(&'a StmtFor), While(&'a StmtWhile), If(&'a StmtIf), With(&'a StmtWith), Match(&'a StmtMatch), Raise(&'a StmtRaise), Try(&'a StmtTry), Assert(&'a StmtAssert), Import(&'a StmtImport), ImportFrom(&'a StmtImportFrom), Global(&'a StmtGlobal), Nonlocal(&'a StmtNonlocal), Expr(&'a StmtExpr), Pass(&'a StmtPass), Break(&'a StmtBreak), Continue(&'a StmtContinue), IpyEscapeCommand(&'a StmtIpyEscapeCommand),
}
See also stmt

Variants



FunctionDef(&'a StmtFunctionDef)



ClassDef(&'a StmtClassDef)



Return(&'a StmtReturn)



Delete(&'a StmtDelete)



TypeAlias(&'a StmtTypeAlias)



Assign(&'a StmtAssign)



AugAssign(&'a StmtAugAssign)



AnnAssign(&'a StmtAnnAssign)



For(&'a StmtFor)



While(&'a StmtWhile)



If(&'a StmtIf)



With(&'a StmtWith)



Match(&'a StmtMatch)



Raise(&'a StmtRaise)



Try(&'a StmtTry)



Assert(&'a StmtAssert)



Import(&'a StmtImport)



ImportFrom(&'a StmtImportFrom)



Global(&'a StmtGlobal)



Nonlocal(&'a StmtNonlocal)



Expr(&'a StmtExpr)



Pass(&'a StmtPass)



Break(&'a StmtBreak)



Continue(&'a StmtContinue)



IpyEscapeCommand(&'a StmtIpyEscapeCommand)

Implementations

Source

impl<'a> StmtRef<'a>

pub const fn is_function_def_stmt(&self) -> bool

Returns true if self is of variant FunctionDef.

pub fn as_function_def_stmt(&self) -> Option<&&'a StmtFunctionDef>

Returns Some if self is a reference of variant FunctionDef, and None otherwise.

pub fn as_mut_function_def_stmt(&mut self) -> Option<&mut &'a StmtFunctionDef>

Returns Some if self is a mutable reference of variant FunctionDef, and None otherwise.

pub fn expect_function_def_stmt(self) -> &'a StmtFunctionDef
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of FunctionDef.

Panics

Panics if the value is not FunctionDef, with a panic message including the content of self.

pub fn function_def_stmt(self) -> Option<&'a StmtFunctionDef>

Returns Some if self is of variant FunctionDef, and None otherwise.

pub const fn is_class_def_stmt(&self) -> bool

Returns true if self is of variant ClassDef.

pub fn as_class_def_stmt(&self) -> Option<&&'a StmtClassDef>

Returns Some if self is a reference of variant ClassDef, and None otherwise.

pub fn as_mut_class_def_stmt(&mut self) -> Option<&mut &'a StmtClassDef>

Returns Some if self is a mutable reference of variant ClassDef, and None otherwise.

pub fn expect_class_def_stmt(self) -> &'a StmtClassDef
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of ClassDef.

Panics

Panics if the value is not ClassDef, with a panic message including the content of self.

pub fn class_def_stmt(self) -> Option<&'a StmtClassDef>

Returns Some if self is of variant ClassDef, and None otherwise.

pub const fn is_return_stmt(&self) -> bool

Returns true if self is of variant Return.

pub fn as_return_stmt(&self) -> Option<&&'a StmtReturn>

Returns Some if self is a reference of variant Return, and None otherwise.

pub fn as_mut_return_stmt(&mut self) -> Option<&mut &'a StmtReturn>

Returns Some if self is a mutable reference of variant Return, and None otherwise.

pub fn expect_return_stmt(self) -> &'a StmtReturn
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Return.

Panics

Panics if the value is not Return, with a panic message including the content of self.

pub fn return_stmt(self) -> Option<&'a StmtReturn>

Returns Some if self is of variant Return, and None otherwise.

pub const fn is_delete_stmt(&self) -> bool

Returns true if self is of variant Delete.

pub fn as_delete_stmt(&self) -> Option<&&'a StmtDelete>

Returns Some if self is a reference of variant Delete, and None otherwise.

pub fn as_mut_delete_stmt(&mut self) -> Option<&mut &'a StmtDelete>

Returns Some if self is a mutable reference of variant Delete, and None otherwise.

pub fn expect_delete_stmt(self) -> &'a StmtDelete
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Delete.

Panics

Panics if the value is not Delete, with a panic message including the content of self.

pub fn delete_stmt(self) -> Option<&'a StmtDelete>

Returns Some if self is of variant Delete, and None otherwise.

pub const fn is_type_alias_stmt(&self) -> bool

Returns true if self is of variant TypeAlias.

pub fn as_type_alias_stmt(&self) -> Option<&&'a StmtTypeAlias>

Returns Some if self is a reference of variant TypeAlias, and None otherwise.

pub fn as_mut_type_alias_stmt(&mut self) -> Option<&mut &'a StmtTypeAlias>

Returns Some if self is a mutable reference of variant TypeAlias, and None otherwise.

pub fn expect_type_alias_stmt(self) -> &'a StmtTypeAlias
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of TypeAlias.

Panics

Panics if the value is not TypeAlias, with a panic message including the content of self.

pub fn type_alias_stmt(self) -> Option<&'a StmtTypeAlias>

Returns Some if self is of variant TypeAlias, and None otherwise.

pub const fn is_assign_stmt(&self) -> bool

Returns true if self is of variant Assign.

pub fn as_assign_stmt(&self) -> Option<&&'a StmtAssign>

Returns Some if self is a reference of variant Assign, and None otherwise.

pub fn as_mut_assign_stmt(&mut self) -> Option<&mut &'a StmtAssign>

Returns Some if self is a mutable reference of variant Assign, and None otherwise.

pub fn expect_assign_stmt(self) -> &'a StmtAssign
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Assign.

Panics

Panics if the value is not Assign, with a panic message including the content of self.

pub fn assign_stmt(self) -> Option<&'a StmtAssign>

Returns Some if self is of variant Assign, and None otherwise.

pub const fn is_aug_assign_stmt(&self) -> bool

Returns true if self is of variant AugAssign.

pub fn as_aug_assign_stmt(&self) -> Option<&&'a StmtAugAssign>

Returns Some if self is a reference of variant AugAssign, and None otherwise.

pub fn as_mut_aug_assign_stmt(&mut self) -> Option<&mut &'a StmtAugAssign>

Returns Some if self is a mutable reference of variant AugAssign, and None otherwise.

pub fn expect_aug_assign_stmt(self) -> &'a StmtAugAssign
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of AugAssign.

Panics

Panics if the value is not AugAssign, with a panic message including the content of self.

pub fn aug_assign_stmt(self) -> Option<&'a StmtAugAssign>

Returns Some if self is of variant AugAssign, and None otherwise.

pub const fn is_ann_assign_stmt(&self) -> bool

Returns true if self is of variant AnnAssign.

pub fn as_ann_assign_stmt(&self) -> Option<&&'a StmtAnnAssign>

Returns Some if self is a reference of variant AnnAssign, and None otherwise.

pub fn as_mut_ann_assign_stmt(&mut self) -> Option<&mut &'a StmtAnnAssign>

Returns Some if self is a mutable reference of variant AnnAssign, and None otherwise.

pub fn expect_ann_assign_stmt(self) -> &'a StmtAnnAssign
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of AnnAssign.

Panics

Panics if the value is not AnnAssign, with a panic message including the content of self.

pub fn ann_assign_stmt(self) -> Option<&'a StmtAnnAssign>

Returns Some if self is of variant AnnAssign, and None otherwise.

pub const fn is_for_stmt(&self) -> bool

Returns true if self is of variant For.

pub fn as_for_stmt(&self) -> Option<&&'a StmtFor>

Returns Some if self is a reference of variant For, and None otherwise.

pub fn as_mut_for_stmt(&mut self) -> Option<&mut &'a StmtFor>

Returns Some if self is a mutable reference of variant For, and None otherwise.

pub fn expect_for_stmt(self) -> &'a StmtFor
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of For.

Panics

Panics if the value is not For, with a panic message including the content of self.

pub fn for_stmt(self) -> Option<&'a StmtFor>

Returns Some if self is of variant For, and None otherwise.

pub const fn is_while_stmt(&self) -> bool

Returns true if self is of variant While.

pub fn as_while_stmt(&self) -> Option<&&'a StmtWhile>

Returns Some if self is a reference of variant While, and None otherwise.

pub fn as_mut_while_stmt(&mut self) -> Option<&mut &'a StmtWhile>

Returns Some if self is a mutable reference of variant While, and None otherwise.

pub fn expect_while_stmt(self) -> &'a StmtWhile
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of While.

Panics

Panics if the value is not While, with a panic message including the content of self.

pub fn while_stmt(self) -> Option<&'a StmtWhile>

Returns Some if self is of variant While, and None otherwise.

pub const fn is_if_stmt(&self) -> bool

Returns true if self is of variant If.

pub fn as_if_stmt(&self) -> Option<&&'a StmtIf>

Returns Some if self is a reference of variant If, and None otherwise.

pub fn as_mut_if_stmt(&mut self) -> Option<&mut &'a StmtIf>

Returns Some if self is a mutable reference of variant If, and None otherwise.

pub fn expect_if_stmt(self) -> &'a StmtIf
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of If.

Panics

Panics if the value is not If, with a panic message including the content of self.

pub fn if_stmt(self) -> Option<&'a StmtIf>

Returns Some if self is of variant If, and None otherwise.

pub const fn is_with_stmt(&self) -> bool

Returns true if self is of variant With.

pub fn as_with_stmt(&self) -> Option<&&'a StmtWith>

Returns Some if self is a reference of variant With, and None otherwise.

pub fn as_mut_with_stmt(&mut self) -> Option<&mut &'a StmtWith>

Returns Some if self is a mutable reference of variant With, and None otherwise.

pub fn expect_with_stmt(self) -> &'a StmtWith
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of With.

Panics

Panics if the value is not With, with a panic message including the content of self.

pub fn with_stmt(self) -> Option<&'a StmtWith>

Returns Some if self is of variant With, and None otherwise.

pub const fn is_match_stmt(&self) -> bool

Returns true if self is of variant Match.

pub fn as_match_stmt(&self) -> Option<&&'a StmtMatch>

Returns Some if self is a reference of variant Match, and None otherwise.

pub fn as_mut_match_stmt(&mut self) -> Option<&mut &'a StmtMatch>

Returns Some if self is a mutable reference of variant Match, and None otherwise.

pub fn expect_match_stmt(self) -> &'a StmtMatch
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Match.

Panics

Panics if the value is not Match, with a panic message including the content of self.

pub fn match_stmt(self) -> Option<&'a StmtMatch>

Returns Some if self is of variant Match, and None otherwise.

pub const fn is_raise_stmt(&self) -> bool

Returns true if self is of variant Raise.

pub fn as_raise_stmt(&self) -> Option<&&'a StmtRaise>

Returns Some if self is a reference of variant Raise, and None otherwise.

pub fn as_mut_raise_stmt(&mut self) -> Option<&mut &'a StmtRaise>

Returns Some if self is a mutable reference of variant Raise, and None otherwise.

pub fn expect_raise_stmt(self) -> &'a StmtRaise
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Raise.

Panics

Panics if the value is not Raise, with a panic message including the content of self.

pub fn raise_stmt(self) -> Option<&'a StmtRaise>

Returns Some if self is of variant Raise, and None otherwise.

pub const fn is_try_stmt(&self) -> bool

Returns true if self is of variant Try.

pub fn as_try_stmt(&self) -> Option<&&'a StmtTry>

Returns Some if self is a reference of variant Try, and None otherwise.

pub fn as_mut_try_stmt(&mut self) -> Option<&mut &'a StmtTry>

Returns Some if self is a mutable reference of variant Try, and None otherwise.

pub fn expect_try_stmt(self) -> &'a StmtTry
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Try.

Panics

Panics if the value is not Try, with a panic message including the content of self.

pub fn try_stmt(self) -> Option<&'a StmtTry>

Returns Some if self is of variant Try, and None otherwise.

pub const fn is_assert_stmt(&self) -> bool

Returns true if self is of variant Assert.

pub fn as_assert_stmt(&self) -> Option<&&'a StmtAssert>

Returns Some if self is a reference of variant Assert, and None otherwise.

pub fn as_mut_assert_stmt(&mut self) -> Option<&mut &'a StmtAssert>

Returns Some if self is a mutable reference of variant Assert, and None otherwise.

pub fn expect_assert_stmt(self) -> &'a StmtAssert
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Assert.

Panics

Panics if the value is not Assert, with a panic message including the content of self.

pub fn assert_stmt(self) -> Option<&'a StmtAssert>

Returns Some if self is of variant Assert, and None otherwise.

pub const fn is_import_stmt(&self) -> bool

Returns true if self is of variant Import.

pub fn as_import_stmt(&self) -> Option<&&'a StmtImport>

Returns Some if self is a reference of variant Import, and None otherwise.

pub fn as_mut_import_stmt(&mut self) -> Option<&mut &'a StmtImport>

Returns Some if self is a mutable reference of variant Import, and None otherwise.

pub fn expect_import_stmt(self) -> &'a StmtImport
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Import.

Panics

Panics if the value is not Import, with a panic message including the content of self.

pub fn import_stmt(self) -> Option<&'a StmtImport>

Returns Some if self is of variant Import, and None otherwise.

pub const fn is_import_from_stmt(&self) -> bool

Returns true if self is of variant ImportFrom.

pub fn as_import_from_stmt(&self) -> Option<&&'a StmtImportFrom>

Returns Some if self is a reference of variant ImportFrom, and None otherwise.

pub fn as_mut_import_from_stmt(&mut self) -> Option<&mut &'a StmtImportFrom>

Returns Some if self is a mutable reference of variant ImportFrom, and None otherwise.

pub fn expect_import_from_stmt(self) -> &'a StmtImportFrom
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of ImportFrom.

Panics

Panics if the value is not ImportFrom, with a panic message including the content of self.

pub fn import_from_stmt(self) -> Option<&'a StmtImportFrom>

Returns Some if self is of variant ImportFrom, and None otherwise.

pub const fn is_global_stmt(&self) -> bool

Returns true if self is of variant Global.

pub fn as_global_stmt(&self) -> Option<&&'a StmtGlobal>

Returns Some if self is a reference of variant Global, and None otherwise.

pub fn as_mut_global_stmt(&mut self) -> Option<&mut &'a StmtGlobal>

Returns Some if self is a mutable reference of variant Global, and None otherwise.

pub fn expect_global_stmt(self) -> &'a StmtGlobal
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Global.

Panics

Panics if the value is not Global, with a panic message including the content of self.

pub fn global_stmt(self) -> Option<&'a StmtGlobal>

Returns Some if self is of variant Global, and None otherwise.

pub const fn is_nonlocal_stmt(&self) -> bool

Returns true if self is of variant Nonlocal.

pub fn as_nonlocal_stmt(&self) -> Option<&&'a StmtNonlocal>

Returns Some if self is a reference of variant Nonlocal, and None otherwise.

pub fn as_mut_nonlocal_stmt(&mut self) -> Option<&mut &'a StmtNonlocal>

Returns Some if self is a mutable reference of variant Nonlocal, and None otherwise.

pub fn expect_nonlocal_stmt(self) -> &'a StmtNonlocal
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Nonlocal.

Panics

Panics if the value is not Nonlocal, with a panic message including the content of self.

pub fn nonlocal_stmt(self) -> Option<&'a StmtNonlocal>

Returns Some if self is of variant Nonlocal, and None otherwise.

pub const fn is_expr_stmt(&self) -> bool

Returns true if self is of variant Expr.

pub fn as_expr_stmt(&self) -> Option<&&'a StmtExpr>

Returns Some if self is a reference of variant Expr, and None otherwise.

pub fn as_mut_expr_stmt(&mut self) -> Option<&mut &'a StmtExpr>

Returns Some if self is a mutable reference of variant Expr, and None otherwise.

pub fn expect_expr_stmt(self) -> &'a StmtExpr
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Expr.

Panics

Panics if the value is not Expr, with a panic message including the content of self.

pub fn expr_stmt(self) -> Option<&'a StmtExpr>

Returns Some if self is of variant Expr, and None otherwise.

pub const fn is_pass_stmt(&self) -> bool

Returns true if self is of variant Pass.

pub fn as_pass_stmt(&self) -> Option<&&'a StmtPass>

Returns Some if self is a reference of variant Pass, and None otherwise.

pub fn as_mut_pass_stmt(&mut self) -> Option<&mut &'a StmtPass>

Returns Some if self is a mutable reference of variant Pass, and None otherwise.

pub fn expect_pass_stmt(self) -> &'a StmtPass
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Pass.

Panics

Panics if the value is not Pass, with a panic message including the content of self.

pub fn pass_stmt(self) -> Option<&'a StmtPass>

Returns Some if self is of variant Pass, and None otherwise.

pub const fn is_break_stmt(&self) -> bool

Returns true if self is of variant Break.

pub fn as_break_stmt(&self) -> Option<&&'a StmtBreak>

Returns Some if self is a reference of variant Break, and None otherwise.

pub fn as_mut_break_stmt(&mut self) -> Option<&mut &'a StmtBreak>

Returns Some if self is a mutable reference of variant Break, and None otherwise.

pub fn expect_break_stmt(self) -> &'a StmtBreak
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Break.

Panics

Panics if the value is not Break, with a panic message including the content of self.

pub fn break_stmt(self) -> Option<&'a StmtBreak>

Returns Some if self is of variant Break, and None otherwise.

pub const fn is_continue_stmt(&self) -> bool

Returns true if self is of variant Continue.

pub fn as_continue_stmt(&self) -> Option<&&'a StmtContinue>

Returns Some if self is a reference of variant Continue, and None otherwise.

pub fn as_mut_continue_stmt(&mut self) -> Option<&mut &'a StmtContinue>

Returns Some if self is a mutable reference of variant Continue, and None otherwise.

pub fn expect_continue_stmt(self) -> &'a StmtContinue
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of Continue.

Panics

Panics if the value is not Continue, with a panic message including the content of self.

pub fn continue_stmt(self) -> Option<&'a StmtContinue>

Returns Some if self is of variant Continue, and None otherwise.

pub const fn is_ipy_escape_command_stmt(&self) -> bool

Returns true if self is of variant IpyEscapeCommand.

pub fn as_ipy_escape_command_stmt(&self) -> Option<&&'a StmtIpyEscapeCommand>

Returns Some if self is a reference of variant IpyEscapeCommand, and None otherwise.

pub fn as_mut_ipy_escape_command_stmt( &mut self, ) -> Option<&mut &'a StmtIpyEscapeCommand>

Returns Some if self is a mutable reference of variant IpyEscapeCommand, and None otherwise.

pub fn expect_ipy_escape_command_stmt(self) -> &'a StmtIpyEscapeCommand
where StmtRef<'a>: Debug,

Unwraps the value, yielding the content of IpyEscapeCommand.

Panics

Panics if the value is not IpyEscapeCommand, with a panic message including the content of self.

pub fn ipy_escape_command_stmt(self) -> Option<&'a StmtIpyEscapeCommand>

Returns Some if self is of variant IpyEscapeCommand, and None otherwise.