pub enum TypeParamRef<'a> {
TypeVar(&'a TypeParamTypeVar),
TypeVarTuple(&'a TypeParamTypeVarTuple),
ParamSpec(&'a TypeParamParamSpec),
}Expand description
See also type_param
Variants
TypeVar(&'a TypeParamTypeVar)
TypeVarTuple(&'a TypeParamTypeVarTuple)
ParamSpec(&'a TypeParamParamSpec)
Implementations
Sourceimpl<'a> TypeParamRef<'a>
impl<'a> TypeParamRef<'a>
Sourcepub const fn is_type_var(&self) -> bool
pub const fn is_type_var(&self) -> bool
Returns true if self is of variant TypeVar.
Sourcepub fn as_type_var(&self) -> Option<&&'a TypeParamTypeVar>
pub fn as_type_var(&self) -> Option<&&'a TypeParamTypeVar>
Returns Some if self is a reference of variant TypeVar, and None otherwise.
Sourcepub fn as_mut_type_var(&mut self) -> Option<&mut &'a TypeParamTypeVar>
pub fn as_mut_type_var(&mut self) -> Option<&mut &'a TypeParamTypeVar>
Returns Some if self is a mutable reference of variant TypeVar, and None otherwise.
Sourcepub fn expect_type_var(self) -> &'a TypeParamTypeVarwhere
TypeParamRef<'a>: Debug,
pub fn expect_type_var(self) -> &'a TypeParamTypeVarwhere
TypeParamRef<'a>: Debug,
Sourcepub fn type_var(self) -> Option<&'a TypeParamTypeVar>
pub fn type_var(self) -> Option<&'a TypeParamTypeVar>
Returns Some if self is of variant TypeVar, and None otherwise.
Sourcepub const fn is_type_var_tuple(&self) -> bool
pub const fn is_type_var_tuple(&self) -> bool
Returns true if self is of variant TypeVarTuple.
Sourcepub fn as_type_var_tuple(&self) -> Option<&&'a TypeParamTypeVarTuple>
pub fn as_type_var_tuple(&self) -> Option<&&'a TypeParamTypeVarTuple>
Returns Some if self is a reference of variant TypeVarTuple, and None otherwise.
Sourcepub fn as_mut_type_var_tuple(
&mut self,
) -> Option<&mut &'a TypeParamTypeVarTuple>
pub fn as_mut_type_var_tuple( &mut self, ) -> Option<&mut &'a TypeParamTypeVarTuple>
Returns Some if self is a mutable reference of variant TypeVarTuple, and None otherwise.
Sourcepub fn expect_type_var_tuple(self) -> &'a TypeParamTypeVarTuplewhere
TypeParamRef<'a>: Debug,
pub fn expect_type_var_tuple(self) -> &'a TypeParamTypeVarTuplewhere
TypeParamRef<'a>: Debug,
Unwraps the value, yielding the content of TypeVarTuple.
Panics
Panics if the value is not TypeVarTuple, with a panic message including the content of self.
Sourcepub fn type_var_tuple(self) -> Option<&'a TypeParamTypeVarTuple>
pub fn type_var_tuple(self) -> Option<&'a TypeParamTypeVarTuple>
Returns Some if self is of variant TypeVarTuple, and None otherwise.
Sourcepub const fn is_param_spec(&self) -> bool
pub const fn is_param_spec(&self) -> bool
Returns true if self is of variant ParamSpec.
Sourcepub fn as_param_spec(&self) -> Option<&&'a TypeParamParamSpec>
pub fn as_param_spec(&self) -> Option<&&'a TypeParamParamSpec>
Returns Some if self is a reference of variant ParamSpec, and None otherwise.
Sourcepub fn as_mut_param_spec(&mut self) -> Option<&mut &'a TypeParamParamSpec>
pub fn as_mut_param_spec(&mut self) -> Option<&mut &'a TypeParamParamSpec>
Returns Some if self is a mutable reference of variant ParamSpec, and None otherwise.
Sourcepub fn expect_param_spec(self) -> &'a TypeParamParamSpecwhere
TypeParamRef<'a>: Debug,
pub fn expect_param_spec(self) -> &'a TypeParamParamSpecwhere
TypeParamRef<'a>: Debug,
Sourcepub fn param_spec(self) -> Option<&'a TypeParamParamSpec>
pub fn param_spec(self) -> Option<&'a TypeParamParamSpec>
Returns Some if self is of variant ParamSpec, and None otherwise.