pub struct AtomicNodeIndex(/* private fields */);Expand description
A unique index for a node within an AST.
This type is interiorly mutable to allow assigning node indices on-demand after parsing.
Implementations