pub struct BytesLiteralFlags(/* private fields */);Expand description
Flags that can be queried to obtain information regarding the prefixes and quotes used for a bytes literal.
Notes on usage
If you’re using a Generator from the ruff_python_codegen crate to generate a lint-rule fix
from an existing bytes literal, consider passing along the BytesLiteral::flags field. If
you don’t have an existing literal but have a Checker from the ruff_linter crate available,
consider using Checker::default_bytes_flags to create instances of this struct; this method
will properly handle surrounding f-strings. For usage that doesn’t fit into one of these
categories, the public constructor BytesLiteralFlags::empty can be used.
Implementations
Sourceimpl BytesLiteralFlags
impl BytesLiteralFlags
Sourcepub fn empty() -> BytesLiteralFlags
pub fn empty() -> BytesLiteralFlags
Construct a new BytesLiteralFlags with no flags set.
See BytesLiteralFlags::with_quote_style, BytesLiteralFlags::with_triple_quotes, and
BytesLiteralFlags::with_prefix for ways of setting the quote style (single or double),
enabling triple quotes, and adding prefixes (such as r), respectively.
See the documentation for BytesLiteralFlags for additional caveats on this constructor,
and situations in which alternative ways to construct this struct should be used, especially
when writing lint rules.
pub fn with_quote_style(self, quote_style: Quote) -> BytesLiteralFlags
pub fn with_triple_quotes( self, triple_quotes: TripleQuotes, ) -> BytesLiteralFlags
pub fn with_unclosed(self, unclosed: bool) -> BytesLiteralFlags
pub fn with_prefix(self, prefix: ByteStringPrefix) -> BytesLiteralFlags
pub fn with_invalid(self) -> BytesLiteralFlags
pub const fn prefix(self) -> ByteStringPrefix