pub struct ExprStringLiteral {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: StringLiteralValue,
}Expand description
An AST node that represents either a single-part string literal or an implicitly concatenated string literal.
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: StringLiteralValueImplementations
Sourceimpl ExprStringLiteral
impl ExprStringLiteral
Sourcepub fn as_single_part_string(&self) -> Option<&StringLiteral>
pub fn as_single_part_string(&self) -> Option<&StringLiteral>
Return Some(literal) if the string only consists of a single StringLiteral part
(indicating that it is not implicitly concatenated). Otherwise, return None.