Compile a Python AST or source code into bytecode consumable by RustPython.
Modules
- compile
- Take an AST and transform it into bytecode
- error
- ir
- preprocess
- symboltable
Structs
Traits
Functions
- decorated_
definition_ range - The range a decorated definition covers from its
def/classkeyword on. - interpolated_
string_ literal_ value - The value of a literal written between the interpolations of an f-string or a t-string.
- interpolation_
debug_ text - The text a
{expr=}interpolation puts in front of its value, and the range that text covers. - string_
literal_ part_ value - The value of one of the literals a string literal is written as.
- string_
literal_ value - The value of a string literal.