Module compile

Module compile 

Structs

CompileOpts
FBlockInfo
PatternContext
The pattern context holds information about captured names and jump targets.

Enums

FBlockDatum
Stores additional data for fblock unwinding
FBlockType

Functions

compile_block_expression
compile_expression
compile_program
Compile a standard Python program to bytecode
compile_program_single
Compile a Python program to bytecode for the context of a REPL
compile_top
Compile an Mod produced from ruff parser
ruff_int_to_bigint