pub fn decorated_definition_range(
source_file: &SourceFile,
statement_range: TextRange,
decorator_list: &[Decorator],
keyword: &str,
) -> TextRangeExpand description
The range a decorated definition covers from its def/class keyword on.
The parser hands over a statement that starts at the first decorator, while a definition is located at the keyword that introduces it.