pub struct Block {
pub instructions: Vec<InstructionInfo>,
pub next: BlockIdx,
pub start_depth: i32,
pub preserve_lasti: bool,
pub except_handler: bool,
pub cold: bool,
/* private fields */
}Fields
instructions: Vec<InstructionInfo>CPython basicblock.b_instr, including allocated slots beyond b_iused.
next: BlockIdxstart_depth: i32Stack depth at block entry, set by stack depth analysis
preserve_lasti: boolWhether to preserve lasti for this handler block (b_preserve_lasti)
except_handler: boolWhether this block is an exception handler target (b_except_handler)
cold: boolWhether this block is only reachable via exception table (b_cold)