AnyInstruction

Enum AnyInstruction 

pub enum AnyInstruction {
    Real(Instruction),
    Pseudo(PseudoInstruction),
}

Variants

Implementations

Source

impl AnyInstruction

pub const fn real(self) -> Option<Instruction>

Gets the inner value of Self::Real.

pub const fn pseudo(self) -> Option<PseudoInstruction>

Gets the inner value of Self::Pseudo.

pub const fn expect_real(self) -> Instruction

Same as Self::real but panics if wasn’t called on Self::Real.

Panics

If was called on something else other than Self::Real.

pub const fn expect_pseudo(self) -> PseudoInstruction

Same as Self::pseudo but panics if wasn’t called on Self::Pseudo.

Panics

If was called on something else other than Self::Pseudo.

pub fn is_block_push(&self) -> bool

Returns true if this is a block push pseudo instruction (SETUP_FINALLY, SETUP_CLEANUP, or SETUP_WITH).

pub fn is_pop_block(&self) -> bool

Returns true if this is a POP_BLOCK pseudo instruction.