pub fn for_each_current_frame(f: impl FnMut(&Py<FrameObject>))Expand description
Invoke f for each frame on the current thread’s chain, from the
topmost frame down to the bottom.
pub fn for_each_current_frame(f: impl FnMut(&Py<FrameObject>))Invoke f for each frame on the current thread’s chain, from the
topmost frame down to the bottom.