Module function

Module function 

Structs

ArgBytesLike
any bytes-like object. Like the y* format code for PyArg_Parse in CPython.
ArgCallable
ArgContiguousBytesLike
A bytes-like object asked for as PyBUF_CONTIG_RO, which is what a shape is requested with rather than assumed.
ArgIndex
ArgIntoBool
A Python bool-like object.
ArgIntoComplex
A Python complex-like object.
ArgIntoFloat
A Python float-like object.
ArgIterable
An iterable Python object.
ArgMapping
ArgMemoryBuffer
A memory buffer, read-write access. Like the w* format code for PyArg_Parse in CPython.
ArgSequence
ArgStrictInt
An int (or subclass, including bool) converted to a Rust primitive.
Callee
What a message says about the function whose arguments are being bound.
FuncArgs
The FuncArgs struct is one of the most used structs when creating a rust function that can be called from python. It holds both positional arguments, as well as keyword arguments passed to the function.
HeapMethodDef
ItemDoc
Static text plus an optional span of the compressed doc blob.
KwArgs
NameArgs
NameChanges
NameCoordinates
NameExcInfo
NameFields
NameIntegers
NameIterables
NameKeywords
NameKwargs
NameKwds
NameKws
NameObjs
NameOthers
Param
PosArgs
A list of positional argument values.
PositionalIterable
One positional-only iterable, defaulting to an empty tuple.
PyMethodDef
PyMethodFlags
SigArg
One Rust argument of a native function.
TimeoutSeconds
A Python timeout value that accepts both float and int.

Enums

ArgAsciiBuffer
ArgByteOrder
ArgStrOrBytesLike
A text string or bytes-like object. Like the s* format code for PyArg_Parse in CPython.
ArgumentError
An error encountered while binding arguments to the parameters of a Python function call.
DefaultRepr
Python source for a parameter default, chosen so it can be rendered in a const context.
Either
FsPath
Helper to implement os.fspath()
OptionalArg
An argument that may or may not be provided by the caller.
ParamKind
PyArithmeticValue
PySetterValue

Traits

FromArgOptional
FromArgs
Implemented by any type that can be accepted as a parameter to a built-in function.
IntoFuncArgs
IntoPyNativeFn
Implemented by types that are or can generate built-in functions.
OptionalArgDefault
Signature default of a field marked optional.
PyNativeFn
A built-in Python function.

Functions

choose_class_params
Prefer preferred when it is a real signature, otherwise alternate.
db_doc
has_signature
False when an argument is a destructured pattern whose type has no FromArgs::PARAMS.
internal_doc_bytes
internal_doc_len
plain_doc
real_signature
None, a bare FuncArgs, and a default of <unrepresentable> contribute no signature. Some(&[]) is ().
signature_prefix_bytes
signature_prefix_len
static_func
Get the STATIC_FUNC of the passed function. The same requirements of zero-sized-ness apply, see that documentation for details.
static_raw_func

Type Aliases

KwArgsMap
The map behind KwArgs.
OptionalOption
PyComparisonValue
PySize
An unsigned size argument (size_t).
PySsize
A signed size or index argument (Py_ssize_t).