pub struct TimeoutSeconds { /* private fields */ }Expand description
A Python timeout value that accepts both float and int.
TimeoutSeconds implements FromArgs so that a built-in function can accept
timeout parameters given as either float or int, normalizing them to f64.
Implementations