pub struct PyRef<T> { /* private fields */ }Expand description
A reference to a Python object.
Note that a PyRef<T> can only deref to a shared / immutable reference.
It is the payload type’s responsibility to handle (possibly concurrent)
mutability with locks or concurrent data structures if required.
A PyRef<T> can be directly returned from a built-in function to handle
situations (such as when implementing in-place methods such as __iadd__)
where a reference to the same object must be returned.
Implementations
Sourceimpl PyRef<PyStr>
impl PyRef<PyStr>
pub fn is_empty(&self) -> bool
pub fn concat_in_place(&mut self, other: &Wtf8, vm: &VirtualMachine)
pub fn try_into_utf8(self, vm: &VirtualMachine) -> PyResult<PyRef<PyUtf8Str>>
Sourceimpl PyRef<PyTuple<PyObjectRef>>
impl PyRef<PyTuple<PyObjectRef>>
pub fn try_into_typed<T: PyPayload>( self, vm: &VirtualMachine, ) -> PyResult<PyRef<PyTuple<PyRef<T>>>>
Sourceimpl<T: PySubclass + Debug> PyRef<T>
impl<T: PySubclass + Debug> PyRef<T>
Sourceimpl<T: PyPayload> PyRef<T>
impl<T: PyPayload> PyRef<T>
pub fn into_exact_or( self, ctx: &Context, f: impl FnOnce(Self) -> PyRefExact<T>, ) -> PyRefExact<T>
Sourceimpl PyRef<VecBuffer>
impl PyRef<VecBuffer>
pub fn into_pybuffer(self, readonly: bool) -> PyBuffer
pub fn into_pybuffer_with_descriptor(self, desc: BufferDescriptor) -> PyBuffer
Methods from Deref<Target = Py<T>>
pub fn downgrade( &self, callback: Option<PyObjectRef>, vm: &VirtualMachine, ) -> PyResult<PyWeakRef<T>>
pub fn payload(&self) -> &T
Sourcepub fn upcast_ref<U: PyPayload + StaticType>(&self) -> &Py<U>where
T: StaticType,
pub fn upcast_ref<U: PyPayload + StaticType>(&self) -> &Py<U>where
T: StaticType,
Converts &Py<T> to &Py<U> where U is an ancestor type.