Re-exports
pub use slot_defs::SLOT_DEFS;pub use slot_defs::SlotAccessor;pub use slot_defs::SlotDef;
Modules
- slot_
defs - Slot definitions array
Macros
Structs
- PyComparison
Op - PyType
Flags - PyType
Slots - Type
Data Ref - Read guard for type data access, using mapped guard for zero-cost deref.
- Type
Data RefMut - Write guard for type data access, using mapped guard for zero-cost deref.
- Type
Data Slot - Type-erased storage for extension module data attached to heap types.
Traits
- AsBuffer
- AsMapping
- AsNumber
- AsSequence
- Callable
- Comparable
- Constructor
- Trait for types that can be constructed via Python’s
__new__method. - Default
Constructor - Destructor
- GetAttr
- GetDescriptor
- Hashable
- Initializer
- Iter
Next - Iterable
- PyStruct
Sequence - Trait for Python struct sequence types.
- PyStruct
Sequence Data - Trait for Data structs that back a PyStructSequence.
- Representable
- Self
Iter - SetAttr
Functions
- hash_
not_ implemented - Marks a type as unhashable. Similar to PyObject_HashNotImplemented in CPython
- struct_
sequence_ new - Create a new struct sequence instance from a sequence.