pub struct TypeDataRefMut<'a, T: 'static> { /* private fields */ }Expand description
Write guard for type data access, using mapped guard for zero-cost deref.
Implementations
Sourceimpl<'a, T: Any + 'static> TypeDataRefMut<'a, T>
impl<'a, T: Any + 'static> TypeDataRefMut<'a, T>
Sourcepub fn try_new(
guard: PyRwLockWriteGuard<'a, Option<TypeDataSlot>>,
) -> Option<Self>
pub fn try_new( guard: PyRwLockWriteGuard<'a, Option<TypeDataSlot>>, ) -> Option<Self>
Try to create a TypeDataRefMut from a write guard. Returns None if the slot is empty or contains a different type.