Module vm

Module vm 

Implement virtual machine to run instructions.

See also: https://github.com/ProgVal/pythonvm-rust/blob/master/src/processor/mod.rs

Modules

thread

Structs

Context
FramePtr
Non-owning frame pointer for the frames stack. The pointed-to frame is kept alive by the caller of with_frame_exc/resume_gen_frame.
Interpreter
The general interface for the VM
InterpreterBuilder
Configuration builder for constructing an Interpreter.
Paths
Path configuration computed at runtime (like PyConfig path outputs)
PyConfig
Combined configuration: user settings + computed paths CPython directly exposes every fields under both of them. We separate them to maintain better ownership discipline.
PyGlobalState
Settings
User-configurable settings for the python vm.
VirtualMachine
Top level container of a python virtual machine. In theory you could create more instances of this struct and have them operate fully isolated.

Enums

CheckHashPycsMode

Constants

MAX_MEMORY_SIZE

Functions

process_hash_secret_seed
resolve_frozen_alias
Resolve frozen module alias to its original name. Returns the original module name if an alias exists, otherwise returns the input name.