Implement virtual machine to run instructions.
See also: https://github.com/ProgVal/pythonvm-rust/blob/master/src/processor/mod.rs
Modules
Structs
- Context
- Frame
Ptr - Non-owning frame pointer for the frames stack. The pointed-to frame is kept alive by the caller of with_frame_exc/resume_gen_frame.
- Interpreter
- The general interface for the VM
- Interpreter
Builder - Configuration builder for constructing an Interpreter.
- Paths
- Path configuration computed at runtime (like PyConfig path outputs)
- PyConfig
- Combined configuration: user settings + computed paths CPython directly exposes every fields under both of them. We separate them to maintain better ownership discipline.
- PyGlobal
State - Settings
- User-configurable settings for the python vm.
- Virtual
Machine - Top level container of a python virtual machine. In theory you could create more instances of this struct and have them operate fully isolated.
Enums
Constants
Functions
- process_
hash_ secret_ seed - resolve_
frozen_ alias - Resolve frozen module alias to its original name. Returns the original module name if an alias exists, otherwise returns the input name.